@@ -10,49 +10,45 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Implement a shared base for tools which provide actions. """
+""" Implement a shared base for tools which provide actions.
+"""
 
 from warnings import warn
 
+import six
+
+from AccessControl.class_init import InitializeClass
 from AccessControl.SecurityInfo import ClassSecurityInfo
-from App.class_init import InitializeClass
 from App.special_dtml import DTMLFile
-from zope.interface import implements
+from zope.interface import implementer
 
-from Products.CMFCore.ActionInformation import ActionInfo
-from Products.CMFCore.ActionInformation import ActionInformation
-from Products.CMFCore.ActionInformation import getOAI
-from Products.CMFCore.exceptions import AccessControl_Unauthorized
-from Products.CMFCore.Expression import getExprContext
-from Products.CMFCore.interfaces import IActionProvider
-from Products.CMFCore.permissions import ManagePortal
-from Products.CMFCore.utils import _dtmldir
+from .ActionInformation import ActionInfo
+from .ActionInformation import ActionInformation
+from .ActionInformation import getOAI
+from .exceptions import AccessControl_Unauthorized
+from .Expression import getExprContext
+from .interfaces import IActionProvider
+from .permissions import ManagePortal
+from .utils import _dtmldir
 
 
+@implementer(IActionProvider)
 class ActionProviderBase:
 
     """ Provide ActionTabs and management methods for ActionProviders
     """
 
-    implements(IActionProvider)
-
     security = ClassSecurityInfo()
-
     _actions = ()
+    _actions_form = DTMLFile('editToolsActions', _dtmldir)
 
-    _actions_form = DTMLFile( 'editToolsActions', _dtmldir )
-
-    manage_options = ( { 'label'  : 'Actions'
-                       , 'action' : 'manage_editActionsForm'
-                       , 'help'   : ('CMFCore', 'Actions.stx')
-                       }
-                     ,
-                     )
+    manage_options = ({'label': 'Actions', 'action': 'manage_editActionsForm',
+                       'help': ('CMFCore', 'Actions.stx')},)
 
     #
     #   ActionProvider interface
     #
-    security.declarePrivate('listActions')
+    @security.private
     def listActions(self, info=None, object=None):
         """ List all the actions defined by a provider.
         """
@@ -64,7 +60,7 @@ class ActionProviderBase:
 
         return oldstyle_actions
 
-    security.declarePrivate('getActionObject')
+    @security.private
     def getActionObject(self, action):
         """Return the actions object or None if action doesn't exist.
         """
@@ -85,7 +81,7 @@ class ActionProviderBase:
         # no action found
         return None
 
-    security.declarePublic('listActionInfos')
+    @security.public
     def listActionInfos(self, action_chain=None, object=None,
                         check_visibility=1, check_permissions=1,
                         check_condition=1, max=-1):
@@ -94,11 +90,11 @@ class ActionProviderBase:
         #
         ec = self._getExprContext(object)
         actions = self.listActions(object=object)
-        actions = [ ActionInfo(action, ec) for action in actions ]
+        actions = [ActionInfo(action, ec) for action in actions]
 
         if action_chain:
             filtered_actions = []
-            if isinstance(action_chain, basestring):
+            if isinstance(action_chain, six.string_types):
                 action_chain = (action_chain,)
             for action_ident in action_chain:
                 sep = action_ident.rfind('/')
@@ -121,7 +117,7 @@ class ActionProviderBase:
                 break
         return action_infos
 
-    security.declarePublic('getActionInfo')
+    @security.public
     def getActionInfo(self, action_chain, object=None, check_visibility=0,
                       check_condition=0):
         """ Get an ActionInfo object specified by a chain of actions.
@@ -147,8 +143,8 @@ class ActionProviderBase:
     #
     #   ZMI methods
     #
-    security.declareProtected( ManagePortal, 'manage_editActionsForm' )
-    def manage_editActionsForm( self, REQUEST, manage_tabs_message=None ):
+    @security.protected(ManagePortal)
+    def manage_editActionsForm(self, REQUEST, manage_tabs_message=None):
 
         """ Show the 'Actions' management tab.
         """
@@ -161,27 +157,14 @@ class ActionProviderBase:
 
         # possible_permissions is in AccessControl.Role.RoleManager.
         pp = self.possible_permissions()
-        return self._actions_form( self
-                                 , REQUEST
-                                 , actions=actions
-                                 , possible_permissions=pp
-                                 , management_view='Actions'
-                                 , manage_tabs_message=manage_tabs_message
-                                 )
+        return self._actions_form(self, REQUEST, actions=actions,
+                                  possible_permissions=pp,
+                                  management_view='Actions',
+                                  manage_tabs_message=manage_tabs_message)
 
-    security.declareProtected( ManagePortal, 'addAction' )
-    def addAction( self
-                 , id
-                 , name
-                 , action
-                 , condition
-                 , permission
-                 , category
-                 , visible=1
-                 , icon_expr=''
-                 , link_target=''
-                 , REQUEST=None
-                 ):
+    @security.protected(ManagePortal)
+    def addAction(self, id, name, action, condition, permission, category,
+                  visible=1, icon_expr='', link_target='', REQUEST=None):
         """ Add an action to our list.
         """
         if not name:
@@ -195,26 +178,24 @@ class ActionProviderBase:
 
         new_actions = self._cloneActions()
 
-        new_action = ActionInformation( id=str(id)
-                                      , title=str(name)
-                                      , category=str(category)
-                                      , condition=condition
-                                      , permissions=permission
-                                      , visible=bool(visible)
-                                      , action=action
-                                      , icon_expr=icon_expr
-                                      , link_target=link_target
-                                      )
+        new_action = ActionInformation(id=str(id), title=str(name),
+                                       category=str(category),
+                                       condition=condition,
+                                       permissions=permission,
+                                       visible=bool(visible),
+                                       action=action,
+                                       icon_expr=icon_expr,
+                                       link_target=link_target)
 
-        new_actions.append( new_action )
-        self._actions = tuple( new_actions )
+        new_actions.append(new_action)
+        self._actions = tuple(new_actions)
 
         if REQUEST is not None:
             return self.manage_editActionsForm(
                 REQUEST, manage_tabs_message='Added.')
 
-    security.declareProtected( ManagePortal, 'changeActions' )
-    def changeActions( self, properties=None, REQUEST=None ):
+    @security.protected(ManagePortal)
+    def changeActions(self, properties=None, REQUEST=None):
 
         """ Update our list of actions.
         """
@@ -223,43 +204,43 @@ class ActionProviderBase:
 
         actions = []
 
-        for index in range( len( self._actions ) ):
-            actions.append( self._extractAction( properties, index ) )
+        for index in range(len(self._actions)):
+            actions.append(self._extractAction(properties, index))
 
-        self._actions = tuple( actions )
+        self._actions = tuple(actions)
 
         if REQUEST is not None:
-            return self.manage_editActionsForm(REQUEST, manage_tabs_message=
-                                               'Actions changed.')
+            msg = 'Actions changed.'
+            return self.manage_editActionsForm(REQUEST,
+                                               manage_tabs_message=msg)
 
-    security.declareProtected( ManagePortal, 'deleteActions' )
-    def deleteActions( self, selections=(), REQUEST=None ):
+    @security.protected(ManagePortal)
+    def deleteActions(self, selections=(), REQUEST=None):
 
         """ Delete actions indicated by indexes in 'selections'.
         """
-        sels = list( map( int, selections ) )  # Convert to a list of integers.
+        sels = list(map(int, selections))  # Convert to a list of integers.
 
         old_actions = self._cloneActions()
         new_actions = []
 
-        for index in range( len( old_actions ) ):
+        for index in range(len(old_actions)):
             if index not in sels:
-                new_actions.append( old_actions[ index ] )
+                new_actions.append(old_actions[index])
 
-        self._actions = tuple( new_actions )
+        self._actions = tuple(new_actions)
 
         if REQUEST is not None:
-            return self.manage_editActionsForm(
-                REQUEST, manage_tabs_message=(
-                'Deleted %d action(s).' % len(sels)))
+            msg = 'Deleted %d action(s).' % len(sels)
+            return self.manage_editActionsForm(REQUEST,
+                                               manage_tabs_message=msg)
 
-    security.declareProtected( ManagePortal, 'moveUpActions' )
-    def moveUpActions( self, selections=(), REQUEST=None ):
+    @security.protected(ManagePortal)
+    def moveUpActions(self, selections=(), REQUEST=None):
 
         """ Move the specified actions up one slot in our list.
         """
-        sels = list( map( int, selections ) )  # Convert to a list of integers.
-        sels.sort()
+        sels = sorted(map(int, selections))  # Convert to list of ints
 
         new_actions = self._cloneActions()
 
@@ -273,20 +254,19 @@ class ActionProviderBase:
             new_actions[idx2] = new_actions[idx]
             new_actions[idx] = a
 
-        self._actions = tuple( new_actions )
+        self._actions = tuple(new_actions)
 
         if REQUEST is not None:
-            return self.manage_editActionsForm(
-                REQUEST, manage_tabs_message=(
-                'Moved up %d action(s).' % len(sels)))
+            msg = 'Moved up %d action(s).' % len(sels)
+            return self.manage_editActionsForm(REQUEST,
+                                               manage_tabs_message=msg)
 
-    security.declareProtected( ManagePortal, 'moveDownActions' )
-    def moveDownActions( self, selections=(), REQUEST=None ):
+    @security.protected(ManagePortal)
+    def moveDownActions(self, selections=(), REQUEST=None):
 
         """ Move the specified actions down one slot in our list.
         """
-        sels = list( map( int, selections ) )  # Convert to a list of integers.
-        sels.sort()
+        sels = sorted(list(map(int, selections)))  # Convert to list of ints
         sels.reverse()
 
         new_actions = self._cloneActions()
@@ -301,37 +281,37 @@ class ActionProviderBase:
             new_actions[idx2] = new_actions[idx]
             new_actions[idx] = a
 
-        self._actions = tuple( new_actions )
+        self._actions = tuple(new_actions)
 
         if REQUEST is not None:
-            return self.manage_editActionsForm(
-                REQUEST, manage_tabs_message=(
-                'Moved down %d action(s).' % len(sels)))
+            msg = 'Moved down %d action(s).' % len(sels)
+            return self.manage_editActionsForm(REQUEST,
+                                               manage_tabs_message=msg)
 
     #
     #   Helper methods
     #
-    security.declarePrivate( '_cloneActions' )
-    def _cloneActions( self ):
+    @security.private
+    def _cloneActions(self):
 
         """ Return a list of actions, cloned from our current list.
         """
-        return map( lambda x: x.clone(), list( self._actions ) )
+        return [x.clone() for x in list(self._actions)]
 
-    security.declarePrivate( '_extractAction' )
-    def _extractAction( self, properties, index ):
+    @security.private
+    def _extractAction(self, properties, index):
 
         """ Extract an ActionInformation from the funky form properties.
         """
-        id          = str( properties.get( 'id_%d'          % index, '' ) )
-        title       = str( properties.get( 'name_%d'        % index, '' ) )
-        action      = str( properties.get( 'action_%d'      % index, '' ) )
-        icon_expr   = str( properties.get( 'icon_expr_%d'   % index, '' ) )
-        condition   = str( properties.get( 'condition_%d'   % index, '' ) )
-        category    = str( properties.get( 'category_%d'    % index, '' ))
-        visible     = bool( properties.get('visible_%d'     % index, False) )
-        permissions =      properties.get( 'permission_%d'  % index, () )
-        link_target = str( properties.get( 'link_target_%d' % index, '' ) )
+        id = str(properties.get('id_%d' % index, ''))
+        title = str(properties.get('name_%d' % index, ''))
+        action = str(properties.get('action_%d' % index, ''))
+        icon_expr = str(properties.get('icon_expr_%d' % index, ''))
+        condition = str(properties.get('condition_%d' % index, ''))
+        category = str(properties.get('category_%d' % index, ''))
+        visible = bool(properties.get('visible_%d' % index, False))
+        permissions = properties.get('permission_%d' % index, ())
+        link_target = str(properties.get('link_target_%d' % index, ''))
 
         if not title:
             raise ValueError('A title is required.')
@@ -339,19 +319,16 @@ class ActionProviderBase:
         if category == '':
             category = 'object'
 
-        if isinstance(permissions, basestring):
-            permissions = ( permissions, )
+        if isinstance(permissions, six.string_types):
+            permissions = (permissions,)
 
-        return ActionInformation( id=id
-                                , title=title
-                                , action=action
-                                , condition=condition
-                                , permissions=permissions
-                                , category=category
-                                , visible=visible
-                                , icon_expr=icon_expr
-                                , link_target=link_target
-                                )
+        return ActionInformation(id=id, title=title, action=action,
+                                 condition=condition,
+                                 permissions=permissions,
+                                 category=category,
+                                 visible=visible,
+                                 icon_expr=icon_expr,
+                                 link_target=link_target)
 
     def _getOAI(self, object):
         return getOAI(self, object)
@@ -359,4 +336,5 @@ class ActionProviderBase:
     def _getExprContext(self, object):
         return getExprContext(self, object)
 
+
 InitializeClass(ActionProviderBase)
