@@ -11,18 +11,16 @@
 #
 ##############################################################################
 """CMFBTreeFolder
-
-$Id: CMFBTreeFolder.py 122157 2011-07-12 15:16:22Z yuppie $
 """
 
+from AccessControl.class_init import InitializeClass
 from AccessControl.SecurityInfo import ClassSecurityInfo
-from App.class_init import InitializeClass
 from Products.BTreeFolder2.BTreeFolder2 import BTreeFolder2Base
 from zope.component.factory import Factory
 
-from Products.CMFCore.permissions import AddPortalFolders
-from Products.CMFCore.PortalFolder import PortalFolder
-from Products.CMFCore.PortalFolder import PortalFolderBase
+from .permissions import AddPortalFolders
+from .PortalFolder import PortalFolder
+from .PortalFolder import PortalFolderBase
 
 
 def manage_addCMFBTreeFolder(dispatcher, id, title='', REQUEST=None):
@@ -34,7 +32,7 @@ def manage_addCMFBTreeFolder(dispatcher, id, title='', REQUEST=None):
     dispatcher._setObject(id, ob, suppress_events=True)
     ob = dispatcher._getOb(id)
     if REQUEST is not None:
-        REQUEST['RESPONSE'].redirect(ob.absolute_url() + '/manage_main' )
+        REQUEST['RESPONSE'].redirect(ob.absolute_url() + '/manage_main')
 
 
 class CMFBTreeFolder(BTreeFolder2Base, PortalFolderBase):
@@ -52,15 +50,16 @@ class CMFBTreeFolder(BTreeFolder2Base, PortalFolderBase):
         PortalFolderBase._checkId(self, id, allow_dup)
         BTreeFolder2Base._checkId(self, id, allow_dup)
 
-    security.declareProtected(AddPortalFolders, 'manage_addPortalFolder')
+    @security.protected(AddPortalFolders)
     def manage_addPortalFolder(self, id, title='', REQUEST=None):
         """Add a new PortalFolder object with id *id*.
         """
         ob = PortalFolder(id, title)
         self._setObject(id, ob, suppress_events=True)
         if REQUEST is not None:
-            return self.folder_contents( # XXX: ick!
-                self, REQUEST, portal_status_message="Folder added")
+            return self.folder_contents(  # XXX: ick!
+                self, REQUEST, portal_status_message='Folder added')
+
 
 InitializeClass(CMFBTreeFolder)
 
