@@ -11,38 +11,34 @@
 #
 ##############################################################################
 """ Customizable DTML methods that come from the filesystem.
-
-$Id: FSDTMLMethod.py 115542 2010-08-08 10:36:11Z hannosch $
 """
 
-try:
-    from OFS.role import RoleManager
-except ImportError:
-    # BBB for Zope < 2.13
-    from AccessControl.Role import RoleManager
+import six
+from six import get_unbound_function
 
+from AccessControl.class_init import InitializeClass
 from AccessControl.SecurityInfo import ClassSecurityInfo
 from AccessControl.SecurityManagement import getSecurityManager
-from App.class_init import InitializeClass
-from App.special_dtml import DTMLFile
 from App.special_dtml import HTML
-from OFS.DTMLMethod import DTMLMethod, decapitate, guess_content_type
+from App.special_dtml import DTMLFile
+from DocumentTemplate.security import RestrictedDTML
+from OFS.DTMLMethod import DTMLMethod
+from OFS.DTMLMethod import decapitate
+from OFS.DTMLMethod import guess_content_type
+from OFS.role import RoleManager
+from ZPublisher.HTTPRequest import default_encoding
 
-from Products.CMFCore.DirectoryView import registerFileExtension
-from Products.CMFCore.DirectoryView import registerMetaType
-from Products.CMFCore.FSObject import FSObject
-from Products.CMFCore.permissions import FTPAccess
-from Products.CMFCore.permissions import View
-from Products.CMFCore.permissions import ViewManagementScreens
-from Products.CMFCore.utils import _checkConditionalGET
-from Products.CMFCore.utils import _dtmldir
-from Products.CMFCore.utils import _setCacheHeaders
+from .DirectoryView import registerFileExtension
+from .DirectoryView import registerMetaType
+from .FSObject import FSObject
+from .permissions import FTPAccess
+from .permissions import View
+from .permissions import ViewManagementScreens
+from .utils import HAS_ZSERVER
+from .utils import _checkConditionalGET
+from .utils import _dtmldir
+from .utils import _setCacheHeaders
 
-# BBB for Zope 2.12
-try:
-    from DocumentTemplate.security import RestrictedDTML
-except ImportError:
-    from AccessControl.DTML import RestrictedDTML
 
 _marker = object()
 
@@ -54,15 +50,16 @@ class FSDTMLMethod(RestrictedDTML, RoleManager, FSObject, HTML):
     """
 
     meta_type = 'Filesystem DTML Method'
+    zmi_icon = 'far fa-file-alt'
     _owner = None
     _proxy_roles = ()
     _cache_namespace_keys = ()
     _reading = 0
 
-    manage_options=({'label':'Customize', 'action':'manage_main'},
-                    {'label':'View', 'action':''},
-                    {'label':'Proxy', 'action':'manage_proxyForm'},
-                   )
+    manage_options = (
+        {'label': 'Customize', 'action': 'manage_main'},
+        {'label': 'View', 'action': ''},
+        {'label': 'Proxy', 'action': 'manage_proxyForm'})
 
     security = ClassSecurityInfo()
     security.declareObjectProtected(View)
@@ -75,6 +72,9 @@ class FSDTMLMethod(RestrictedDTML, RoleManager, FSObject, HTML):
         # Normally called via HTML.__init__ but we don't need the rest that
         # happens there.
         self.initvars(None, {})
+        # Set a sane default encoding value if it was not already set
+        if 'encoding' not in self.__dict__:
+            self.encoding = default_encoding
 
     def _createZODBClone(self):
         """Create a ZODB (editable) equivalent of this object."""
@@ -83,7 +83,7 @@ class FSDTMLMethod(RestrictedDTML, RoleManager, FSObject, HTML):
     def _readFile(self, reparse):
         """Read the data from the filesystem.
         """
-        file = open(self._filepath, 'r') # not 'rb', as this is a text file!
+        file = open(self._filepath, 'r')  # not 'rb', as this is a text file!
         try:
             data = file.read()
         finally:
@@ -98,18 +98,18 @@ class FSDTMLMethod(RestrictedDTML, RoleManager, FSObject, HTML):
                 self._reading = 0
 
     # Hook up chances to reload in debug mode
-    security.declarePrivate('read_raw')
+    @security.private
     def read_raw(self):
         if not self._reading:
             self._updateFromFS()
         return HTML.read_raw(self)
 
-    #### The following is mainly taken from OFS/DTMLMethod.py ###
+    # The following is mainly taken from OFS/DTMLMethod.py
 
-    index_html=None # Prevent accidental acquisition
+    index_html = None  # Prevent accidental acquisition
 
     # Documents masquerade as functions:
-    func_code = DTMLMethod.func_code
+    __code__ = DTMLMethod.__code__
 
     default_content_type = 'text/html'
 
@@ -119,8 +119,9 @@ class FSDTMLMethod(RestrictedDTML, RoleManager, FSObject, HTML):
 
         self._updateFromFS()
 
-        kw['document_id']   =self.getId()
-        kw['document_title']=self.title
+        kw['document_id'] = self.getId()
+        kw['document_title'] = self.title
+        kw['encoding'] = getattr(self, 'encoding') or None
 
         if client is not None:
             if _checkConditionalGET(self, kw):
@@ -133,32 +134,39 @@ class FSDTMLMethod(RestrictedDTML, RoleManager, FSObject, HTML):
                 return data
 
         __traceback_info__ = self._filepath
-        security=getSecurityManager()
+        security = getSecurityManager()
         security.addContext(self)
         try:
             r = HTML.__call__(self, client, REQUEST, **kw)
 
             if client is None:
                 # Called as subtemplate, so don't need error propagation!
-                if RESPONSE is None: result = r
-                else: result = decapitate(r, RESPONSE)
+                if RESPONSE is None:
+                    result = r
+                else:
+                    result = decapitate(r, RESPONSE)
                 if not self._cache_namespace_keys:
                     self.ZCacheable_set(result)
                 return result
 
-            if not isinstance(r, basestring) or RESPONSE is None:
+            if not isinstance(r, six.string_types) or RESPONSE is None:
                 if not self._cache_namespace_keys:
                     self.ZCacheable_set(r)
                 return r
 
-        finally: security.removeContext(self)
+        finally:
+            security.removeContext(self)
 
-        have_key=RESPONSE.headers.has_key
-        if not (have_key('content-type') or have_key('Content-Type')):
-            if self.__dict__.has_key('content_type'):
-                c=self.content_type
+        headers = RESPONSE.headers
+        if not ('content-type' in headers or 'Content-Type' in headers):
+            if 'content_type' in self.__dict__:
+                c = self.content_type
             else:
-                c, e=guess_content_type(self.getId(), r)
+                if six.PY2:
+                    c, _e = guess_content_type(self.getId(), r)
+                else:
+                    c, _e = guess_content_type(self.getId(), r.encode())
+
             RESPONSE.setHeader('Content-Type', c)
         if RESPONSE is not None:
             # caching policy manager hook
@@ -169,16 +177,16 @@ class FSDTMLMethod(RestrictedDTML, RoleManager, FSObject, HTML):
         return result
 
     def getCacheNamespaceKeys(self):
-        '''
+        """
         Returns the cacheNamespaceKeys.
-        '''
+        """
         return self._cache_namespace_keys
 
     def setCacheNamespaceKeys(self, keys, REQUEST=None):
-        '''
+        """
         Sets the list of names that should be looked up in the
         namespace to provide a cache key.
-        '''
+        """
         ks = []
         for key in keys:
             key = str(key).strip()
@@ -192,17 +200,20 @@ class FSDTMLMethod(RestrictedDTML, RoleManager, FSObject, HTML):
     def validate(self, inst, parent, name, value, md=None):
         return getSecurityManager().validate(inst, parent, name, value)
 
-    security.declareProtected(FTPAccess, 'manage_FTPget')
-    manage_FTPget = DTMLMethod.manage_FTPget.im_func
+    if HAS_ZSERVER:
+        security.declareProtected(FTPAccess, 'manage_FTPget')
+        manage_FTPget = get_unbound_function(DTMLMethod.manage_FTPget)
 
     security.declareProtected(ViewManagementScreens, 'PrincipiaSearchSource')
-    PrincipiaSearchSource = DTMLMethod.PrincipiaSearchSource.im_func
+    PrincipiaSearchSource = get_unbound_function(
+                                DTMLMethod.PrincipiaSearchSource)
 
     security.declareProtected(ViewManagementScreens, 'document_src')
-    document_src = DTMLMethod.document_src.im_func
+    document_src = get_unbound_function(DTMLMethod.document_src)
 
     security.declareProtected(ViewManagementScreens, 'manage_haveProxy')
-    manage_haveProxy = DTMLMethod.manage_haveProxy.im_func
+    manage_haveProxy = get_unbound_function(DTMLMethod.manage_haveProxy)
+
 
 InitializeClass(FSDTMLMethod)
 
