@@ -11,30 +11,32 @@
 #
 ##############################################################################
 """ Customizable image objects that come from the filesystem.
-
-$Id: FSFile.py 110577 2010-04-07 06:33:17Z jens $
 """
 
 import codecs
 import os
+from warnings import warn
 
+import six
+
+from AccessControl.class_init import InitializeClass
 from AccessControl.SecurityInfo import ClassSecurityInfo
-from App.class_init import InitializeClass
 from App.special_dtml import DTMLFile
 from OFS.Image import File
 from zope.contenttype import guess_content_type
+from ZPublisher.HTTPRequest import default_encoding
 
-from Products.CMFCore.DirectoryView import registerFileExtension
-from Products.CMFCore.DirectoryView import registerMetaType
-from Products.CMFCore.FSObject import FSObject
-from Products.CMFCore.permissions import FTPAccess
-from Products.CMFCore.permissions import View
-from Products.CMFCore.permissions import ViewManagementScreens
-from Products.CMFCore.utils import _checkConditionalGET
-from Products.CMFCore.utils import _dtmldir
-from Products.CMFCore.utils import _FSCacheHeaders
-from Products.CMFCore.utils import _setCacheHeaders
-from Products.CMFCore.utils import _ViewEmulator
+from .DirectoryView import registerFileExtension
+from .DirectoryView import registerMetaType
+from .FSObject import FSObject
+from .permissions import FTPAccess
+from .permissions import View
+from .permissions import ViewManagementScreens
+from .utils import _checkConditionalGET
+from .utils import _dtmldir
+from .utils import _FSCacheHeaders
+from .utils import _setCacheHeaders
+from .utils import _ViewEmulator
 
 
 class FSFile(FSObject):
@@ -44,9 +46,10 @@ class FSFile(FSObject):
     # Note that OFS.Image.File is not a base class because it is mutable.
 
     meta_type = 'Filesystem File'
+    zmi_icon = 'far fa-file-archive'
     content_type = 'unknown/unknown'
 
-    manage_options = ({'label':'Customize', 'action':'manage_main'},)
+    manage_options = ({'label': 'Customize', 'action': 'manage_main'},)
 
     security = ClassSecurityInfo()
     security.declareObjectProtected(View)
@@ -55,7 +58,7 @@ class FSFile(FSObject):
     manage_main = DTMLFile('custfile', _dtmldir)
 
     def __init__(self, id, filepath, fullname=None, properties=None):
-        id = fullname or id # Use the whole filename.
+        id = fullname or id  # Use the whole filename.
         FSObject.__init__(self, id, filepath, fullname, properties)
 
     def _createZODBClone(self):
@@ -70,21 +73,21 @@ class FSFile(FSObject):
             return self.content_type
 
         # Next, look at file headers
-        headers=getattr(file, 'headers', None)
-        if headers and headers.has_key('content-type'):
-            content_type=headers['content-type']
+        headers = getattr(file, 'headers', None)
+        if headers and 'content-type' in headers:
+            content_type = headers['content-type']
         else:
             # Last resort: Use the (imperfect) content type guessing
             # mechanism from OFS.Image, which ultimately uses the
             # Python mimetypes module.
-            if not isinstance(body, basestring):
+            if not isinstance(body, (six.string_types, six.binary_type)):
                 body = body.data
-            content_type, enc=guess_content_type(
-                getattr(file, 'filename',id), body, content_type)
+            content_type, enc = guess_content_type(
+                getattr(file, 'filename', id), body, content_type)
             if (enc is None
                 and (content_type.startswith('text/') or
                      content_type.startswith('application/'))
-                and body.startswith(codecs.BOM_UTF8)):
+                    and body.startswith(codecs.BOM_UTF8)):
                 content_type += '; charset=utf-8'
 
         return content_type
@@ -100,25 +103,48 @@ class FSFile(FSObject):
 
         if reparse or self.content_type == 'unknown/unknown':
             try:
-                mtime = os.stat(self._filepath)[8]
-            except:
-                mtime = 0
-            if mtime != self._file_mod_time or mtime == 0:
+                mtime = os.stat(self._filepath).st_mtime
+            except Exception:
+                mtime = 0.0
+            if mtime != self._file_mod_time or mtime == 0.0:
                 self.ZCacheable_invalidate()
                 self._file_mod_time = mtime
-            self.content_type=self._get_content_type(file, data, self.id)
+            self.content_type = self._get_content_type(file, data, self.id)
         return data
 
-    #### The following is mainly taken from OFS/File.py ###
+    # The following is mainly taken from OFS/File.py
 
     def __str__(self):
         self._updateFromFS()
-        return str( self._readFile( 0 ) )
+        if six.PY2:
+            return str(self._readFile(0))
+
+        data = self._readFile(0)
+        ct = self.content_type
+        encoding = None
+
+        if 'charset=' in ct:
+            encoding = ct[ct.find('charset=')+8:]
+        elif getattr(self, 'encoding', None):
+            encoding = self.encoding
+        elif ct.startswith('text/'):
+            encoding = default_encoding
+
+        if encoding:
+            return str(data, encoding=encoding)
+
+        warn('Calling str() on non-text data is deprecated, use bytes()',
+             DeprecationWarning, stacklevel=2)
+        return str(data, encoding=default_encoding)
+
+    def __bytes__(self):
+        self._updateFromFS()
+        return bytes(self._readFile(0))
 
     def modified(self):
         return self.getModTime()
 
-    security.declareProtected(View, 'index_html')
+    @security.protected(View)
     def index_html(self, REQUEST, RESPONSE):
         """
         The default view of the contents of a File or Image.
@@ -146,9 +172,9 @@ class FSFile(FSObject):
         data_len = len(data)
         RESPONSE.setHeader('Content-Length', data_len)
 
-        #There are 2 Cache Managers which can be in play....
-        #need to decide which to use to determine where the cache headers
-        #are decided on.
+        # There are 2 Cache Managers which can be in play....
+        # need to decide which to use to determine where the cache headers
+        # are decided on.
         if self.ZCacheable_getManager() is not None:
             self.ZCacheable_set(None)
         else:
@@ -159,7 +185,7 @@ class FSFile(FSObject):
         # return False to disable this simple caching behaviour
         return _FSCacheHeaders(self)
 
-    security.declareProtected(View, 'getContentType')
+    @security.protected(View)
     def getContentType(self):
         """Get the content type of a file or image.
 
@@ -171,6 +197,7 @@ class FSFile(FSObject):
     security.declareProtected(FTPAccess, 'manage_FTPget')
     manage_FTPget = index_html
 
+
 InitializeClass(FSFile)
 
 registerFileExtension('doc', FSFile)
@@ -182,4 +209,10 @@ registerFileExtension('cab', FSFile)
 registerFileExtension('ico', FSFile)
 registerFileExtension('js', FSFile)
 registerFileExtension('css', FSFile)
+registerFileExtension('map', FSFile)
+registerFileExtension('svg', FSFile)
+registerFileExtension('ttf', FSFile)
+registerFileExtension('eot', FSFile)
+registerFileExtension('woff', FSFile)
+registerFileExtension('woff2', FSFile)
 registerMetaType('File', FSFile)
