@@ -11,37 +11,41 @@
 #
 ##############################################################################
 """ Customizable page templates that come from the filesystem.
-
-$Id: FSPageTemplate.py 110577 2010-04-07 06:33:17Z jens $
 """
 
 import re
 
+import six
+from six import get_unbound_function
+
+from AccessControl.class_init import InitializeClass
 from AccessControl.SecurityInfo import ClassSecurityInfo
 from AccessControl.SecurityManagement import getSecurityManager
-from App.class_init import InitializeClass
 from App.special_dtml import DTMLFile
 from Products.PageTemplates.PageTemplate import PageTemplate
 from Products.PageTemplates.utils import charsetFromMetaEquiv
 from Products.PageTemplates.utils import encodingFromXMLPreamble
-from Products.PageTemplates.ZopePageTemplate import preferred_encodings
 from Products.PageTemplates.ZopePageTemplate import Src
 from Products.PageTemplates.ZopePageTemplate import ZopePageTemplate
+from Products.PageTemplates.ZopePageTemplate import preferred_encodings
 from Shared.DC.Scripts.Script import Script
 
-from Products.CMFCore.DirectoryView import registerFileExtension
-from Products.CMFCore.DirectoryView import registerMetaType
-from Products.CMFCore.FSObject import FSObject
-from Products.CMFCore.permissions import FTPAccess
-from Products.CMFCore.permissions import View
-from Products.CMFCore.permissions import ViewManagementScreens
-from Products.CMFCore.utils import _checkConditionalGET
-from Products.CMFCore.utils import _dtmldir
-from Products.CMFCore.utils import _setCacheHeaders
+from .DirectoryView import registerFileExtension
+from .DirectoryView import registerMetaType
+from .FSObject import FSObject
+from .permissions import FTPAccess
+from .permissions import View
+from .permissions import ViewManagementScreens
+from .utils import HAS_ZSERVER
+from .utils import _checkConditionalGET
+from .utils import _dtmldir
+from .utils import _setCacheHeaders
 
 
-xml_detect_re = re.compile('^\s*<\?xml\s+(?:[^>]*?encoding=["\']([^"\'>]+))?')
-charset_re = re.compile(r'charset.*?=.*?(?P<charset>[\w\-]*)', re.I|re.M|re.S)
+xml_detect_re = re.compile(
+    br'^\s*<\?xml\s+(?:[^>]*?encoding=["\']([^"\'>]+))?')
+charset_re = re.compile(r'charset.*?=.*?(?P<charset>[\w\-]*)',
+                        re.I | re.M | re.S)
 _marker = object()
 
 
@@ -51,20 +55,21 @@ class FSPageTemplate(FSObject, Script, PageTemplate):
     """
 
     meta_type = 'Filesystem Page Template'
+    zmi_icon = 'far fa-file-code'
     _owner = None  # Unowned
 
-    manage_options=({'label':'Customize', 'action':'manage_main'},
-                    {'label':'Test', 'action':'ZScriptHTML_tryForm'},
-                   )
+    manage_options = (
+        {'label': 'Customize', 'action': 'manage_main'},)
 
     security = ClassSecurityInfo()
     security.declareObjectProtected(View)
 
-    security.declareProtected(ViewManagementScreens, 'manage_main')
+    security.declareProtected(ViewManagementScreens,  # NOQA: flake8: D001
+                              'manage_main')
     manage_main = DTMLFile('custpt', _dtmldir)
 
     # Declare security for unprotected PageTemplate methods.
-    security.declarePrivate('pt_edit', 'write')
+    security.declarePrivate('pt_edit', 'write')  # NOQA: flake8: D001
 
     def __init__(self, id, filepath, fullname=None, properties=None):
         FSObject.__init__(self, id, filepath, fullname, properties)
@@ -84,9 +89,15 @@ class FSPageTemplate(FSObject, Script, PageTemplate):
         """Read the data from the filesystem.
         """
         if reparse:
-            file = open(self._filepath, 'rU') # not 'rb', as this is a text file!
+            if six.PY2:
+                # not 'rb', as this is a text file!
+                file = open(self._filepath, 'rU')
+            else:
+                file = open(self._filepath, 'br')
             try:
                 data = file.read()
+                if not six.PY2:
+                    data = data.replace(b'\r\n', b'\n').replace(b'\r', b'\n')
             finally:
                 file.close()
 
@@ -104,10 +115,16 @@ class FSPageTemplate(FSObject, Script, PageTemplate):
                 if xml_info:
                     # Smells like xml
                     # set "content_type" from the XML declaration
-                    encoding = xml_info.group(1) or 'utf-8'
+                    if xml_info.group(1):
+                        if six.PY3:
+                            encoding = xml_info.group(1).decode('ascii')
+                        else:
+                            encoding = xml_info.group(1)
+                    else:
+                        encoding = 'utf-8'
                     self.content_type = 'text/xml; charset=%s' % encoding
 
-            if not isinstance(data, unicode):
+            if not isinstance(data, six.text_type):
                 if encoding is None:
                     charset = getattr(self, 'charset', None)
 
@@ -119,13 +136,13 @@ class FSPageTemplate(FSObject, Script, PageTemplate):
 
                             if charset is None:
                                 charset = charsetFromMetaEquiv(data)
-                                
+
                         elif self.content_type.startswith('text/xml'):
                             charset = encodingFromXMLPreamble(data)
 
                         else:
-                            raise ValueError('Unsupported content_type: %s'
-                                                % self.content_type)
+                            raise ValueError('Unsupported content_type: %s' %
+                                             self.content_type)
 
                     if charset is not None:
                         preferred.insert(0, charset)
@@ -135,32 +152,32 @@ class FSPageTemplate(FSObject, Script, PageTemplate):
 
                 for enc in preferred:
                     try:
-                        data = unicode(data, enc)
-                        if isinstance(data, unicode):
+                        data = six.text_type(data, enc)
+                        if isinstance(data, six.text_type):
                             break
                     except UnicodeDecodeError:
-                            continue
+                        continue
                 else:
-                    data = unicode(data)
+                    data = six.text_type(data)
 
             self.write(data)
 
-
-    security.declarePrivate('read')
+    @security.private
     def read(self):
         # Tie in on an opportunity to auto-update
         self._updateFromFS()
         return FSPageTemplate.inheritedAttribute('read')(self)
 
-    ### The following is mainly taken from ZopePageTemplate.py ###
+    # The following is mainly taken from ZopePageTemplate.py
 
     expand = 0
+    output_encoding = 'utf-8'
 
-    func_defaults = None
-    func_code = ZopePageTemplate.func_code
+    __defaults__ = None
+    __code__ = ZopePageTemplate.__code__
     _default_bindings = ZopePageTemplate._default_bindings
 
-    security.declareProtected(View, '__call__')
+    security.declareProtected(View, '__call__')  # NOQA: flake8: D001
 
     def pt_macros(self):
         # Tie in on an opportunity to auto-reload
@@ -177,23 +194,22 @@ class FSPageTemplate(FSObject, Script, PageTemplate):
                 return ''
 
         result = FSPageTemplate.inheritedAttribute('pt_render')(
-                                self, source, extra_context
-                                )
+                                self, source, extra_context)
         if not source:
             _setCacheHeaders(self, extra_context)
         return result
 
-    security.declareProtected(ViewManagementScreens, 'pt_source_file')
+    @security.protected(ViewManagementScreens)
     def pt_source_file(self):
 
         """ Return a file name to be compiled into the TAL code.
         """
         return 'file:%s' % self._filepath
 
-    security.declarePrivate( '_ZPT_exec' )
-    _ZPT_exec = ZopePageTemplate._exec.im_func
+    security.declarePrivate('_ZPT_exec')  # NOQA: flake8: D001
+    _ZPT_exec = get_unbound_function(ZopePageTemplate._exec)
 
-    security.declarePrivate( '_exec' )
+    @security.private
     def _exec(self, bound_names, args, kw):
         """Call a FSPageTemplate"""
         try:
@@ -203,18 +219,18 @@ class FSPageTemplate(FSObject, Script, PageTemplate):
         # Read file first to get a correct content_type default value.
         self._updateFromFS()
 
-        if not kw.has_key('args'):
+        if 'args' not in kw:
             kw['args'] = args
         bound_names['options'] = kw
 
         try:
             response = self.REQUEST.RESPONSE
-            if not response.headers.has_key('content-type'):
+            if 'content-type' not in response.headers:
                 response.setHeader('content-type', self.content_type)
         except AttributeError:
             pass
 
-        security=getSecurityManager()
+        security = getSecurityManager()
         bound_names['user'] = security.getUser()
 
         # Retrieve the value from the cache.
@@ -248,26 +264,30 @@ class FSPageTemplate(FSObject, Script, PageTemplate):
         return result
 
     # Copy over more methods
-    security.declareProtected(FTPAccess, 'manage_FTPget')
-    manage_FTPget = ZopePageTemplate.manage_FTPget.im_func
+    if HAS_ZSERVER:
+        security.declareProtected(FTPAccess,  # NOQA: flake8: D001
+                                  'manage_FTPget')
+        manage_FTPget = get_unbound_function(ZopePageTemplate.manage_FTPget)
 
-    security.declareProtected(View, 'get_size')
-    get_size = ZopePageTemplate.get_size.im_func
+    security.declareProtected(View, 'get_size')  # NOQA: flake8: D001
+    get_size = get_unbound_function(ZopePageTemplate.get_size)
     getSize = get_size
 
-    security.declareProtected(ViewManagementScreens, 'PrincipiaSearchSource')
-    PrincipiaSearchSource = ZopePageTemplate.PrincipiaSearchSource.im_func
+    security.declareProtected(ViewManagementScreens,  # NOQA: flake8: D001
+                              'PrincipiaSearchSource')
+    PrincipiaSearchSource = get_unbound_function(
+                                ZopePageTemplate.PrincipiaSearchSource)
 
-    security.declareProtected(ViewManagementScreens, 'document_src')
-    document_src = ZopePageTemplate.document_src.im_func
+    security.declareProtected(ViewManagementScreens,  # NOQA: flake8: D001
+                              'document_src')
+    document_src = get_unbound_function(ZopePageTemplate.document_src)
 
-    pt_getContext = ZopePageTemplate.pt_getContext.im_func
-
-    ZScriptHTML_tryParams = ZopePageTemplate.ZScriptHTML_tryParams.im_func
+    pt_getContext = get_unbound_function(ZopePageTemplate.pt_getContext)
 
     source_dot_xml = Src()
 
-setattr(FSPageTemplate, 'source.xml',  FSPageTemplate.source_dot_xml)
+
+setattr(FSPageTemplate, 'source.xml', FSPageTemplate.source_dot_xml)
 setattr(FSPageTemplate, 'source.html', FSPageTemplate.source_dot_xml)
 InitializeClass(FSPageTemplate)
 
