@@ -12,28 +12,27 @@
 #
 ##############################################################################
 """ FSSTXMethod: Filesystem methodish Structured Text document.
-
-$Id: FSSTXMethod.py 114572 2010-07-11 10:53:36Z hannosch $
 """
 
+from AccessControl.class_init import InitializeClass
 from AccessControl.SecurityInfo import ClassSecurityInfo
-from App.class_init import InitializeClass
 from App.special_dtml import DTMLFile
 from DocumentTemplate.DT_HTML import HTML as DTML_HTML
 from OFS.DTMLDocument import DTMLDocument
 from Products.PageTemplates.ZopePageTemplate import ZopePageTemplate
 from zope.structuredtext import stx2html
 
-from Products.CMFCore.DirectoryView import registerFileExtension
-from Products.CMFCore.DirectoryView import registerMetaType
-from Products.CMFCore.FSObject import FSObject
-from Products.CMFCore.permissions import FTPAccess
-from Products.CMFCore.permissions import View
-from Products.CMFCore.permissions import ViewManagementScreens
-from Products.CMFCore.utils import _dtmldir
-from Products.CMFCore.utils import _checkConditionalGET
-from Products.CMFCore.utils import _setCacheHeaders
-from Products.CMFCore.utils import _ViewEmulator
+from .DirectoryView import registerFileExtension
+from .DirectoryView import registerMetaType
+from .FSObject import FSObject
+from .permissions import FTPAccess
+from .permissions import View
+from .permissions import ViewManagementScreens
+from .utils import _checkConditionalGET
+from .utils import _dtmldir
+from .utils import _setCacheHeaders
+from .utils import _ViewEmulator
+
 
 _STX_TEMPLATE = 'ZPT'  # or 'DTML'
 
@@ -77,15 +76,15 @@ COOKED TEXT HERE
 </html>
 """
 
+
 class FSSTXMethod(FSObject):
     """ A chunk of StructuredText, rendered as a skin method of a CMF site.
     """
     meta_type = 'Filesystem STX Method'
-    _owner = None # unowned
+    _owner = None  # unowned
 
-    manage_options=({'label' : 'Customize','action' : 'manage_main'},
-                    {'label' : 'View','action' : ''},
-                   )
+    manage_options = ({'label': 'Customize', 'action': 'manage_main'},
+                      {'label': 'View', 'action': ''})
 
     security = ClassSecurityInfo()
     security.declareObjectProtected(View)
@@ -112,7 +111,7 @@ class FSSTXMethod(FSObject):
     def _readFile(self, reparse):
         """Read the data from the filesystem.
         """
-        file = open(self._filepath, 'r') # not 'rb', as this is a text file!
+        file = open(self._filepath, 'r')  # not 'rb', as this is a text file!
         try:
             data = file.read()
         finally:
@@ -125,16 +124,14 @@ class FSSTXMethod(FSObject):
     #
     #   "Wesleyan" interface (we need to be "methodish").
     #
-    class func_code:
+    class _func_code:
         pass
 
-    func_code = func_code()
-    func_code.co_varnames = ()
-    func_code.co_argcount = 0
-    func_code.__roles__ = ()
+    __code__ = _func_code()
+    __code__.co_varnames = ()
+    __code__.co_argcount = 0
 
-    func_defaults__roles__ = ()
-    func_defaults = ()
+    __defaults__ = ()
 
     index_html = None   # No accidental acquisition
 
@@ -147,15 +144,16 @@ class FSSTXMethod(FSObject):
 
     _default_DTML_template = DTML_HTML(_DEFAULT_TEMPLATE_DTML)
     _default_ZPT_template = ZopePageTemplate('stxmethod_view',
-                                             _DEFAULT_TEMPLATE_ZPT, 'text/html')
+                                             _DEFAULT_TEMPLATE_ZPT,
+                                             'text/html')
 
-    def __call__( self, REQUEST={}, RESPONSE=None, **kw ):
+    def __call__(self, REQUEST={}, RESPONSE=None, **kw):
         """ Return our rendered StructuredText.
         """
         self._updateFromFS()
 
         if RESPONSE is not None:
-            RESPONSE.setHeader( 'Content-Type', 'text/html' )
+            RESPONSE.setHeader('Content-Type', 'text/html')
 
         view = _ViewEmulator(self.getId()).__of__(self)
         if _checkConditionalGET(view, extra_context={}):
@@ -165,11 +163,11 @@ class FSSTXMethod(FSObject):
 
         return self._render(REQUEST, RESPONSE, **kw)
 
-    security.declarePrivate('modified')
+    @security.private
     def modified(self):
         return self.getModTime()
 
-    security.declarePrivate('_render')
+    @security.private
     def _render(self, REQUEST={}, RESPONSE=None, **kw):
         """ Find the appropriate rendering template and use it to render us.
         """
@@ -183,7 +181,6 @@ class FSSTXMethod(FSObject):
         template = getattr(self, 'stxmethod_view', default_template)
 
         if getattr(template, 'isDocTemp', 0):
-            #posargs = (self, REQUEST, RESPONSE)
             posargs = (self, REQUEST)
         else:
             posargs = ()
@@ -191,24 +188,25 @@ class FSSTXMethod(FSObject):
         kwargs = {'cooked': self.cook()}
         return template(*posargs, **kwargs)
 
-    security.declareProtected(FTPAccess, 'manage_FTPget')
+    @security.protected(FTPAccess)
     def manage_FTPget(self):
         """ Fetch our source for delivery via FTP.
         """
         return self.raw
 
-    security.declareProtected(ViewManagementScreens, 'PrincipiaSearchSource')
+    @security.protected(ViewManagementScreens)
     def PrincipiaSearchSource(self):
         """ Fetch our source for indexing in a catalog.
         """
         return self.raw
 
-    security.declareProtected(ViewManagementScreens, 'document_src')
-    def document_src( self ):
+    @security.protected(ViewManagementScreens)
+    def document_src(self):
         """ Fetch our source for rendering in the ZMI.
         """
         return self.raw
 
+
 InitializeClass(FSSTXMethod)
 
 registerFileExtension('stx', FSSTXMethod)
