@@ -11,25 +11,24 @@
 #
 ##############################################################################
 """ Customizable ZSQL methods that come from the filesystem.
-
-$Id: FSZSQLMethod.py 110577 2010-04-07 06:33:17Z jens $
 """
 
 import logging
 
+from AccessControl.class_init import InitializeClass
 from AccessControl.SecurityInfo import ClassSecurityInfo
 from Acquisition import ImplicitAcquisitionWrapper
-from App.class_init import InitializeClass
+from App.config import getConfiguration
 from App.special_dtml import DTMLFile
-import Globals # for data
 from Products.ZSQLMethods.SQL import SQL
 
-from Products.CMFCore.DirectoryView import registerFileExtension
-from Products.CMFCore.DirectoryView import registerMetaType
-from Products.CMFCore.FSObject import FSObject
-from Products.CMFCore.permissions import View
-from Products.CMFCore.permissions import ViewManagementScreens
-from Products.CMFCore.utils import _dtmldir
+from .DirectoryView import registerFileExtension
+from .DirectoryView import registerMetaType
+from .FSObject import FSObject
+from .permissions import View
+from .permissions import ViewManagementScreens
+from .utils import _dtmldir
+
 
 logger = logging.getLogger('CMFCore.FSZSQLMethod')
 
@@ -41,10 +40,10 @@ class FSZSQLMethod(SQL, FSObject):
 
     meta_type = 'Filesystem Z SQL Method'
 
-    manage_options = ({'label':'Customize', 'action':'manage_customise'},
-                      {'label':'Test', 'action':'manage_testForm',
-                       'help':('ZSQLMethods','Z-SQL-Method_Test.stx')},
-                     )
+    manage_options = (
+        {'label': 'Customize', 'action': 'manage_customise'},
+        {'label': 'Test', 'action': 'manage_testForm',
+         'help': ('ZSQLMethods', 'Z-SQL-Method_Test.stx')})
 
     security = ClassSecurityInfo()
     security.declareObjectProtected(View)
@@ -54,7 +53,7 @@ class FSZSQLMethod(SQL, FSObject):
     security.declarePrivate('manage_edit')
     security.declarePrivate('manage_advanced')
     security.declarePrivate('manage_advancedForm')
-    manage=None
+    manage = None
 
     security.declareProtected(ViewManagementScreens, 'manage_customise')
     manage_customise = DTMLFile('custzsql', _dtmldir)
@@ -83,43 +82,43 @@ class FSZSQLMethod(SQL, FSObject):
     def _readFile(self, reparse):
         """Read the data from the filesystem.
         """
-        file = open(self._filepath, 'r') # not 'rb', as this is a text file!
+        file = open(self._filepath, 'r')  # not 'rb', as this is a text file!
         try:
             data = file.read()
         finally:
             file.close()
 
         # parse parameters
-        parameters={}
+        parameters = {}
         start = data.find('<dtml-comment>')
-        end   = data.find('</dtml-comment>')
-        if start==-1 or end==-1 or start>end:
-            raise ValueError,'Could not find parameter block'
-        block = data[start+14:end]
+        end = data.find('</dtml-comment>')
+        if start == -1 or end == -1 or start > end:
+            raise ValueError('Could not find parameter block')
+        block = data[start + 14:end]
 
         for line in block.split('\n'):
-            pair = line.split(':',1)
-            if len(pair)!=2:
+            pair = line.split(':', 1)
+            if len(pair) != 2:
                 continue
-            parameters[pair[0].strip().lower()]=pair[1].strip()
+            parameters[pair[0].strip().lower()] = pair[1].strip()
 
         # check for required parameters
         try:
-            connection_id =   ( parameters.get('connection id', '') or
-                                parameters['connection_id'] )
-        except KeyError,e:
+            connection_id = (parameters.get('connection id', '') or
+                             parameters['connection_id'])
+        except KeyError as e:
             raise ValueError("The '%s' parameter is required "
-                             "but was not supplied" % e)
+                             'but was not supplied' % e)
 
         # Optional parameters
-        title =           parameters.get('title','')
-        arguments =       parameters.get('arguments','')
-        max_rows =        parameters.get('max_rows',1000)
-        max_cache =       parameters.get('max_cache',100)
-        cache_time =      parameters.get('cache_time',0)
-        class_name =      parameters.get('class_name','')
-        class_file =      parameters.get('class_file','')
-        connection_hook = parameters.get('connection_hook',None)
+        title = parameters.get('title', '')
+        arguments = parameters.get('arguments', '')
+        max_rows = parameters.get('max_rows', 1000)
+        max_cache = parameters.get('max_cache', 100)
+        cache_time = parameters.get('cache_time', 0)
+        class_name = parameters.get('class_name', '')
+        class_file = parameters.get('class_file', '')
+        connection_hook = parameters.get('connection_hook', None)
         direct = parameters.get('allow_simple_one_argument_traversal', None)
 
         self.manage_edit(title, connection_id, arguments, template=data)
@@ -134,18 +133,18 @@ class FSZSQLMethod(SQL, FSObject):
 
         # do we need to do anything on reparse?
 
-
-    if Globals.DevelopmentMode:
+    if getConfiguration().debug_mode:
         # Provide an opportunity to update the properties.
         def __of__(self, parent):
             try:
                 self = ImplicitAcquisitionWrapper(self, parent)
                 self._updateFromFS()
                 return self
-            except:
-                logger.exception("Error during __of__")
+            except Exception:
+                logger.exception('Error during __of__')
                 raise
 
+
 InitializeClass(FSZSQLMethod)
 
 registerFileExtension('zsql', FSZSQLMethod)
