@@ -11,48 +11,61 @@
 #
 ##############################################################################
 """ Basic membership tool.
-
-$Id: MembershipTool.py 110577 2010-04-07 06:33:17Z jens $
 """
 
 import logging
 from warnings import warn
 
-from AccessControl.SecurityInfo import ClassSecurityInfo
+import six
+
+from AccessControl.class_init import InitializeClass
 from AccessControl.requestmethod import postonly
+from AccessControl.SecurityInfo import ClassSecurityInfo
+from AccessControl.SecurityManagement import getSecurityManager
 from AccessControl.User import nobody
 from Acquisition import aq_base
 from Acquisition import aq_inner
 from Acquisition import aq_parent
-from App.class_init import InitializeClass
 from App.Dialogs import MessageDialog
 from App.special_dtml import DTMLFile
 from OFS.Folder import Folder
 from Persistence import PersistentMapping
 from ZODB.POSException import ConflictError
 from zope.component import getUtility
-from zope.interface import implements
+from zope.component import queryUtility
+from zope.component.interfaces import IFactory
+from zope.globalrequest import getRequest
+from zope.interface import implementedBy
+from zope.interface import implementer
+from ZPublisher.BaseRequest import RequestContainer
+
+from .exceptions import AccessControl_Unauthorized
+from .exceptions import BadRequest
+from .interfaces import ICookieCrumbler
+from .interfaces import IMemberDataTool
+from .interfaces import IMembershipTool
+from .interfaces import IRegistrationTool
+from .interfaces import ISiteRoot
+from .interfaces import ITypesTool
+from .permissions import AccessContentsInformation
+from .permissions import ChangeLocalRoles
+from .permissions import ListPortalMembers
+from .permissions import ManagePortal
+from .permissions import ManageUsers
+from .permissions import SetOwnPassword
+from .permissions import View
+from .PortalFolder import PortalFolder
+from .utils import Message as _
+from .utils import UniqueObject
+from .utils import _checkPermission
+from .utils import _dtmldir
+from .utils import registerToolInterface
 
-from Products.CMFCore.exceptions import AccessControl_Unauthorized
-from Products.CMFCore.exceptions import BadRequest
-from Products.CMFCore.interfaces import IMembershipTool
-from Products.CMFCore.interfaces import ISiteRoot
-from Products.CMFCore.permissions import AccessContentsInformation
-from Products.CMFCore.permissions import ChangeLocalRoles
-from Products.CMFCore.permissions import ListPortalMembers
-from Products.CMFCore.permissions import ManagePortal
-from Products.CMFCore.permissions import ManageUsers
-from Products.CMFCore.permissions import SetOwnPassword
-from Products.CMFCore.permissions import View
-from Products.CMFCore.utils import _checkPermission
-from Products.CMFCore.utils import _dtmldir
-from Products.CMFCore.utils import _getAuthenticatedUser
-from Products.CMFCore.utils import getToolByName
-from Products.CMFCore.utils import UniqueObject
 
 logger = logging.getLogger('CMFCore.MembershipTool')
 
 
+@implementer(IMembershipTool)
 class MembershipTool(UniqueObject, Folder):
 
     """ This tool accesses member data through an acl_users object.
@@ -61,72 +74,67 @@ class MembershipTool(UniqueObject, Folder):
     different way.
     """
 
-    implements(IMembershipTool)
-
     id = 'portal_membership'
     meta_type = 'CMF Membership Tool'
+    zmi_icon = 'fa fa-users'
     memberareaCreationFlag = 1
+    _HOME_FOLDER_FACTORY_NAME = 'cmf.folder.home.bbb1'
 
     security = ClassSecurityInfo()
 
-    manage_options=( ({ 'label' : 'Configuration'
-                     , 'action' : 'manage_mapRoles'
-                     },) +
-                   ( { 'label' : 'Overview'
-                     , 'action' : 'manage_overview'
-                     },
-                   ) + Folder.manage_options)
+    manage_options = (
+        ({'label': 'Configuration', 'action': 'manage_mapRoles'},
+         {'label': 'Overview', 'action': 'manage_overview'}) +
+        Folder.manage_options)
 
     #
     #   ZMI methods
     #
-    security.declareProtected(ManagePortal, 'manage_overview')
-    manage_overview = DTMLFile( 'explainMembershipTool', _dtmldir )
+    security.declareProtected(ManagePortal,  # NOQA: flake8: D001
+                              'manage_overview')
+    manage_overview = DTMLFile('explainMembershipTool', _dtmldir)
 
     #
     #   'portal_membership' interface methods
     #
-    security.declareProtected(ManagePortal, 'manage_mapRoles')
-    manage_mapRoles = DTMLFile('membershipRolemapping', _dtmldir )
+    security.declareProtected(ManagePortal,  # NOQA: flake8: D001
+                              'manage_mapRoles')
+    manage_mapRoles = DTMLFile('membershipRolemapping', _dtmldir)
 
-    security.declareProtected(SetOwnPassword, 'setPassword')
+    @security.protected(SetOwnPassword)
     @postonly
     def setPassword(self, password, domains=None, REQUEST=None):
-        '''Allows the authenticated member to set his/her own password.
-        '''
-        # XXX: this method violates the rules for tools/utilities:
-        # it depends on a non-utility tool
-        registration = getToolByName(self, 'portal_registration', None)
+        """Allows the authenticated member to set his/her own password.
+        """
         if not self.isAnonymousUser():
             member = self.getAuthenticatedMember()
-            if registration:
-                failMessage = registration.testPasswordValidity(password)
+            rtool = queryUtility(IRegistrationTool)
+            if rtool is not None:
+                failMessage = rtool.testPasswordValidity(password)
                 if failMessage is not None:
                     raise BadRequest(failMessage)
             member.setSecurityProfile(password=password, domains=domains)
         else:
             raise BadRequest('Not logged in.')
 
-    security.declarePublic('getAuthenticatedMember')
+    @security.public
     def getAuthenticatedMember(self):
-        '''
+        """
         Returns the currently authenticated member object
         or the Anonymous User.  Never returns None.
-        '''
-        u = _getAuthenticatedUser(self)
+        """
+        u = getSecurityManager().getUser()
         if u is None:
             u = nobody
         return self.wrapUser(u)
 
-    security.declarePrivate('wrapUser')
+    @security.private
     def wrapUser(self, u, wrap_anon=0):
         """ Set up the correct acquisition wrappers for a user object.
 
         Provides an opportunity for a portal_memberdata tool to retrieve and
         store member data independently of the user object.
         """
-        # XXX: this method violates the rules for tools/utilities:
-        # it depends on a non-utility tool
         b = getattr(u, 'aq_base', None)
         if b is None:
             # u isn't wrapped at all.  Wrap it in self.acl_users.
@@ -140,22 +148,22 @@ class MembershipTool(UniqueObject, Folder):
 
         # Apply any role mapping if we have it
         if hasattr(self, 'role_map'):
-            for portal_role in self.role_map.keys():
+            for portal_role in self.role_map:
                 if (self.role_map.get(portal_role) in u.roles and
                         portal_role not in u.roles):
                     u.roles.append(portal_role)
 
-        mdtool = getToolByName(self, 'portal_memberdata', None)
+        mdtool = queryUtility(IMemberDataTool)
         if mdtool is not None:
             try:
                 u = mdtool.wrapUser(u)
             except ConflictError:
                 raise
-            except:
-                logger.exception("Error during wrapUser")
+            except Exception:
+                logger.exception('Error during wrapUser')
         return u
 
-    security.declareProtected(ManagePortal, 'getPortalRoles')
+    @security.protected(ManagePortal)
     def getPortalRoles(self):
         """
         Return all local roles defined by the portal itself,
@@ -163,7 +171,7 @@ class MembershipTool(UniqueObject, Folder):
         by the portal object
         """
         parent = self.aq_inner.aq_parent
-        roles = list( parent.userdefined_roles() )
+        roles = list(parent.userdefined_roles())
 
         # This is *not* a local role in the portal but used by it
         roles.append('Manager')
@@ -171,14 +179,15 @@ class MembershipTool(UniqueObject, Folder):
 
         return roles
 
-    security.declareProtected(ManagePortal, 'setRoleMapping')
+    @security.protected(ManagePortal)
     @postonly
     def setRoleMapping(self, portal_role, userfolder_role, REQUEST=None):
         """
         set the mapping of roles between roles understood by
         the portal and roles coming from outside user sources
         """
-        if not hasattr(self, 'role_map'): self.role_map = PersistentMapping()
+        if not hasattr(self, 'role_map'):
+            self.role_map = PersistentMapping()
 
         if len(userfolder_role) < 1:
             del self.role_map[portal_role]
@@ -186,11 +195,11 @@ class MembershipTool(UniqueObject, Folder):
             self.role_map[portal_role] = userfolder_role
 
         return MessageDialog(
-               title  ='Mapping updated',
+               title='Mapping updated',
                message='The Role mappings have been updated',
-               action ='manage_mapRoles')
+               action='manage_mapRoles')
 
-    security.declareProtected(ManagePortal, 'getMappedRole')
+    @security.protected(ManagePortal)
     def getMappedRole(self, portal_role):
         """
         returns a role name if the portal role is mapped to
@@ -201,15 +210,18 @@ class MembershipTool(UniqueObject, Folder):
         else:
             return ''
 
-    security.declarePublic('getMembersFolder')
+    @security.public
     def getMembersFolder(self):
         """ Get the members folder object.
         """
-        parent = aq_parent( aq_inner(self) )
-        members = getattr(parent, 'Members', None)
-        return members
+        parent = aq_parent(aq_inner(self))
+        members_folder = getattr(parent, 'Members', None)
+        if members_folder is None:
+            return None
+        request_container = RequestContainer(REQUEST=getRequest())
+        return members_folder.__of__(request_container)
 
-    security.declareProtected(ManagePortal, 'getMemberareaCreationFlag')
+    @security.protected(ManagePortal)
     def getMemberareaCreationFlag(self):
         """
         Returns the flag indicating whether the membership tool
@@ -219,7 +231,7 @@ class MembershipTool(UniqueObject, Folder):
         """
         return self.memberareaCreationFlag
 
-    security.declareProtected(ManagePortal, 'setMemberareaCreationFlag')
+    @security.protected(ManagePortal)
     def setMemberareaCreationFlag(self):
         """
         sets the flag indicating whether the membership tool
@@ -236,11 +248,11 @@ class MembershipTool(UniqueObject, Folder):
             self.memberareaCreationFlag = 0
 
         return MessageDialog(
-               title  ='Member area creation flag changed',
+               title='Member area creation flag changed',
                message='Member area creation flag has been updated',
-               action ='manage_mapRoles')
+               action='manage_mapRoles')
 
-    security.declarePublic('createMemberArea')
+    @security.public
     def createMemberArea(self, member_id=''):
         """ Create a member area for 'member_id' or authenticated user.
         """
@@ -251,44 +263,39 @@ class MembershipTool(UniqueObject, Folder):
             return None
         if self.isAnonymousUser():
             return None
-        # Note: We can't use getAuthenticatedMember() and getMemberById()
-        # because they might be wrapped by MemberDataTool.
-        user = _getAuthenticatedUser(self)
-        user_id = user.getId()
-        if member_id in ('', user_id):
-            member = user
-            member_id = user_id
-        else:
-            if _checkPermission(ManageUsers, self):
-                uf = self._huntUserFolder(member_id, self)
-                if uf:
-                    member = uf.getUserById(member_id).__of__(uf)
-                else:
-                    raise ValueError('Member %s does not exist' % member_id)
-            else:
+        if member_id:
+            if not self.isMemberAccessAllowed(member_id):
+                return None
+            member = self.getMemberById(member_id)
+            if member is None:
                 return None
-        if hasattr( aq_base(members), member_id ):
-            return None
         else:
-            f_title = "%s's Home" % member_id
-            members.manage_addPortalFolder( id=member_id, title=f_title )
-            f=getattr(members, member_id)
+            member = self.getAuthenticatedMember()
+            member_id = member.getId()
+        if hasattr(aq_base(members), member_id):
+            return None
 
-            f.manage_permission(View,
-                                ['Owner','Manager','Reviewer'], 0)
-            f.manage_permission(AccessContentsInformation,
-                                ['Owner','Manager','Reviewer'], 0)
+        factory_name = self._HOME_FOLDER_FACTORY_NAME
+        portal_type_name = 'Folder'
+        ttool = queryUtility(ITypesTool)
+        if ttool is not None:
+            portal_type = ttool.getTypeInfo('Home Folder')
+            if portal_type is not None:
+                factory_name = portal_type.factory
+                portal_type_name = portal_type.getId()
 
-            # Grant Ownership and Owner role to Member
-            f.changeOwnership(member)
-            f.__ac_local_roles__ = None
-            f.manage_setLocalRoles(member_id, ['Owner'])
+        factory = getUtility(IFactory, factory_name)
+        obj = factory(id=member_id)
+        obj._setPortalTypeName(portal_type_name)
+        members._setObject(member_id, obj)
+        f = members._getOb(member_id)
+        f.changeOwnership(member)
         return f
 
-    security.declarePublic('createMemberarea')
+    security.declarePublic('createMemberarea')  # NOQA: flake8: D001
     createMemberarea = createMemberArea
 
-    security.declareProtected(ManageUsers, 'deleteMemberArea')
+    @security.protected(ManageUsers)
     @postonly
     def deleteMemberArea(self, member_id, REQUEST=None):
         """ Delete member area of member specified by member_id.
@@ -296,65 +303,66 @@ class MembershipTool(UniqueObject, Folder):
         members = self.getMembersFolder()
         if not members:
             return 0
-        if hasattr( aq_base(members), member_id ):
+        if hasattr(aq_base(members), member_id):
             members.manage_delObjects(member_id)
             return 1
         else:
             return 0
 
-    security.declarePublic('isAnonymousUser')
+    @security.public
     def isAnonymousUser(self):
-        '''
+        """
         Returns 1 if the user is not logged in.
-        '''
-        u = _getAuthenticatedUser(self)
+        """
+        u = getSecurityManager().getUser()
         if u is None or u.getUserName() == 'Anonymous User':
             return 1
         return 0
 
-    security.declarePublic('checkPermission')
+    @security.public
     def checkPermission(self, permissionName, object, subobjectName=None):
-        '''
+        """
         Checks whether the current user has the given permission on
         the given object or subobject.
-        '''
+        """
         if subobjectName is not None:
             object = getattr(object, subobjectName)
         return _checkPermission(permissionName, object)
 
-    security.declarePublic('credentialsChanged')
+    @security.protected(ManageUsers)
+    def isMemberAccessAllowed(self, member_id):
+        """Check if the authenticated user is this member or an user manager.
+        """
+        sm = getSecurityManager()
+        user = sm.getUser()
+        if user is None:
+            return False
+        if member_id == user.getId():
+            return True
+        return sm.checkPermission(ManageUsers, self)
+
+    @security.public
     def credentialsChanged(self, password, REQUEST=None):
-        '''
+        """
         Notifies the authentication mechanism that this user has changed
         passwords.  This can be used to update the authentication cookie.
         Note that this call should *not* cause any change at all to user
         databases.
-        '''
-        # XXX: this method violates the rules for tools/utilities:
-        # it depends on self.REQUEST
-        if REQUEST is None:
-            REQUEST = self.REQUEST
-            warn("credentialsChanged should be called with 'REQUEST' as "
-                 "second argument. The BBB code will be removed in CMF 2.3.",
-                 DeprecationWarning, stacklevel=2)
-
+        """
         if not self.isAnonymousUser():
-            acl_users = self.acl_users
-            user = _getAuthenticatedUser(self)
+            user = getSecurityManager().getUser()
             name = user.getUserName()
             # this really does need to be the user name, and not the user id,
             # because we're dealing with authentication credentials
-            p = getattr(REQUEST, '_credentials_changed_path', None)
-            if p is not None:
-                # Use an interface provided by CookieCrumbler.
-                change = self.restrictedTraverse(p)
-                change(user, name, password)
+            cctool = queryUtility(ICookieCrumbler)
+            if cctool is not None:
+                cctool.credentialsChanged(user, name, password, REQUEST)
 
-    security.declareProtected(ManageUsers, 'getMemberById')
+    @security.protected(ManageUsers)
     def getMemberById(self, id):
-        '''
+        """
         Returns the given member.
-        '''
+        """
         user = self._huntUser(id, self)
         if user is not None:
             user = self.wrapUser(user)
@@ -380,7 +388,7 @@ class MembershipTool(UniqueObject, Folder):
         """
         uf = self._huntUserFolder(member_id, context)
         if uf is not None:
-            return uf.getUserById(member_id)
+            return uf.getUserById(member_id).__of__(uf)
 
     def __getPUS(self):
         """ Retrieve the nearest user folder
@@ -390,31 +398,30 @@ class MembershipTool(UniqueObject, Folder):
              stacklevel=2)
         return self.acl_users
 
-    security.declareProtected(ManageUsers, 'listMemberIds')
+    @security.protected(ManageUsers)
     def listMemberIds(self):
-        '''Lists the ids of all members.  This may eventually be
+        """Lists the ids of all members.  This may eventually be
         replaced with a set of methods for querying pieces of the
         list rather than the entire list at once.
-        '''
+        """
         user_folder = self.acl_users
-        return [ x.getId() for x in user_folder.getUsers() ]
+        return [x.getId() for x in user_folder.getUsers()]
 
-    security.declareProtected(ManageUsers, 'listMembers')
+    @security.protected(ManageUsers)
     def listMembers(self):
-        '''Gets the list of all members.
-        '''
-        return map(self.wrapUser, self.acl_users.getUsers())
+        """Gets the list of all members.
+        """
+        return list(map(self.wrapUser, self.acl_users.getUsers()))
 
-    security.declareProtected(ListPortalMembers, 'searchMembers')
-    def searchMembers( self, search_param, search_term ):
+    @security.protected(ListPortalMembers)
+    def searchMembers(self, search_param, search_term):
         """ Search the membership """
-        # XXX: this method violates the rules for tools/utilities:
-        # it depends on a non-utility tool
-        md = getToolByName( self, 'portal_memberdata' )
+        mdtool = queryUtility(IMemberDataTool)
+        if mdtool is not None:
+            return mdtool.searchMemberData(search_param, search_term)
+        return None
 
-        return md.searchMemberData( search_param, search_term )
-
-    security.declareProtected(View, 'getCandidateLocalRoles')
+    @security.protected(View)
     def getCandidateLocalRoles(self, obj):
         """ What local roles can I assign?
         """
@@ -423,32 +430,31 @@ class MembershipTool(UniqueObject, Folder):
         if _checkPermission(ManageUsers, obj):
             local_roles = self.getPortalRoles()
             if 'Manager' not in member_roles:
-                 local_roles.remove('Manager')
+                local_roles.remove('Manager')
         else:
-            local_roles = [ role for role in member_roles
-                            if role not in ('Member', 'Authenticated') ]
-        local_roles.sort()
-        return tuple(local_roles)
+            local_roles = [role for role in member_roles
+                           if role not in ('Member', 'Authenticated')]
+        return tuple(sorted(local_roles))
 
-    security.declareProtected(View, 'setLocalRoles')
+    @security.protected(View)
     @postonly
     def setLocalRoles(self, obj, member_ids, member_role, reindex=1,
                       REQUEST=None):
         """ Add local roles on an item.
         """
-        if ( _checkPermission(ChangeLocalRoles, obj)
-             and member_role in self.getCandidateLocalRoles(obj) ):
+        if _checkPermission(ChangeLocalRoles, obj) and \
+           member_role in self.getCandidateLocalRoles(obj):
             for member_id in member_ids:
-                roles = list(obj.get_local_roles_for_userid( userid=member_id ))
+                roles = list(obj.get_local_roles_for_userid(userid=member_id))
 
                 if member_role not in roles:
-                    roles.append( member_role )
-                    obj.manage_setLocalRoles( member_id, roles )
+                    roles.append(member_role)
+                    obj.manage_setLocalRoles(member_id, roles)
 
         if reindex and hasattr(aq_base(obj), 'reindexObjectSecurity'):
             obj.reindexObjectSecurity()
 
-    security.declareProtected(View, 'deleteLocalRoles')
+    @security.protected(View)
     @postonly
     def deleteLocalRoles(self, obj, member_ids, reindex=1, recursive=0,
                          REQUEST=None):
@@ -460,7 +466,7 @@ class MembershipTool(UniqueObject, Folder):
                     obj.manage_delLocalRoles(userids=member_ids)
                     break
 
-        if recursive and hasattr( aq_base(obj), 'contentValues' ):
+        if recursive and hasattr(aq_base(obj), 'contentValues'):
             for subobj in obj.contentValues():
                 self.deleteLocalRoles(subobj, member_ids, 0, 1)
 
@@ -468,30 +474,27 @@ class MembershipTool(UniqueObject, Folder):
             # reindexObjectSecurity is always recursive
             obj.reindexObjectSecurity()
 
-    security.declarePrivate('addMember')
+    @security.private
     def addMember(self, id, password, roles, domains, properties=None):
-        '''Adds a new member to the user folder.  Security checks will have
+        """Adds a new member to the user folder.  Security checks will have
         already been performed.  Called by portal_registration.
-        '''
+        """
         self.acl_users._doAddUser(id, password, roles, domains)
 
         if properties is not None:
             member = self.getMemberById(id)
             member.setMemberProperties(properties)
 
-    security.declareProtected(ManageUsers, 'deleteMembers')
+    @security.protected(ManageUsers)
     @postonly
     def deleteMembers(self, member_ids, delete_memberareas=1,
                       delete_localroles=1, REQUEST=None):
         """ Delete members specified by member_ids.
         """
-        # XXX: this method violates the rules for tools/utilities:
-        # it depends on a non-utility tool
-
         # Delete members in acl_users.
         acl_users = self.acl_users
         if _checkPermission(ManageUsers, acl_users):
-            if isinstance(member_ids, basestring):
+            if isinstance(member_ids, six.string_types):
                 member_ids = (member_ids,)
             member_ids = list(member_ids)
             for member_id in member_ids[:]:
@@ -501,13 +504,14 @@ class MembershipTool(UniqueObject, Folder):
                 acl_users.userFolderDelUsers(member_ids)
             except (AttributeError, NotImplementedError):
                 raise NotImplementedError('The underlying User Folder '
-                                         'doesn\'t support deleting members.')
+                                          "doesn't support deleting members.")
         else:
-            raise AccessControl_Unauthorized('You need the \'Manage users\' '
-                                 'permission for the underlying User Folder.')
+            raise AccessControl_Unauthorized("You need the 'Manage users' "
+                                             'permission for the underlying '
+                                             'User Folder.')
 
         # Delete member data in portal_memberdata.
-        mdtool = getToolByName(self, 'portal_memberdata', None)
+        mdtool = queryUtility(IMemberDataTool)
         if mdtool is not None:
             for member_id in member_ids:
                 mdtool.deleteMemberData(member_id)
@@ -515,16 +519,16 @@ class MembershipTool(UniqueObject, Folder):
         # Delete members' home folders including all content items.
         if delete_memberareas:
             for member_id in member_ids:
-                 self.deleteMemberArea(member_id)
+                self.deleteMemberArea(member_id)
 
         # Delete members' local roles.
         if delete_localroles:
-            self.deleteLocalRoles( getUtility(ISiteRoot), member_ids,
-                                   reindex=1, recursive=1 )
+            self.deleteLocalRoles(getUtility(ISiteRoot), member_ids,
+                                  reindex=1, recursive=1)
 
         return tuple(member_ids)
 
-    security.declarePublic('getHomeFolder')
+    @security.public
     def getHomeFolder(self, id=None, verifyPermission=0):
         """Returns a member's home folder object or None.
         Set verifyPermission to 1 to return None when the user
@@ -532,7 +536,7 @@ class MembershipTool(UniqueObject, Folder):
         """
         return None
 
-    security.declarePublic('getHomeUrl')
+    @security.public
     def getHomeUrl(self, id=None, verifyPermission=0):
         """Returns the URL to a member's home folder or None.
         Set verifyPermission to 1 to return None when the user
@@ -540,4 +544,47 @@ class MembershipTool(UniqueObject, Folder):
         """
         return None
 
+
 InitializeClass(MembershipTool)
+registerToolInterface('portal_membership', IMembershipTool)
+
+
+@implementer(IFactory)
+class HomeFolderFactoryBase(object):
+
+    """Creates a home folder.
+    """
+
+    title = _(u'Home Folder')
+    description = _(u'A home folder for portal members.')
+
+    def __call__(self, id, title=None, *args, **kw):
+        if title is None:
+            title = "{0}'s Home".format(id)
+        item = PortalFolder(id, title, *args, **kw)
+        item.manage_setLocalRoles(id, ['Owner'])
+        return item
+
+    def getInterfaces(self):
+        return implementedBy(PortalFolder)
+
+
+class _BBBHomeFolderFactory(HomeFolderFactoryBase):
+
+    """Creates a home folder.
+    """
+
+    description = _(u'Classic CMFCore home folder for portal members.')
+
+    def __call__(self, id, title=None, *args, **kw):
+        item = super(_BBBHomeFolderFactory,
+                     self).__call__(id, title=title, *args, **kw)
+
+        item.manage_permission(View,
+                               ['Owner', 'Manager', 'Reviewer'], 0)
+        item.manage_permission(AccessContentsInformation,
+                               ['Owner', 'Manager', 'Reviewer'], 0)
+        return item
+
+
+BBBHomeFolderFactory = _BBBHomeFolderFactory()
