@@ -11,20 +11,18 @@
 #
 ##############################################################################
 """TypeInformation browser views.
-
-$Id: typeinfo.py 110577 2010-04-07 06:33:17Z jens $
 """
 
 from xml.dom.minidom import parseString
 
-from zope.component import queryMultiAdapter
-from zope.component import queryUtility
-
-from Products.CMFCore.TypesTool import FactoryTypeInformation
-from Products.CMFCore.TypesTool import ScriptableTypeInformation
 from Products.GenericSetup.browser.utils import AddWithPresettingsViewBase
 from Products.GenericSetup.interfaces import IBody
 from Products.GenericSetup.interfaces import ISetupTool
+from zope.component import queryMultiAdapter
+from zope.component import queryUtility
+
+from ..TypesTool import FactoryTypeInformation
+from ..TypesTool import ScriptableTypeInformation
 
 
 class FactoryTypeInformationAddView(AddWithPresettingsViewBase):
@@ -62,10 +60,9 @@ class FactoryTypeInformationAddView(AddWithPresettingsViewBase):
                     obj_ids.append(obj_id)
                 if not obj_ids:
                     continue
-                obj_ids.sort()
                 profiles.append({'id': info['id'],
                                  'title': info['title'],
-                                 'obj_ids': tuple(obj_ids)})
+                                 'obj_ids': tuple(sorted(obj_ids))})
         return tuple(profiles)
 
     def _initSettings(self, obj, profile_id, obj_path):
