@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2005 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,21 +11,20 @@
 #
 ##############################################################################
 """Catalog tool setup handlers.
-
-$Id: catalog.py 107359 2009-12-30 15:33:55Z jens $
 """
 
 from Products.GenericSetup.utils import exportObjects
 from Products.GenericSetup.utils import importObjects
+from zope.component import getSiteManager
 
-from Products.CMFCore.utils import getToolByName
+from ..interfaces import ICatalogTool
 
 
 def importCatalogTool(context):
     """Import catalog tool.
     """
-    site = context.getSite()
-    tool = getToolByName(site, 'portal_catalog', None)
+    sm = getSiteManager(context.getSite())
+    tool = sm.queryUtility(ICatalogTool)
     if tool is None:
         logger = context.getLogger('catalog')
         logger.debug('Nothing to import.')
@@ -33,11 +32,12 @@ def importCatalogTool(context):
 
     importObjects(tool, '', context)
 
+
 def exportCatalogTool(context):
     """Export catalog tool.
     """
-    site = context.getSite()
-    tool = getToolByName(site, 'portal_catalog', None)
+    sm = getSiteManager(context.getSite())
+    tool = sm.queryUtility(ICatalogTool)
     if tool is None:
         logger = context.getLogger('catalog')
         logger.debug('Nothing to export.')
