@@ -11,21 +11,28 @@
 #
 ##############################################################################
 """Filesystem exporter / importer adapters.
-
-$Id: content.py 119567 2011-01-13 15:56:12Z gotcha $
 """
 
+import itertools
+import operator
 from csv import reader
 from csv import writer
-from ConfigParser import ConfigParser
-from StringIO import StringIO
 
-from zope.interface import implements
+import six
+from six import StringIO
+from six.moves.configparser import ConfigParser
 
+from DateTime import DateTime
+from Products.GenericSetup.content import DAVAwareFileAdapter
+from Products.GenericSetup.content import _globtest
 from Products.GenericSetup.interfaces import IFilesystemExporter
 from Products.GenericSetup.interfaces import IFilesystemImporter
-from Products.GenericSetup.content import _globtest
-from Products.CMFCore.utils import getToolByName
+from zope.component import getUtility
+from zope.interface import implementer
+from zope.publisher.interfaces.http import MethodNotAllowed
+
+from ..interfaces import ITypesTool
+
 
 #
 #   setup_tool handlers
@@ -33,23 +40,38 @@ from Products.CMFCore.utils import getToolByName
 def exportSiteStructure(context):
     IFilesystemExporter(context.getSite()).export(context, 'structure', True)
 
+
 def importSiteStructure(context):
     IFilesystemImporter(context.getSite()).import_(context, 'structure', True)
 
 
 def encode_if_needed(text, encoding):
-    if isinstance(text, unicode):
-        result = text.encode(encoding)
+    if six.PY2:
+        if isinstance(text, six.text_type):
+            text = text.encode(encoding)
     else:
+        if not isinstance(text, six.text_type):
+            text = text.decode(encoding)
         # no need to encode;
         # let's avoid double encoding in case of encoded string
-        result = text
-    return result
+    return text
+
+
+class FolderishDAVAwareFileAdapter(DAVAwareFileAdapter):
+    """ A version of the DAVAwareFileAdapter that uses .properties to store
+    the DAV result, rather than its own id. For use in serialising folderish
+    objects. """
+
+    def _getFileName(self):
+        """ Return the name under which our file data is stored.
+        """
+        return '.properties'
 
 
 #
 #   Filesystem export/import adapters
 #
+@implementer(IFilesystemExporter, IFilesystemImporter)
 class StructureFolderWalkingAdapter(object):
     """ Tree-walking exporter for "folderish" types.
 
@@ -78,35 +100,65 @@ class StructureFolderWalkingAdapter(object):
     and thus will not be recreated during the import process.
     """
 
-    implements(IFilesystemExporter, IFilesystemImporter)
-
     def __init__(self, context):
         self.context = context
+        self._encoding = self.context.getProperty('default_charset', 'utf-8')
+
+    def read_data_file(self, import_context, datafile, subdir):
+        out = import_context.readDataFile(datafile, subdir)
+        if not out:
+            return out
+        return encode_if_needed(out, self._encoding)
 
     def export(self, export_context, subdir, root=False):
         """ See IFilesystemExporter.
         """
-        self._encoding = self.context.getProperty('default_charset', 'utf-8')
+        content_type = 'text/comma-separated-values'
 
         # Enumerate exportable children
         exportable = self.context.contentItems()
         exportable = [x + (IFilesystemExporter(x, None),) for x in exportable]
         exportable = [x for x in exportable if x[1] is not None]
 
-        stream = StringIO()
-        csv_writer = writer(stream)
-
-        for object_id, object, ignored in exportable:
-            csv_writer.writerow((object_id, object.getPortalTypeName()))
+        objects_stream = StringIO()
+        objects_csv_writer = writer(objects_stream)
+        wf_stream = StringIO()
+        wf_csv_writer = writer(wf_stream)
 
         if not root:
             subdir = '%s/%s' % (subdir, self.context.getId())
 
+        try:
+            wft = self.context.portal_workflow
+        except AttributeError:
+            # No workflow tool to export definitions from
+            for object_id, object, ignored in exportable:
+                objects_csv_writer.writerow((object_id,
+                                             object.getPortalTypeName()))
+        else:
+            for object_id, object, ignored in exportable:
+                objects_csv_writer.writerow((object_id,
+                                             object.getPortalTypeName()))
+
+                workflows = wft.getWorkflowsFor(object)
+                for workflow in workflows:
+                    workflow_id = workflow.getId()
+                    state_variable = workflow.state_var
+                    state_record = wft.getStatusOf(workflow_id, object)
+                    if state_record is None:
+                        continue
+                    state = state_record.get(state_variable)
+                    wf_csv_writer.writerow((object_id, workflow_id, state))
+
+            export_context.writeDataFile('.workflow_states',
+                                         text=wf_stream.getvalue(),
+                                         content_type=content_type,
+                                         subdir=subdir)
+
         export_context.writeDataFile('.objects',
-                                     text=stream.getvalue(),
-                                     content_type='text/comma-separated-values',
-                                     subdir=subdir,
-                                    )
+                                     text=objects_stream.getvalue(),
+                                     content_type=content_type,
+                                     subdir=subdir)
 
         parser = ConfigParser()
 
@@ -121,11 +173,14 @@ class StructureFolderWalkingAdapter(object):
         stream = StringIO()
         parser.write(stream)
 
-        export_context.writeDataFile('.properties',
-                                    text=stream.getvalue(),
-                                    content_type='text/plain',
-                                    subdir=subdir,
-                                    )
+        try:
+            FolderishDAVAwareFileAdapter(self.context).export(export_context,
+                                                              subdir, root)
+        except (AttributeError, MethodNotAllowed):
+            export_context.writeDataFile('.properties',
+                                         text=stream.getvalue(),
+                                         content_type='text/plain',
+                                         subdir=subdir)
 
         for id, object in self.context.objectItems():
 
@@ -141,29 +196,32 @@ class StructureFolderWalkingAdapter(object):
         if not root:
             subdir = '%s/%s' % (subdir, context.getId())
 
-        objects = import_context.readDataFile('.objects', subdir)
+        objects = self.read_data_file(import_context, '.objects', subdir)
+        workflow_states = self.read_data_file(import_context,
+                                              '.workflow_states', subdir)
         if objects is None:
             return
 
         dialect = 'excel'
-        stream = StringIO(objects)
+        object_stream = StringIO(objects)
+        wf_stream = StringIO(workflow_states)
 
-        rowiter = reader(stream, dialect)
-        ours = filter(None, tuple(rowiter))
+        object_rowiter = reader(object_stream, dialect)
+        ours = [_f for _f in tuple(object_rowiter) if _f]
         our_ids = set([item[0] for item in ours])
 
         prior = set(context.contentIds())
 
-        preserve = import_context.readDataFile('.preserve', subdir)
+        preserve = self.read_data_file(import_context, '.preserve', subdir)
         if not preserve:
             preserve = set()
         else:
             preservable = prior.intersection(our_ids)
             preserve = set(_globtest(preserve, preservable))
 
-        delete = import_context.readDataFile('.delete', subdir)
+        delete = self.read_data_file(import_context, '.delete', subdir)
         if not delete:
-            delete= set()
+            delete = set()
         else:
             deletable = prior.difference(our_ids)
             delete = set(_globtest(delete, deletable))
@@ -192,26 +250,69 @@ class StructureFolderWalkingAdapter(object):
 
             IFilesystemImporter(wrapped).import_(import_context, subdir)
 
+        if workflow_states is not None:
+            existing = context.objectIds()
+            wft = context.portal_workflow
+            wf_rowiter = reader(wf_stream, dialect)
+            wf_by_objectid = itertools.groupby(wf_rowiter,
+                                               operator.itemgetter(0))
+
+            for object_id, states in wf_by_objectid:
+                if object_id not in existing:
+                    logger = import_context.getLogger('SFWA')
+                    logger.warning("Couldn't set workflow for object %s/%s, it"
+                                   " doesn't exist" % (context.id, object_id))
+                    continue
+
+                object = context[object_id]
+                for object_id, workflow_id, state_id in states:
+                    workflow = wft.getWorkflowById(workflow_id)
+                    state_variable = workflow.state_var
+                    wf_state = {'action': None,
+                                'actor': None,
+                                'comments': 'Setting state to %s' % state_id,
+                                state_variable: state_id,
+                                'time': DateTime()}
+
+                    wft.setStatusOf(workflow_id, object, wf_state)
+                    workflow.updateRoleMappingsFor(object)
+
+                object.reindexObject()
+
     def _makeInstance(self, id, portal_type, subdir, import_context):
 
         context = self.context
-        properties = import_context.readDataFile('.properties',
-                                                 '%s/%s' % (subdir, id))
-        tool = getToolByName(context, 'portal_types')
+        subdir = '%s/%s' % (subdir, id)
+        properties = self.read_data_file(import_context, '.properties',
+                                         subdir)
+        tool = getUtility(ITypesTool)
 
         try:
             tool.constructContent(portal_type, context, id)
-        except ValueError: # invalid type
+        except ValueError:  # invalid type
             return None
 
         content = context._getOb(id)
 
         if properties is not None:
+            if '[DEFAULT]' not in properties:
+                try:
+                    adp = FolderishDAVAwareFileAdapter
+                    adp(content).import_(import_context, subdir)
+                    return content
+                except (AttributeError, MethodNotAllowed):
+                    # Fall through to old implemenatation below
+                    pass
+
             lines = properties.splitlines()
 
             stream = StringIO('\n'.join(lines))
-            parser = ConfigParser(defaults={'title': '', 'description': 'NONE'})
-            parser.readfp(stream)
+            parser = ConfigParser(defaults={'title': '',
+                                            'description': 'NONE'})
+            try:
+                parser.read_file(stream)
+            except AttributeError:  # Python 2
+                parser.readfp(stream)
 
             title = parser.get('DEFAULT', 'title')
             description = parser.get('DEFAULT', 'description')
