@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2005 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,20 +11,17 @@
 #
 ##############################################################################
 """Cookie crumbler xml adapters and setup handlers.
-
-$Id: cookieauth.py 107359 2009-12-30 15:33:55Z jens $
 """
 
-from zope.component import adapts
-
 from Products.GenericSetup.interfaces import ISetupEnviron
-from Products.GenericSetup.utils import exportObjects
-from Products.GenericSetup.utils import importObjects
 from Products.GenericSetup.utils import PropertyManagerHelpers
 from Products.GenericSetup.utils import XMLAdapterBase
+from Products.GenericSetup.utils import exportObjects
+from Products.GenericSetup.utils import importObjects
+from zope.component import adapts
+from zope.component import getSiteManager
 
-from Products.CMFCore.interfaces import ICookieCrumbler
-from Products.CMFCore.utils import getToolByName
+from ..interfaces import ICookieCrumbler
 
 
 class CookieCrumblerXMLAdapter(XMLAdapterBase, PropertyManagerHelpers):
@@ -53,16 +50,29 @@ class CookieCrumblerXMLAdapter(XMLAdapterBase, PropertyManagerHelpers):
         if self.environ.shouldPurge():
             self._purgeProperties()
 
+        self._migrateProperties(node)
         self._initProperties(node)
 
         self._logger.info('Cookie crumbler imported.')
 
+    def _migrateProperties(self, node):
+        # BBB: for CMF 2.2 settings
+        for child in node.childNodes:
+            if child.nodeName != 'property':
+                continue
+            if child.getAttribute('name') not in ('auto_login_page',
+                                                  'unauth_page',
+                                                  'logout_page'):
+                continue
+            node.removeChild(child)
+            child.unlink()
+
 
 def importCookieCrumbler(context):
     """Import cookie crumbler settings from an XML file.
     """
-    site = context.getSite()
-    tool = getToolByName(site, 'cookie_authentication', None)
+    sm = getSiteManager(context.getSite())
+    tool = sm.queryUtility(ICookieCrumbler)
     if tool is None:
         logger = context.getLogger('cookies')
         logger.debug('Nothing to import.')
@@ -70,11 +80,12 @@ def importCookieCrumbler(context):
 
     importObjects(tool, '', context)
 
+
 def exportCookieCrumbler(context):
     """Export cookie crumbler settings as an XML file.
     """
-    site = context.getSite()
-    tool = getToolByName(site, 'cookie_authentication', None)
+    sm = getSiteManager(context.getSite())
+    tool = sm.queryUtility(ICookieCrumbler)
     if tool is None:
         logger = context.getLogger('cookies')
         logger.debug('Nothing to export.')
