@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2005 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,24 +11,21 @@
 #
 ##############################################################################
 """Skins tool xml adapters and setup handlers.
-
-$Id: skins.py 107359 2009-12-30 15:33:55Z jens $
 """
 
 from Acquisition import aq_inner
 from Acquisition import aq_parent
-from zope.component import adapts
-
 from Products.GenericSetup.interfaces import ISetupEnviron
-from Products.GenericSetup.utils import exportObjects
-from Products.GenericSetup.utils import importObjects
 from Products.GenericSetup.utils import NodeAdapterBase
 from Products.GenericSetup.utils import ObjectManagerHelpers
 from Products.GenericSetup.utils import XMLAdapterBase
+from Products.GenericSetup.utils import exportObjects
+from Products.GenericSetup.utils import importObjects
+from zope.component import adapts
+from zope.component import getSiteManager
 
-from Products.CMFCore.interfaces import IDirectoryView
-from Products.CMFCore.interfaces import ISkinsTool
-from Products.CMFCore.utils import getToolByName
+from ..interfaces import IDirectoryView
+from ..interfaces import ISkinsTool
 
 
 class DirectoryViewNodeAdapter(NodeAdapterBase):
@@ -112,7 +109,9 @@ class SkinsToolXMLAdapter(XMLAdapterBase, ObjectManagerHelpers):
         for k, v in self.context.getSkinPaths():
             node = self._doc.createElement('skin-path')
             node.setAttribute('name', k)
-            for layer in [ l.strip() for l in v.split(',') if l.strip() ]:
+            for layer in [
+                    layer.strip()
+                    for layer in v.split(',') if layer.strip()]:
                 child = self._doc.createElement('layer')
                 child.setAttribute('name', layer)
                 node.appendChild(child)
@@ -152,7 +151,7 @@ class SkinsToolXMLAdapter(XMLAdapterBase, ObjectManagerHelpers):
                             if oldpath.index(layer) == 0:
                                 layernode.setAttribute('insert-before', '*')
                             else:
-                                pos = oldpath[oldpath.index(layer)-1]
+                                pos = oldpath[oldpath.index(layer) - 1]
                                 layernode.setAttribute('insert-after', pos)
                             child.insertBefore(layernode, newlayerstart)
                 path = self._updatePath(path, child)
@@ -168,7 +167,7 @@ class SkinsToolXMLAdapter(XMLAdapterBase, ObjectManagerHelpers):
             skinnable.setupCurrentSkin(request)
 
     def _updatePath(self, path, node):
-        path = [ name.strip() for name in path.split(',') if name.strip() ]
+        path = [name.strip() for name in path.split(',') if name.strip()]
 
         for child in node.childNodes:
             if child.nodeName != 'layer':
@@ -196,7 +195,7 @@ class SkinsToolXMLAdapter(XMLAdapterBase, ObjectManagerHelpers):
                 else:
                     try:
                         index = path.index(insert_after)
-                        path.insert(index+1, layer_name)
+                        path.insert(index + 1, layer_name)
                         continue
                     except ValueError:
                         pass
@@ -204,8 +203,7 @@ class SkinsToolXMLAdapter(XMLAdapterBase, ObjectManagerHelpers):
             if not child.hasAttribute('remove'):
                 path.append(layer_name)
 
-        return str( ','.join(path) )
-
+        return str(','.join(path))
 
     def _removeSkin(self, skin_name=None):
         """
@@ -213,14 +211,14 @@ class SkinsToolXMLAdapter(XMLAdapterBase, ObjectManagerHelpers):
         """
         skins = self.context.getSkinSelections()
         if skin_name in skins:
-            self.context.manage_skinLayers(chosen=[skin_name], del_skin=1, )
+            self.context.manage_skinLayers(chosen=[skin_name], del_skin=1)
 
 
 def importSkinsTool(context):
     """Import skins tool FSDirViews and skin paths from an XML file.
     """
-    site = context.getSite()
-    tool = getToolByName(site, 'portal_skins', None)
+    sm = getSiteManager(context.getSite())
+    tool = sm.queryUtility(ISkinsTool)
     if tool is None:
         logger = context.getLogger('skins')
         logger.debug('Nothing to import.')
@@ -228,11 +226,12 @@ def importSkinsTool(context):
 
     importObjects(tool, '', context)
 
+
 def exportSkinsTool(context):
     """Export skins tool FSDVs and skin paths as an XML file.
     """
-    site = context.getSite()
-    tool = getToolByName(site, 'portal_skins', None)
+    sm = getSiteManager(context.getSite())
+    tool = sm.queryUtility(ISkinsTool)
     if tool is None:
         logger = context.getLogger('skins')
         logger.debug('Nothing to export.')
