@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2005 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,30 +11,30 @@
 #
 ##############################################################################
 """Actions tool node adapter unit tests.
-
-$Id: test_actions.py 105897 2009-11-20 07:57:56Z yuppie $
 """
 
 import unittest
-import Testing
 
-from Acquisition import aq_parent
 from Acquisition import Implicit
+from Acquisition import aq_parent
 from OFS.OrderedFolder import OrderedFolder
-from zope.interface import implements
-
-from Products.CMFCore.ActionProviderBase import ActionProviderBase
-from Products.CMFCore.interfaces import IActionProvider
-from Products.CMFCore.interfaces import IActionsTool
-from Products.CMFCore.testing import ExportImportZCMLLayer
-from Products.CMFCore.tests.base.dummy import DummySite
 from Products.GenericSetup.testing import BodyAdapterTestCase
 from Products.GenericSetup.testing import NodeAdapterTestCase
 from Products.GenericSetup.tests.common import BaseRegistryTests
 from Products.GenericSetup.tests.common import DummyExportContext
 from Products.GenericSetup.tests.common import DummyImportContext
+from zope.component import getSiteManager
+from zope.interface import implementer
 
-_ACTION_XML = """\
+from ...ActionProviderBase import ActionProviderBase
+from ...interfaces import IActionProvider
+from ...interfaces import IActionsTool
+from ...interfaces import IMembershipTool
+from ...testing import ExportImportZCMLLayer
+from ...tests.base.dummy import DummySite
+
+
+_ACTION_XML = b"""\
 <object name="foo_action" meta_type="CMF Action">
  <property name="title">Foo</property>
  <property name="description"></property>
@@ -47,7 +47,7 @@ _ACTION_XML = """\
 </object>
 """
 
-_ACTIONCATEGORY_XML = """\
+_ACTIONCATEGORY_XML = b"""\
 <object name="foo_category" meta_type="CMF Action Category">
  <property name="title"></property>
  <object name="foo_action" meta_type="CMF Action">
@@ -63,8 +63,8 @@ _ACTIONCATEGORY_XML = """\
 </object>
 """
 
-_ACTIONSTOOL_BODY = """\
-<?xml version="1.0"?>
+_ACTIONSTOOL_BODY = b"""\
+<?xml version="1.0" encoding="utf-8"?>
 <object name="portal_actions" meta_type="CMF Actions Tool"
    xmlns:i18n="http://xml.zope.org/namespaces/i18n">
  <action-provider name="portal_actions"/>
@@ -84,7 +84,7 @@ _ACTIONSTOOL_BODY = """\
 </object>
 """
 
-_EMPTY_EXPORT = """\
+_EMPTY_EXPORT = b"""\
 <?xml version="1.0"?>
 <object name="portal_actions" meta_type="CMF Actions Tool"
    xmlns:i18n="http://xml.zope.org/namespaces/i18n">
@@ -92,7 +92,7 @@ _EMPTY_EXPORT = """\
 </object>
 """
 
-_OLD_EXPORT = """\
+_OLD_EXPORT = b"""\
 <?xml version="1.0"?>
 <object name="portal_actions" meta_type="CMF Actions Tool"
    xmlns:i18n="http://xml.zope.org/namespaces/i18n">
@@ -126,7 +126,7 @@ _OLD_EXPORT = """\
 """
 
 _NORMAL_EXPORT = """\
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="utf-8"?>
 <object name="portal_actions" meta_type="CMF Actions Tool"
    xmlns:i18n="http://xml.zope.org/namespaces/i18n">
  <action-provider name="portal_actions">
@@ -142,7 +142,7 @@ _NORMAL_EXPORT = """\
 </object>
 """
 
-_NEWSYTLE_EXPORT = """\
+_NEWSYTLE_EXPORT = b"""\
 <?xml version="1.0"?>
 <object name="portal_actions" meta_type="CMF Actions Tool"
    xmlns:i18n="http://xml.zope.org/namespaces/i18n">
@@ -217,9 +217,9 @@ _REMOVE_IMPORT = """\
 """
 
 
+@implementer(IActionProvider)
 class DummyTool(OrderedFolder, ActionProviderBase):
-
-    implements(IActionProvider)
+    pass
 
 
 class DummyUser(Implicit):
@@ -237,9 +237,9 @@ class DummyMembershipTool(DummyTool):
         return DummyUser().__of__(aq_parent(self))
 
 
+@implementer(IActionsTool)
 class DummyActionsTool(DummyTool):
 
-    implements(IActionsTool)
     id = 'portal_actions'
     meta_type = 'CMF Actions Tool'
 
@@ -253,7 +253,7 @@ class DummyActionsTool(DummyTool):
         return self._providers[:]
 
     def deleteActionProvider(self, provider_name):
-        self._providers = [ x for x in self._providers if x != provider_name ]
+        self._providers = [x for x in self._providers if x != provider_name]
 
 
 class ActionNodeAdapterTests(NodeAdapterTestCase, unittest.TestCase):
@@ -261,7 +261,7 @@ class ActionNodeAdapterTests(NodeAdapterTestCase, unittest.TestCase):
     layer = ExportImportZCMLLayer
 
     def _getTargetClass(self):
-        from Products.CMFCore.exportimport.actions import ActionNodeAdapter
+        from ..actions import ActionNodeAdapter
 
         return ActionNodeAdapter
 
@@ -287,7 +287,7 @@ class ActionNodeAdapterTests(NodeAdapterTestCase, unittest.TestCase):
         self.assertEqual(obj.visible, True)
 
     def setUp(self):
-        from Products.CMFCore.ActionInformation import Action
+        from ...ActionInformation import Action
 
         self._obj = Action('foo_action')
         self._XML = _ACTION_XML
@@ -298,13 +298,12 @@ class ActionCategoryNodeAdapterTests(NodeAdapterTestCase, unittest.TestCase):
     layer = ExportImportZCMLLayer
 
     def _getTargetClass(self):
-        from Products.CMFCore.exportimport.actions \
-                import ActionCategoryNodeAdapter
+        from ..actions import ActionCategoryNodeAdapter
 
         return ActionCategoryNodeAdapter
 
     def _populate(self, obj):
-        from Products.CMFCore.ActionInformation import Action
+        from ...ActionInformation import Action
 
         obj._setObject('foo_action', Action('foo_action'))
 
@@ -313,7 +312,7 @@ class ActionCategoryNodeAdapterTests(NodeAdapterTestCase, unittest.TestCase):
         self.assertEqual(obj.title, '')
 
     def setUp(self):
-        from Products.CMFCore.ActionInformation import ActionCategory
+        from ...ActionInformation import ActionCategory
 
         self._obj = ActionCategory('foo_category')
         self._XML = _ACTIONCATEGORY_XML
@@ -324,14 +323,13 @@ class ActionsToolXMLAdapterTests(BodyAdapterTestCase, unittest.TestCase):
     layer = ExportImportZCMLLayer
 
     def _getTargetClass(self):
-        from Products.CMFCore.exportimport.actions \
-                import ActionsToolXMLAdapter
+        from ..actions import ActionsToolXMLAdapter
 
         return ActionsToolXMLAdapter
 
     def _populate(self, obj):
-        from Products.CMFCore.ActionInformation import Action
-        from Products.CMFCore.ActionInformation import ActionCategory
+        from ...ActionInformation import Action
+        from ...ActionInformation import ActionCategory
 
         obj._setObject('foo_category', ActionCategory('foo_category'))
         obj.action_providers = ('portal_actions',)
@@ -345,23 +343,22 @@ class ActionsToolXMLAdapterTests(BodyAdapterTestCase, unittest.TestCase):
         self.assertEqual(obj.action_providers[0], 'portal_actions')
 
     def setUp(self):
-        from Products.CMFCore.ActionsTool import ActionsTool
+        from ...ActionsTool import ActionsTool
 
-        site = DummySite('site')
-        site._setObject('portal_actions', ActionsTool('portal_actions'))
-        self._obj = site.portal_actions
+        self._obj = ActionsTool('portal_actions')
         self._BODY = _ACTIONSTOOL_BODY
+        getSiteManager().registerUtility(self._obj, IActionsTool)
 
 
 class _ActionSetup(BaseRegistryTests):
 
     def _initSite(self, foo=2, bar=2):
-        self.root.site = DummySite('site')
-        site = self.root.site
-        site.portal_membership = DummyMembershipTool()
-
-        site.portal_actions = DummyActionsTool()
-        site.portal_actions.addActionProvider('portal_actions')
+        site = DummySite('site')
+        sm = getSiteManager()
+        sm.registerUtility(DummyMembershipTool(), IMembershipTool)
+        atool = DummyActionsTool()
+        atool.addActionProvider('portal_actions')
+        sm.registerUtility(atool, IActionsTool)
 
         if foo > 0:
             site.portal_foo = DummyTool()
@@ -374,7 +371,7 @@ class _ActionSetup(BaseRegistryTests):
                                       permission=(),
                                       category='dummy',
                                       visible=1)
-            site.portal_actions.addActionProvider('portal_foo')
+            atool.addActionProvider('portal_foo')
 
         if bar > 0:
             site.portal_bar = DummyTool()
@@ -387,9 +384,9 @@ class _ActionSetup(BaseRegistryTests):
                                       permission=('Manage portal',),
                                       category='dummy',
                                       visible=0)
-            site.portal_actions.addActionProvider('portal_bar')
+            atool.addActionProvider('portal_bar')
 
-        return site
+        return site, atool
 
 
 class exportActionProvidersTests(_ActionSetup):
@@ -397,32 +394,30 @@ class exportActionProvidersTests(_ActionSetup):
     layer = ExportImportZCMLLayer
 
     def test_unchanged(self):
-        from Products.CMFCore.exportimport.actions \
-                import exportActionProviders
+        from ..actions import exportActionProviders
 
-        site = self._initSite(0, 0)
+        site, _atool = self._initSite(0, 0)
         context = DummyExportContext(site)
         exportActionProviders(context)
 
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'actions.xml')
-        self._compareDOM(text, _EMPTY_EXPORT)
+        self._compareDOM(text.decode('utf8'), _EMPTY_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
     def test_normal(self):
-        from Products.CMFCore.exportimport.actions \
-                import exportActionProviders
+        from ..actions import exportActionProviders
 
-        site = self._initSite()
+        site, atool = self._initSite()
         # Set up an old action for added difficulty
-        site.portal_actions.addAction(id='baz',
-                                      name='Baz',
-                                      action='baz',
-                                      condition='python:1',
-                                      permission=(),
-                                      category='dummy',
-                                      visible=1)
+        atool.addAction(id='baz',
+                        name='Baz',
+                        action='baz',
+                        condition='python:1',
+                        permission=(),
+                        category='dummy',
+                        visible=1)
 
         context = DummyExportContext(site)
         exportActionProviders(context)
@@ -430,7 +425,7 @@ class exportActionProvidersTests(_ActionSetup):
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'actions.xml')
-        self._compareDOM(text, _NORMAL_EXPORT)
+        self._compareDOM(text.decode('utf-8'), _NORMAL_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
 
@@ -439,100 +434,91 @@ class importActionProvidersTests(_ActionSetup):
     layer = ExportImportZCMLLayer
 
     def test_empty_default_purge(self):
-        from Products.CMFCore.exportimport.actions \
-                import importActionProviders
+        from ..actions import importActionProviders
 
-        site = self._initSite(2, 0)
-        atool = site.portal_actions
+        site, atool = self._initSite(2, 0)
 
         self.assertEqual(len(atool.listActionProviders()), 2)
-        self.failUnless('portal_foo' in atool.listActionProviders())
-        self.failUnless('portal_actions' in atool.listActionProviders())
+        self.assertTrue('portal_foo' in atool.listActionProviders())
+        self.assertTrue('portal_actions' in atool.listActionProviders())
 
         context = DummyImportContext(site)
         context._files['actions.xml'] = _EMPTY_EXPORT
         importActionProviders(context)
 
         self.assertEqual(len(atool.listActionProviders()), 1)
-        self.failIf('portal_foo' in atool.listActionProviders())
-        self.failUnless('portal_actions' in atool.listActionProviders())
+        self.assertFalse('portal_foo' in atool.listActionProviders())
+        self.assertTrue('portal_actions' in atool.listActionProviders())
         self.assertEqual(len(atool.objectIds()), 0)
 
     def test_empty_explicit_purge(self):
-        from Products.CMFCore.exportimport.actions \
-                import importActionProviders
+        from ..actions import importActionProviders
 
-        site = self._initSite(2, 0)
-        atool = site.portal_actions
+        site, atool = self._initSite(2, 0)
 
         self.assertEqual(len(atool.listActionProviders()), 2)
-        self.failUnless('portal_foo' in atool.listActionProviders())
-        self.failUnless('portal_actions' in atool.listActionProviders())
+        self.assertTrue('portal_foo' in atool.listActionProviders())
+        self.assertTrue('portal_actions' in atool.listActionProviders())
 
         context = DummyImportContext(site, True)
         context._files['actions.xml'] = _EMPTY_EXPORT
         importActionProviders(context)
 
         self.assertEqual(len(atool.listActionProviders()), 1)
-        self.failIf('portal_foo' in atool.listActionProviders())
-        self.failUnless('portal_actions' in atool.listActionProviders())
+        self.assertFalse('portal_foo' in atool.listActionProviders())
+        self.assertTrue('portal_actions' in atool.listActionProviders())
         self.assertEqual(len(atool.objectIds()), 0)
 
     def test_empty_skip_purge(self):
-        from Products.CMFCore.exportimport.actions \
-                import importActionProviders
+        from ..actions import importActionProviders
 
-        site = self._initSite(2, 0)
-        atool = site.portal_actions
+        site, atool = self._initSite(2, 0)
 
         self.assertEqual(len(atool.listActionProviders()), 2)
-        self.failUnless('portal_foo' in atool.listActionProviders())
-        self.failUnless('portal_actions' in atool.listActionProviders())
+        self.assertTrue('portal_foo' in atool.listActionProviders())
+        self.assertTrue('portal_actions' in atool.listActionProviders())
 
         context = DummyImportContext(site, False)
         context._files['actions.xml'] = _EMPTY_EXPORT
         importActionProviders(context)
 
         self.assertEqual(len(atool.listActionProviders()), 2)
-        self.failUnless('portal_foo' in atool.listActionProviders())
-        self.failUnless('portal_actions' in atool.listActionProviders())
+        self.assertTrue('portal_foo' in atool.listActionProviders())
+        self.assertTrue('portal_actions' in atool.listActionProviders())
 
     def test_normal(self):
-        from Products.CMFCore.exportimport.actions \
-                import exportActionProviders
-        from Products.CMFCore.exportimport.actions \
-                import importActionProviders
+        from ..actions import exportActionProviders
+        from ..actions import importActionProviders
 
-        site = self._initSite(1, 1)
-        atool = site.portal_actions
+        site, atool = self._initSite(1, 1)
         foo = site.portal_foo
         bar = site.portal_bar
 
         self.assertEqual(len(atool.listActionProviders()), 1)
-        self.failIf('portal_foo' in atool.listActionProviders())
-        self.failIf(foo.listActions())
-        self.failIf('portal_bar' in atool.listActionProviders())
-        self.failIf(bar.listActions())
-        self.failUnless('portal_actions' in atool.listActionProviders())
+        self.assertFalse('portal_foo' in atool.listActionProviders())
+        self.assertFalse(foo.listActions())
+        self.assertFalse('portal_bar' in atool.listActionProviders())
+        self.assertFalse(bar.listActions())
+        self.assertTrue('portal_actions' in atool.listActionProviders())
 
         context = DummyImportContext(site)
         context._files['actions.xml'] = _OLD_EXPORT
         importActionProviders(context)
 
         self.assertEqual(len(atool.listActionProviders()), 3)
-        self.failUnless('portal_bar' in atool.listActionProviders())
-        self.failUnless('portal_foo' in atool.listActionProviders())
-        self.failUnless('portal_actions' in atool.listActionProviders())
+        self.assertTrue('portal_bar' in atool.listActionProviders())
+        self.assertTrue('portal_foo' in atool.listActionProviders())
+        self.assertTrue('portal_actions' in atool.listActionProviders())
 
         self.assertEqual(len(atool.objectIds()), 1)
-        self.failUnless('dummy' in atool.objectIds())
+        self.assertTrue('dummy' in atool.objectIds())
         # Only one action appears. The importer only deals with actions
         # defined by the actions tool. Other tools are responsible for
         # exporting/importing actions themselves.
-        self.assertEqual(len(atool.dummy.objectIds()) , 1)
-        self.failUnless('baz' in atool.dummy.objectIds())
-        self.failIf(foo.listActions())
-        self.failIf(bar.listActions())
+        self.assertEqual(len(atool.dummy.objectIds()), 1)
+        self.assertTrue('baz' in atool.dummy.objectIds())
+        self.assertFalse(foo.listActions())
+        self.assertFalse(bar.listActions())
 
         # complete the roundtrip
         context = DummyExportContext(site)
@@ -541,17 +527,14 @@ class importActionProvidersTests(_ActionSetup):
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'actions.xml')
-        self._compareDOM(text, _NEWSYTLE_EXPORT)
+        self._compareDOM(text.decode('utf8'), _NEWSYTLE_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
     def test_i18n(self):
-        from Products.CMFCore.exportimport.actions \
-                import exportActionProviders
-        from Products.CMFCore.exportimport.actions \
-                import importActionProviders
+        from ..actions import exportActionProviders
+        from ..actions import importActionProviders
 
-        site = self._initSite(0, 0)
-        atool = site.portal_actions
+        site, atool = self._initSite(0, 0)
 
         context = DummyImportContext(site)
         context._files['actions.xml'] = _I18N_IMPORT
@@ -569,15 +552,13 @@ class importActionProvidersTests(_ActionSetup):
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'actions.xml')
-        self._compareDOM(text, _I18N_IMPORT)
+        self._compareDOM(text.decode('utf8'), _I18N_IMPORT)
         self.assertEqual(content_type, 'text/xml')
 
     def test_insert_skip_purge(self):
-        from Products.CMFCore.exportimport.actions \
-                import importActionProviders
+        from ..actions import importActionProviders
 
-        site = self._initSite(0, 0)
-        atool = site.portal_actions
+        site, atool = self._initSite(0, 0)
 
         context = DummyImportContext(site)
         context._files['actions.xml'] = _NEWSYTLE_EXPORT
@@ -598,14 +579,12 @@ class importActionProvidersTests(_ActionSetup):
         self.assertEqual(atool.dummy.baz.icon_expr, 'string:baz_icon.png')
 
     def test_remove_skip_purge(self):
-        from Products.CMFCore.exportimport.actions \
-                import importActionProviders
+        from ..actions import importActionProviders
 
-        site = self._initSite(2, 2)
-        atool = site.portal_actions
+        site, atool = self._initSite(2, 2)
 
         self.assertEqual(atool.listActionProviders(),
-                          ['portal_actions', 'portal_foo', 'portal_bar'])
+                         ['portal_actions', 'portal_foo', 'portal_bar'])
 
         context = DummyImportContext(site, False)
         context._files['actions.xml'] = _REMOVE_IMPORT
@@ -622,7 +601,3 @@ def test_suite():
         unittest.makeSuite(exportActionProvidersTests),
         unittest.makeSuite(importActionProvidersTests),
         ))
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
