@@ -10,22 +10,25 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Caching policy manager xml adapter and setup handler unit tests. """
+"""Caching policy manager xml adapter and setup handler unit tests.
+"""
 
 import unittest
-import Testing
 
 from OFS.Folder import Folder
-
 from Products.GenericSetup.testing import BodyAdapterTestCase
 from Products.GenericSetup.testing import NodeAdapterTestCase
 from Products.GenericSetup.tests.common import BaseRegistryTests
 from Products.GenericSetup.tests.common import DummyExportContext
 from Products.GenericSetup.tests.common import DummyImportContext
+from zope.component import getSiteManager
 
-from Products.CMFCore.testing import ExportImportZCMLLayer
+from ...CachingPolicyManager import CachingPolicyManager
+from ...interfaces import ICachingPolicyManager
+from ...testing import ExportImportZCMLLayer
 
-_CP_XML = """\
+
+_CP_XML = b"""\
 <caching-policy name="foo_policy" enable_304s="False" etag_func=""
    last_modified="True" max_age_secs="0" mtime_func="object/modified"
    must_revalidate="False" no_cache="False" no_store="False"
@@ -33,58 +36,51 @@ _CP_XML = """\
    proxy_revalidate="False" public="False" vary=""/>
 """
 
-_CPM_BODY = """\
-<?xml version="1.0"?>
+_CPM_BODY = b"""\
+<?xml version="1.0" encoding="utf-8"?>
 <object name="caching_policy_manager" meta_type="CMF Caching Policy Manager">
  <caching-policy name="foo_policy" enable_304s="False" etag_func=""
     last_modified="True" max_age_secs="600" mtime_func="object/modified"
     must_revalidate="False" no_cache="False" no_store="False"
     no_transform="False"
-    predicate="python:object.getPortalTypeName() == 'Foo'" private="False"
-    proxy_revalidate="False" public="False" vary=""/>
+    predicate="python:object.getPortalTypeName() == &#x27;Foo&#x27;"
+    private="False" proxy_revalidate="False" public="False" vary=""/>
 </object>
 """
 
 
-class CachingPolicyNodeAdapterTests(NodeAdapterTestCase,
-                                    unittest.TestCase,
-                                   ):
+class CachingPolicyNodeAdapterTests(NodeAdapterTestCase, unittest.TestCase):
 
     layer = ExportImportZCMLLayer
 
     def _getTargetClass(self):
-        from Products.CMFCore.exportimport.cachingpolicymgr \
-                import CachingPolicyNodeAdapter
+        from ..cachingpolicymgr import CachingPolicyNodeAdapter
 
         return CachingPolicyNodeAdapter
 
     def setUp(self):
-        from Products.CMFCore.CachingPolicyManager import CachingPolicy
+        from ...CachingPolicyManager import CachingPolicy
 
         self._obj = CachingPolicy('foo_policy', max_age_secs=0)
         self._XML = _CP_XML
 
 
 class CachingPolicyManagerXMLAdapterTests(BodyAdapterTestCase,
-                                          unittest.TestCase,
-                                         ):
+                                          unittest.TestCase):
 
     layer = ExportImportZCMLLayer
 
     def _getTargetClass(self):
-        from Products.CMFCore.exportimport.cachingpolicymgr \
-                import CachingPolicyManagerXMLAdapter
+        from ..cachingpolicymgr import CachingPolicyManagerXMLAdapter
 
         return CachingPolicyManagerXMLAdapter
 
     def _populate(self, obj):
         obj.addPolicy('foo_policy',
-                      'python:object.getPortalTypeName() == \'Foo\'',
+                      "python:object.getPortalTypeName() == 'Foo'",
                       'object/modified', 600, 0, 0, 0, '', '')
 
     def setUp(self):
-        from Products.CMFCore.CachingPolicyManager import CachingPolicyManager
-
         self._obj = CachingPolicyManager()
         self._BODY = _CPM_BODY
 
@@ -93,10 +89,10 @@ class _CachingPolicyManagerSetup(BaseRegistryTests):
 
     POLICY_ID = 'policy_id'
     PREDICATE = "python:object.getId() == 'foo'"
-    MTIME_FUNC = "object/modified"
+    MTIME_FUNC = 'object/modified'
     MAX_AGE_SECS = 60
-    VARY = "Test"
-    ETAG_FUNC = "object/getETag"
+    VARY = 'Test'
+    ETAG_FUNC = 'object/getETag'
     S_MAX_AGE_SECS = 120
     PRE_CHECK = 42
     POST_CHECK = 43
@@ -120,35 +116,31 @@ class _CachingPolicyManagerSetup(BaseRegistryTests):
        PREDICATE, S_MAX_AGE_SECS, VARY)
 
     def _initSite(self, with_policy=False):
-        from Products.CMFCore.CachingPolicyManager import CachingPolicyManager
-
-        self.root.site = Folder(id='site')
-        site = self.root.site
-        mgr = CachingPolicyManager()
-        site._setObject( mgr.getId(), mgr )
+        site = Folder(id='site').__of__(self.app)
+        cpm = CachingPolicyManager()
+        getSiteManager().registerUtility(cpm, ICachingPolicyManager)
 
         if with_policy:
-            mgr.addPolicy( policy_id=self.POLICY_ID
-                         , predicate=self.PREDICATE
-                         , mtime_func=self.MTIME_FUNC
-                         , max_age_secs=self.MAX_AGE_SECS
-                         , no_cache=True
-                         , no_store=True
-                         , must_revalidate=True
-                         , vary=self.VARY
-                         , etag_func=self.ETAG_FUNC
-                         , s_max_age_secs=self.S_MAX_AGE_SECS
-                         , proxy_revalidate=True
-                         , public=True
-                         , private=True
-                         , no_transform=True
-                         , enable_304s=True
-                         , last_modified=False
-                         , pre_check=self.PRE_CHECK
-                         , post_check=self.POST_CHECK
-                         )
+            cpm.addPolicy(policy_id=self.POLICY_ID,
+                          predicate=self.PREDICATE,
+                          mtime_func=self.MTIME_FUNC,
+                          max_age_secs=self.MAX_AGE_SECS,
+                          no_cache=True,
+                          no_store=True,
+                          must_revalidate=True,
+                          vary=self.VARY,
+                          etag_func=self.ETAG_FUNC,
+                          s_max_age_secs=self.S_MAX_AGE_SECS,
+                          proxy_revalidate=True,
+                          public=True,
+                          private=True,
+                          no_transform=True,
+                          enable_304s=True,
+                          last_modified=False,
+                          pre_check=self.PRE_CHECK,
+                          post_check=self.POST_CHECK)
 
-        return site
+        return site, cpm
 
 
 class exportCachingPolicyManagerTests(_CachingPolicyManagerSetup):
@@ -156,31 +148,29 @@ class exportCachingPolicyManagerTests(_CachingPolicyManagerSetup):
     layer = ExportImportZCMLLayer
 
     def test_empty(self):
-        from Products.CMFCore.exportimport.cachingpolicymgr \
-                import exportCachingPolicyManager
+        from ..cachingpolicymgr import exportCachingPolicyManager
 
-        site = self._initSite(with_policy=False)
+        site, _cpm = self._initSite(with_policy=False)
         context = DummyExportContext(site)
         exportCachingPolicyManager(context)
 
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'cachingpolicymgr.xml')
-        self._compareDOM(text, self._EMPTY_EXPORT)
+        self._compareDOM(text.decode('utf8'), self._EMPTY_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
     def test_with_policy(self):
-        from Products.CMFCore.exportimport.cachingpolicymgr \
-                import exportCachingPolicyManager
+        from ..cachingpolicymgr import exportCachingPolicyManager
 
-        site = self._initSite(with_policy=True)
+        site, _cpm = self._initSite(with_policy=True)
         context = DummyExportContext(site)
         exportCachingPolicyManager(context)
 
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'cachingpolicymgr.xml')
-        self._compareDOM(text, self._WITH_POLICY_EXPORT)
+        self._compareDOM(text.decode('utf8'), self._WITH_POLICY_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
 
@@ -189,11 +179,9 @@ class importCachingPolicyManagerTests(_CachingPolicyManagerSetup):
     layer = ExportImportZCMLLayer
 
     def test_normal(self):
-        from Products.CMFCore.exportimport.cachingpolicymgr \
-                import importCachingPolicyManager
+        from ..cachingpolicymgr import importCachingPolicyManager
 
-        site = self._initSite(with_policy=False)
-        cpm = site.caching_policy_manager
+        site, cpm = self._initSite(with_policy=False)
         self.assertEqual(len(cpm.listPolicies()), 0)
 
         context = DummyImportContext(site)
@@ -201,7 +189,7 @@ class importCachingPolicyManagerTests(_CachingPolicyManagerSetup):
         importCachingPolicyManager(context)
 
         self.assertEqual(len(cpm.listPolicies()), 1)
-        policy_id, policy = cpm.listPolicies()[0]
+        _policy_id, policy = cpm.listPolicies()[0]
         self.assertEqual(policy.getPolicyId(), self.POLICY_ID)
         self.assertEqual(policy.getPredicate(), self.PREDICATE)
         self.assertEqual(policy.getMTimeFunc(), self.MTIME_FUNC)
@@ -229,7 +217,3 @@ def test_suite():
         unittest.makeSuite(exportCachingPolicyManagerTests),
         unittest.makeSuite(importCachingPolicyManagerTests),
         ))
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
