@@ -11,26 +11,27 @@
 #
 ##############################################################################
 """Catalog tool setup handler unit tests.
-
-$Id: test_catalog.py 110577 2010-04-07 06:33:17Z jens $
 """
 
 import unittest
-from Testing import ZopeTestCase
-ZopeTestCase.installProduct('ZCTextIndex', 1)
 
 from OFS.Folder import Folder
+from Products.GenericSetup.tests.common import BaseRegistryTests
+from Products.GenericSetup.tests.common import DummyExportContext
+from Products.GenericSetup.tests.common import DummyImportContext
 from Products.ZCTextIndex.Lexicon import CaseNormalizer
 from Products.ZCTextIndex.Lexicon import Splitter
 from Products.ZCTextIndex.Lexicon import StopWordRemover
 from Products.ZCTextIndex.ZCTextIndex import PLexicon
+from Testing import ZopeTestCase
+from zope.component import getSiteManager
 
-from Products.GenericSetup.tests.common import BaseRegistryTests
-from Products.GenericSetup.tests.common import DummyExportContext
-from Products.GenericSetup.tests.common import DummyImportContext
+from ...CatalogTool import CatalogTool
+from ...interfaces import ICatalogTool
+from ...testing import ExportImportZCMLLayer
 
-from Products.CMFCore.CatalogTool import CatalogTool
-from Products.CMFCore.testing import ExportImportZCMLLayer
+
+ZopeTestCase.installProduct('ZCTextIndex', 1)
 
 _EMPTY_EXPORT = """\
 <?xml version="1.0"?>
@@ -76,14 +77,15 @@ class _extra:
 class _CatalogToolSetup(BaseRegistryTests):
 
     def _initSite(self, foo=2):
-        site = self.root.site = Folder(id='site')
-        ctool = site.portal_catalog = CatalogTool()
+        site = Folder(id='site').__of__(self.app)
+        ctool = CatalogTool()
+        getSiteManager().registerUtility(ctool, ICatalogTool)
 
         for obj_id in ctool.objectIds():
             ctool._delObject(obj_id)
         for idx_id in ctool.indexes():
             ctool.delIndex(idx_id)
-        for col in ctool.schema()[:]:
+        for col in list(ctool.schema()):
             ctool.delColumn(col)
 
         if foo > 0:
@@ -98,7 +100,7 @@ class _CatalogToolSetup(BaseRegistryTests):
 
             ctool.addColumn('foo_zctext')
 
-        return site
+        return site, ctool
 
 
 class exportCatalogToolTests(_CatalogToolSetup):
@@ -106,29 +108,29 @@ class exportCatalogToolTests(_CatalogToolSetup):
     layer = ExportImportZCMLLayer
 
     def test_unchanged(self):
-        from Products.CMFCore.exportimport.catalog import exportCatalogTool
+        from ..catalog import exportCatalogTool
 
-        site = self._initSite(0)
+        site, _ctool = self._initSite(0)
         context = DummyExportContext(site)
         exportCatalogTool(context)
 
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'catalog.xml')
-        self._compareDOM(text, _EMPTY_EXPORT)
+        self._compareDOM(text.decode('utf8'), _EMPTY_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
     def test_normal(self):
-        from Products.CMFCore.exportimport.catalog import exportCatalogTool
+        from ..catalog import exportCatalogTool
 
-        site = self._initSite(2)
+        site, _ctool = self._initSite(2)
         context = DummyExportContext(site)
         exportCatalogTool(context)
 
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'catalog.xml')
-        self._compareDOM(text, _NORMAL_EXPORT)
+        self._compareDOM(text.decode('utf8'), _NORMAL_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
 
@@ -137,10 +139,9 @@ class importCatalogToolTests(_CatalogToolSetup):
     layer = ExportImportZCMLLayer
 
     def test_empty_purge(self):
-        from Products.CMFCore.exportimport.catalog import importCatalogTool
+        from ..catalog import importCatalogTool
 
-        site = self._initSite(2)
-        ctool = site.portal_catalog
+        site, ctool = self._initSite(2)
 
         self.assertEqual(len(ctool.objectIds()), 1)
         self.assertEqual(len(ctool.indexes()), 1)
@@ -155,10 +156,9 @@ class importCatalogToolTests(_CatalogToolSetup):
         self.assertEqual(len(ctool.schema()), 0)
 
     def test_empty_update(self):
-        from Products.CMFCore.exportimport.catalog import importCatalogTool
+        from ..catalog import importCatalogTool
 
-        site = self._initSite(2)
-        ctool = site.portal_catalog
+        site, ctool = self._initSite(2)
 
         self.assertEqual(len(ctool.objectIds()), 1)
         self.assertEqual(len(ctool.indexes()), 1)
@@ -173,11 +173,10 @@ class importCatalogToolTests(_CatalogToolSetup):
         self.assertEqual(len(ctool.schema()), 1)
 
     def test_normal_purge(self):
-        from Products.CMFCore.exportimport.catalog import exportCatalogTool
-        from Products.CMFCore.exportimport.catalog import importCatalogTool
+        from ..catalog import exportCatalogTool
+        from ..catalog import importCatalogTool
 
-        site = self._initSite(2)
-        ctool = site.portal_catalog
+        site, ctool = self._initSite(2)
 
         self.assertEqual(len(ctool.objectIds()), 1)
         self.assertEqual(len(ctool.indexes()), 1)
@@ -198,14 +197,13 @@ class importCatalogToolTests(_CatalogToolSetup):
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'catalog.xml')
-        self._compareDOM(text, _NORMAL_EXPORT)
+        self._compareDOM(text.decode('utf8'), _NORMAL_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
     def test_normal_update(self):
-        from Products.CMFCore.exportimport.catalog import importCatalogTool
+        from ..catalog import importCatalogTool
 
-        site = self._initSite(2)
-        ctool = site.portal_catalog
+        site, ctool = self._initSite(2)
 
         self.assertEqual(len(ctool.objectIds()), 1)
         self.assertEqual(len(ctool.indexes()), 1)
@@ -225,7 +223,3 @@ def test_suite():
         unittest.makeSuite(exportCatalogToolTests),
         unittest.makeSuite(importCatalogToolTests),
         ))
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
