@@ -10,35 +10,50 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Filesystem exporter / importer adapter unit tests. """
+"""Filesystem exporter / importer adapter unit tests.
+"""
 
 import unittest
-import Testing
-
 from csv import reader
-from ConfigParser import ConfigParser
-from StringIO import StringIO
 
-from zope.testing.cleanup import cleanUp
+from six import StringIO
+from six import binary_type
+from six.moves.configparser import ConfigParser
 
 from Products.GenericSetup.tests.common import DummyExportContext
 from Products.GenericSetup.tests.common import DummyImportContext
+from zope.component import getSiteManager
+from zope.testing.cleanup import cleanUp
+
+from ...interfaces import ITypesTool
+from ...testing import DummyWorkflow
+from .test_workflow import DummyWorkflowTool
+
+
+def safe_bytes(value, encoding='utf8'):
+    if isinstance(value, binary_type):
+        return value
+    return value.encode(encoding)
 
 
 class SiteStructureExporterTests(unittest.TestCase):
 
     def _getExporter(self):
-        from Products.CMFCore.exportimport.content import exportSiteStructure
+        from ..content import exportSiteStructure
         return exportSiteStructure
 
     def _getImporter(self):
-        from Products.CMFCore.exportimport.content import importSiteStructure
+        from ..content import importSiteStructure
         return importSiteStructure
 
     def _makeSetupTool(self):
         from Products.GenericSetup.tool import SetupTool
         return SetupTool('portal_setup')
 
+    def _makeWorkflowTool(self):
+        obj = DummyWorkflowTool()
+        return obj
+
     def _setUpAdapters(self):
         from zope.component import provideAdapter
 
@@ -46,14 +61,11 @@ class SiteStructureExporterTests(unittest.TestCase):
         from Products.GenericSetup.interfaces import IFilesystemImporter
         from Products.GenericSetup.interfaces import ICSVAware
         from Products.GenericSetup.interfaces import IINIAware
-        from Products.CMFCore.interfaces import IFolderish
+        from ...interfaces import IFolderish
 
-        from Products.CMFCore.exportimport.content import \
-             StructureFolderWalkingAdapter
-        from Products.GenericSetup.content import \
-             CSVAwareFileAdapter
-        from Products.GenericSetup.content import \
-             INIAwareFileAdapter
+        from ..content import StructureFolderWalkingAdapter
+        from Products.GenericSetup.content import CSVAwareFileAdapter
+        from Products.GenericSetup.content import INIAwareFileAdapter
 
         provideAdapter(StructureFolderWalkingAdapter,
                        (IFolderish,),
@@ -79,6 +91,14 @@ class SiteStructureExporterTests(unittest.TestCase):
                        (IINIAware,),
                        IFilesystemImporter)
 
+    def _get_config_parser(self, text):
+        parser = ConfigParser()
+        try:
+            parser.read_file(StringIO(text))
+        except AttributeError:  # Python 2
+            parser.readfp(StringIO(text))
+        return parser
+
     def tearDown(self):
         cleanUp()
 
@@ -103,8 +123,7 @@ class SiteStructureExporterTests(unittest.TestCase):
         self.assertEqual(filename, 'structure/.properties')
         self.assertEqual(content_type, 'text/plain')
 
-        parser = ConfigParser()
-        parser.readfp(StringIO(text))
+        parser = self._get_config_parser(text)
 
         self.assertEqual(parser.get('DEFAULT', 'Title'),
                          site.title)
@@ -133,8 +152,7 @@ class SiteStructureExporterTests(unittest.TestCase):
         self.assertEqual(filename, 'structure/.properties')
         self.assertEqual(content_type, 'text/plain')
 
-        parser = ConfigParser()
-        parser.readfp(StringIO(text))
+        parser = self._get_config_parser(text)
 
         self.assertEqual(parser.get('DEFAULT', 'Title'),
                          site.title)
@@ -169,8 +187,7 @@ class SiteStructureExporterTests(unittest.TestCase):
         filename, text, content_type = context._wrote[1]
         self.assertEqual(filename, 'structure/.properties')
         self.assertEqual(content_type, 'text/plain')
-        parser = ConfigParser()
-        parser.readfp(StringIO(text))
+        parser = self._get_config_parser(text)
 
         self.assertEqual(parser.get('DEFAULT', 'title'), 'AAA')
         self.assertEqual(parser.get('DEFAULT', 'description'), 'DESCRIPTION')
@@ -205,7 +222,7 @@ class SiteStructureExporterTests(unittest.TestCase):
             self.assertEqual(objects[index][0], ITEM_IDS[index])
             self.assertEqual(objects[index][1], TEST_INI_AWARE)
 
-            filename, text, content_type = context._wrote[index+2]
+            filename, text, content_type = context._wrote[index + 2]
             self.assertEqual(filename, 'structure/%s.ini' % ITEM_IDS[index])
             object = site._getOb(ITEM_IDS[index])
             self.assertEqual(text.strip(),
@@ -215,13 +232,12 @@ class SiteStructureExporterTests(unittest.TestCase):
         filename, text, content_type = context._wrote[1]
         self.assertEqual(filename, 'structure/.properties')
         self.assertEqual(content_type, 'text/plain')
-        parser = ConfigParser()
-        parser.readfp(StringIO(text))
+        parser = self._get_config_parser(text)
 
-        self.assertEqual(parser.get('DEFAULT', 'title'),
-            ITEMS_TITLE.encode('utf8'))
-        self.assertEqual(parser.get('DEFAULT', 'description'),
-            ITEMS_DESCRIPTION.encode('utf8'))
+        self.assertEqual(safe_bytes(parser.get('DEFAULT', 'title')),
+                         ITEMS_TITLE.encode('utf8'))
+        self.assertEqual(safe_bytes(parser.get('DEFAULT', 'description')),
+                         ITEMS_DESCRIPTION.encode('utf8'))
 
     def test_export_site_with_exportable_simple_items(self):
         self._setUpAdapters()
@@ -248,7 +264,7 @@ class SiteStructureExporterTests(unittest.TestCase):
             self.assertEqual(objects[index][0], ITEM_IDS[index])
             self.assertEqual(objects[index][1], TEST_INI_AWARE)
 
-            filename, text, content_type = context._wrote[index+2]
+            filename, text, content_type = context._wrote[index + 2]
             self.assertEqual(filename, 'structure/%s.ini' % ITEM_IDS[index])
             object = site._getOb(ITEM_IDS[index])
             self.assertEqual(text.strip(),
@@ -258,13 +274,49 @@ class SiteStructureExporterTests(unittest.TestCase):
         filename, text, content_type = context._wrote[1]
         self.assertEqual(filename, 'structure/.properties')
         self.assertEqual(content_type, 'text/plain')
-        parser = ConfigParser()
-        parser.readfp(StringIO(text))
+        parser = self._get_config_parser(text)
 
         self.assertEqual(parser.get('DEFAULT', 'title'), 'AAA')
         self.assertEqual(parser.get('DEFAULT', 'description'), 'DESCRIPTION')
 
-    def test_export_site_with_exportable_simple_items_unicode_default_charset(self):
+    def test_export_site_includes_workflow(self):
+        self._setUpAdapters()
+        ITEM_IDS = ('foo', 'bar', 'baz')
+
+        site = _makeFolder('site', site_folder=True)
+
+        site._setObject('portal_workflow', self._makeWorkflowTool())
+        wftool = site.portal_workflow
+        wftool._setObject('foo_workflow', DummyWorkflow('foo_workflow'))
+        wftool.foo_workflow.state_var = 'state'
+        wftool.setDefaultChain('foo_workflow')
+        wftool.setChainForPortalTypes((TEST_INI_AWARE,),
+                                      'foo_workflow', verify=False)
+
+        site.title = 'AAA'
+        site.description = 'DESCRIPTION'
+        for id in ITEM_IDS:
+            site._setObject(id, _makeINIAware(id))
+            wftool.setStatusOf('foo_workflow', site[id],
+                               {'state': 'published'})
+
+        context = DummyExportContext(site)
+        exporter = self._getExporter()
+        exporter(context)
+
+        self.assertEqual(len(context._wrote), 3 + len(ITEM_IDS))
+        filename, text, content_type = context._wrote[0]
+        self.assertEqual(filename, 'structure/.workflow_states')
+        self.assertEqual(content_type, 'text/comma-separated-values')
+
+        objects = [x for x in reader(StringIO(text))]
+        self.assertEqual(len(objects), 3)
+        for index in range(len(ITEM_IDS)):
+            self.assertEqual(objects[index][0], ITEM_IDS[index])
+            self.assertEqual(objects[index][1], 'foo_workflow')
+            self.assertEqual(objects[index][2], 'published')
+
+    def test_export_site_exportable_simple_items_unicode_default_charset(self):
         self._setUpAdapters()
         ITEM_IDS = ('foo', 'bar', 'baz')
 
@@ -294,7 +346,7 @@ class SiteStructureExporterTests(unittest.TestCase):
             self.assertEqual(objects[index][0], ITEM_IDS[index])
             self.assertEqual(objects[index][1], TEST_INI_AWARE)
 
-            filename, text, content_type = context._wrote[index+2]
+            filename, text, content_type = context._wrote[index + 2]
             self.assertEqual(filename, 'structure/%s.ini' % ITEM_IDS[index])
             object = site._getOb(ITEM_IDS[index])
             self.assertEqual(text.strip(),
@@ -304,13 +356,12 @@ class SiteStructureExporterTests(unittest.TestCase):
         filename, text, content_type = context._wrote[1]
         self.assertEqual(filename, 'structure/.properties')
         self.assertEqual(content_type, 'text/plain')
-        parser = ConfigParser()
-        parser.readfp(StringIO(text))
+        parser = self._get_config_parser(text)
 
-        self.assertEqual(parser.get('DEFAULT', 'title'),
-            ITEMS_TITLE.encode('utf8'))
-        self.assertEqual(parser.get('DEFAULT', 'description'),
-            ITEMS_DESCRIPTION.encode('utf8'))
+        self.assertEqual(safe_bytes(parser.get('DEFAULT', 'title')),
+                         ITEMS_TITLE.encode('utf8'))
+        self.assertEqual(safe_bytes(parser.get('DEFAULT', 'description')),
+                         ITEMS_DESCRIPTION.encode('utf8'))
 
     def test_export_site_with_exportable_simple_items_unicode_latin1(self):
         self._setUpAdapters()
@@ -343,7 +394,7 @@ class SiteStructureExporterTests(unittest.TestCase):
             self.assertEqual(objects[index][0], ITEM_IDS[index])
             self.assertEqual(objects[index][1], TEST_INI_AWARE)
 
-            filename, text, content_type = context._wrote[index+2]
+            filename, text, content_type = context._wrote[index + 2]
             self.assertEqual(filename, 'structure/%s.ini' % ITEM_IDS[index])
             object = site._getOb(ITEM_IDS[index])
             self.assertEqual(text.strip(),
@@ -353,13 +404,13 @@ class SiteStructureExporterTests(unittest.TestCase):
         filename, text, content_type = context._wrote[1]
         self.assertEqual(filename, 'structure/.properties')
         self.assertEqual(content_type, 'text/plain')
-        parser = ConfigParser()
-        parser.readfp(StringIO(text))
+        parser = self._get_config_parser(text)
 
-        self.assertEqual(parser.get('DEFAULT', 'title'),
-            ITEMS_TITLE.encode('latin1'))
-        self.assertEqual(parser.get('DEFAULT', 'description'),
-            ITEMS_DESCRIPTION.encode('latin1'))
+        self.assertEqual(safe_bytes(parser.get('DEFAULT', 'title'), 'latin1'),
+                         ITEMS_TITLE.encode('latin1'))
+        self.assertEqual(safe_bytes(parser.get('DEFAULT', 'description'),
+                                    'latin1'),
+                         ITEMS_DESCRIPTION.encode('latin1'))
 
     def test_export_site_with_subfolders(self):
         self._setUpAdapters()
@@ -378,7 +429,7 @@ class SiteStructureExporterTests(unittest.TestCase):
         exporter = self._getExporter()
         exporter(context)
 
-        self.assertEqual(len(context._wrote), 2 + (2 *len(FOLDER_IDS)))
+        self.assertEqual(len(context._wrote), 2 + (2 * len(FOLDER_IDS)))
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'structure/.objects')
         self.assertEqual(content_type, 'text/comma-separated-values')
@@ -401,8 +452,7 @@ class SiteStructureExporterTests(unittest.TestCase):
             self.assertEqual(filename,
                              '/'.join(('structure', id, '.properties')))
             self.assertEqual(content_type, 'text/plain')
-            parser = ConfigParser()
-            parser.readfp(StringIO(text))
+            parser = self._get_config_parser(text)
 
             self.assertEqual(parser.get('DEFAULT', 'Title'), 'Title: %s' % id)
 
@@ -410,12 +460,35 @@ class SiteStructureExporterTests(unittest.TestCase):
         self.assertEqual(filename, 'structure/.properties')
         self.assertEqual(content_type, 'text/plain')
 
-        parser = ConfigParser()
-        parser.readfp(StringIO(text))
+        parser = self._get_config_parser(text)
 
         self.assertEqual(parser.get('DEFAULT', 'title'), 'AAA')
         self.assertEqual(parser.get('DEFAULT', 'description'), 'DESCRIPTION')
 
+    def test_export_site_with_dav_aware_folder(self):
+        self._setUpAdapters()
+
+        site = _makeFolder('site', site_folder=True)
+        site.title = 'AAA'
+        site.description = 'DESCRIPTION'
+
+        folder = _makeDAVAwareFolder('foo')
+        folder.title = 'foo'
+        folder.description = 'xyzzy'
+        folder.body = 'A content item'
+        site._setObject('foo', folder)
+
+        context = DummyExportContext(site)
+        exporter = self._getExporter()
+        exporter(context)
+
+        filename, text, content_type = context._wrote[-1]
+        self.assertEqual(filename, 'structure/foo/.properties')
+        self.assertEqual(content_type, 'text/plain')
+        self.assertEqual(text,
+                         KNOWN_DAV % (folder.title, folder.description,
+                                      folder.body))
+
     def test_export_site_with_csvaware(self):
         self._setUpAdapters()
 
@@ -443,13 +516,11 @@ class SiteStructureExporterTests(unittest.TestCase):
         self.assertEqual(filename, 'structure/.properties')
         self.assertEqual(content_type, 'text/plain')
 
-        parser = ConfigParser()
-        parser.readfp(StringIO(text))
+        parser = self._get_config_parser(text)
 
-        self.assertEqual(parser.get('DEFAULT', 'Title'),
-                                    site.title)
+        self.assertEqual(parser.get('DEFAULT', 'Title'), site.title)
         self.assertEqual(parser.get('DEFAULT', 'Description'),
-                                    site.description)
+                         site.description)
 
         filename, text, content_type = context._wrote[2]
         self.assertEqual(filename, 'structure/aware.csv')
@@ -499,10 +570,10 @@ class SiteStructureExporterTests(unittest.TestCase):
         for id in FOLDER_IDS:
             context._files['structure/%s/.objects' % id] = ''
             context._files['structure/%s/.properties' % id] = (
-                _PROPERTIES_TEMPLATE % id )
+                _PROPERTIES_TEMPLATE % id)
 
         _ROOT_OBJECTS = '\n'.join(['%s,%s' % (id, TEST_FOLDER)
-                                        for id in FOLDER_IDS])
+                                   for id in FOLDER_IDS])
 
         context._files['structure/.objects'] = _ROOT_OBJECTS
         context._files['structure/.properties'] = (
@@ -514,6 +585,63 @@ class SiteStructureExporterTests(unittest.TestCase):
         content = site.contentValues()
         self.assertEqual(len(content), len(FOLDER_IDS))
 
+    def test_import_site_with_dav_aware_folder(self):
+        from Products.GenericSetup.tests.test_content \
+            import _PROPERTIES_TEMPLATE
+        self._setUpAdapters()
+        FOLDER_IDS = ('foo', 'bar', 'baz')
+
+        site = _makeFolder('site', site_folder=True)
+
+        context = DummyImportContext(site)
+
+        for id in FOLDER_IDS:
+            context._files['structure/%s/.objects' % id] = ''
+            context._files['structure/%s/.properties' % id] = (
+                KNOWN_DAV % ('Title', 'Description', 'Body'))
+
+        _ROOT_OBJECTS = '\n'.join(['%s,%s' % (id, TEST_DAV_FOLDER)
+                                  for id in FOLDER_IDS])
+
+        context._files['structure/.objects'] = _ROOT_OBJECTS
+        context._files['structure/.properties'] = (
+                _PROPERTIES_TEMPLATE % 'Test Site')
+
+        importer = self._getImporter()
+        importer(context)
+        content = site.contentValues()
+        self.assertEqual(len(content), len(FOLDER_IDS))
+        self.assertEqual(content[0]._was_put_as_read,
+                         KNOWN_DAV % ('Title', 'Description', 'Body'))
+
+    def test_import_site_with_dav_aware_folder_with_generic_file_data(self):
+        from Products.GenericSetup.tests.test_content \
+            import _PROPERTIES_TEMPLATE
+        self._setUpAdapters()
+        FOLDER_IDS = ('foo', 'bar', 'baz')
+
+        site = _makeFolder('site', site_folder=True)
+
+        context = DummyImportContext(site)
+
+        for id in FOLDER_IDS:
+            context._files['structure/%s/.objects' % id] = ''
+            context._files['structure/%s/.properties' % id] = (
+                _PROPERTIES_TEMPLATE % ('Sub Folder Title',))
+
+        _ROOT_OBJECTS = '\n'.join(['%s,%s' % (id, TEST_DAV_FOLDER)
+                                   for id in FOLDER_IDS])
+
+        context._files['structure/.objects'] = _ROOT_OBJECTS
+        context._files['structure/.properties'] = (
+                _PROPERTIES_TEMPLATE % 'Test Site')
+
+        importer = self._getImporter()
+        importer(context)
+        content = site.contentValues()
+        self.assertEqual(len(content), len(FOLDER_IDS))
+        self.assertEqual(content[0].title, 'Sub Folder Title')
+
     def test_import_site_with_subitems(self):
         self._setUpAdapters()
         ITEM_IDS = ('foo', 'bar', 'baz')
@@ -528,8 +656,7 @@ class SiteStructureExporterTests(unittest.TestCase):
             id = ITEM_IDS[index]
             context._files[
                     'structure/%s.ini' % id] = KNOWN_INI % ('Title: %s' % id,
-                                                            'xyzzy',
-                                                           )
+                                                            'xyzzy')
         importer = self._getImporter()
         importer(context)
 
@@ -538,6 +665,37 @@ class SiteStructureExporterTests(unittest.TestCase):
         for found_id, expected_id in zip(after, ITEM_IDS):
             self.assertEqual(found_id, expected_id)
 
+    def test_import_site_includes_workflow(self):
+        self._setUpAdapters()
+        ITEM_IDS = ('foo', 'bar', 'baz')
+
+        site = _makeFolder('site', site_folder=True)
+
+        site._setObject('portal_workflow', self._makeWorkflowTool())
+        wftool = site.portal_workflow
+        wftool._setObject('foo_workflow', DummyWorkflow('foo_workflow'))
+        wftool.foo_workflow.state_var = 'state'
+        wftool.setDefaultChain('foo_workflow')
+        wftool.setChainForPortalTypes((TEST_INI_AWARE,),
+                                      'foo_workflow', verify=False)
+
+        context = DummyImportContext(site)
+        context._files['structure/.objects'] = '\n'.join(
+                            ['%s,%s' % (x, TEST_INI_AWARE) for x in ITEM_IDS])
+        context._files['structure/.workflow_states'] = '\n'.join(
+                            ['%s,foo_workflow,draft' % (x) for x in ITEM_IDS])
+        for index in range(len(ITEM_IDS)):
+            id = ITEM_IDS[index]
+            context._files[
+                    'structure/%s.ini' % id] = KNOWN_INI % ('Title: %s' % id,
+                                                            'xyzzy')
+        importer = self._getImporter()
+        importer(context)
+
+        for item_id in ITEM_IDS:
+            wf = wftool.getStatusOf('foo_workflow', site[item_id])
+            self.assertEqual(wf['state'], 'draft')
+
     def test_import_site_with_subitems_and_blanklines_dotobjects(self):
         self._setUpAdapters()
         ITEM_IDS = ('foo', 'bar', 'baz')
@@ -553,8 +711,7 @@ class SiteStructureExporterTests(unittest.TestCase):
             id = ITEM_IDS[index]
             context._files[
                     'structure/%s.ini' % id] = KNOWN_INI % ('Title: %s' % id,
-                                                            'xyzzy',
-                                                           )
+                                                            'xyzzy')
         importer = self._getImporter()
         importer(context)
 
@@ -577,8 +734,7 @@ class SiteStructureExporterTests(unittest.TestCase):
             id = ITEM_IDS[index]
             context._files[
                     'structure/%s.ini' % id] = KNOWN_INI % ('Title: %s' % id,
-                                                            'xyzzy',
-                                                           )
+                                                            'xyzzy')
 
         importer = self._getImporter()
         importer(context)
@@ -586,9 +742,9 @@ class SiteStructureExporterTests(unittest.TestCase):
         after = site.objectIds()
         self.assertEqual(len(after), 0)
         self.assertEqual(len(context._notes), len(ITEM_IDS))
-        for level, component, message in context._notes:
+        for _level, component, message in context._notes:
             self.assertEqual(component, 'SFWA')
-            self.failUnless(message.startswith("Couldn't make"))
+            self.assertTrue(message.startswith("Couldn't make"))
 
     def test_reimport_no_structure_no_delete(self):
         self._setUpAdapters()
@@ -624,15 +780,14 @@ class SiteStructureExporterTests(unittest.TestCase):
             id = ITEM_IDS[index]
             context._files[
                     'structure/%s.ini' % id] = KNOWN_INI % ('Title: %s' % id,
-                                                            'xyzzy',
-                                                           )
+                                                            'xyzzy')
 
         importer = self._getImporter()
         importer(context)
 
         self.assertEqual(len(site.objectIds()), len(ITEM_IDS))
         for obj in site.objectValues():
-            self.failIf(hasattr(obj, 'before'))
+            self.assertFalse(hasattr(obj, 'before'))
 
     def test_reimport_with_structure_and_preserve(self):
         self._setUpAdapters()
@@ -650,8 +805,7 @@ class SiteStructureExporterTests(unittest.TestCase):
             id = ITEM_IDS[index]
             context._files[
                     'structure/%s.ini' % id] = KNOWN_INI % ('Title: %s' % id,
-                                                            'xyzzy',
-                                                           )
+                                                            'xyzzy')
         context._files['structure/.preserve'] = '*'
 
         importer = self._getImporter()
@@ -680,8 +834,7 @@ class SiteStructureExporterTests(unittest.TestCase):
             id = ITEM_IDS[index]
             context._files[
                     'structure/%s.ini' % id] = KNOWN_INI % ('Title: %s' % id,
-                                                            'xyzzy',
-                                                           )
+                                                            'xyzzy')
         context._files['structure/.preserve'] = 'b*'
 
         importer = self._getImporter()
@@ -711,8 +864,7 @@ class SiteStructureExporterTests(unittest.TestCase):
             id = ITEM_IDS[index]
             context._files[
                     'structure/%s.ini' % id] = KNOWN_INI % ('Title: %s' % id,
-                                                            'xyzzy',
-                                                           )
+                                                            'xyzzy')
         context._files['structure/.preserve'] = 'foo'
         context._files['structure/.delete'] = 'baz'
 
@@ -721,9 +873,9 @@ class SiteStructureExporterTests(unittest.TestCase):
 
         after = site.objectIds()
         self.assertEqual(len(after), len(ITEM_IDS) - 1)
-        self.failIf('baz' in after)
+        self.assertFalse('baz' in after)
         self.assertEqual(getattr(site.foo, 'before', None), True)
-        self.failIf(hasattr(site.bar, 'before'))
+        self.assertFalse(hasattr(site.bar, 'before'))
 
     def test_import_site_with_subfolders_and_preserve(self):
         self._setUpAdapters()
@@ -757,14 +909,15 @@ one,two,three
 four,five,six
 """
 
+
 def _makeCSVAware(id):
     from OFS.SimpleItem import SimpleItem
-    from zope.interface import implements
-    from Products.CMFCore.interfaces import IDynamicType
+    from zope.interface import implementer
+    from ...interfaces import IDynamicType
     from Products.GenericSetup.interfaces import ICSVAware
 
+    @implementer(IDynamicType, ICSVAware)
     class _TestCSVAware(SimpleItem):
-        implements(IDynamicType, ICSVAware)
         _was_put = None
         portal_type = TEST_CSV_AWARE
 
@@ -790,14 +943,15 @@ title = %s
 description = %s
 """
 
+
 def _makeINIAware(id):
     from OFS.SimpleItem import SimpleItem
-    from zope.interface import implements
-    from Products.CMFCore.interfaces import IDynamicType
+    from zope.interface import implementer
+    from ...interfaces import IDynamicType
     from Products.GenericSetup.interfaces import IINIAware
 
+    @implementer(IDynamicType, IINIAware)
     class _TestINIAware(SimpleItem):
-        implements(IDynamicType, IINIAware)
         _was_put = None
         title = 'INI title'
         description = 'INI description'
@@ -812,6 +966,9 @@ def _makeINIAware(id):
         def put_ini(self, text):
             self._was_put = text
 
+        def reindexObject(self):
+            return NotImplemented
+
     aware = _TestINIAware()
     aware._setId(id)
 
@@ -826,14 +983,15 @@ Description: %s
 %s
 """
 
+
 def _makeDAVAware(id):
     from OFS.SimpleItem import SimpleItem
-    from zope.interface import implements
-    from Products.CMFCore.interfaces import IDynamicType
+    from zope.interface import implementer
+    from ...interfaces import IDynamicType
     from Products.GenericSetup.interfaces import IDAVAware
 
+    @implementer(IDynamicType, IDAVAware)
     class _TestDAVAware(SimpleItem):
-        implements(IDynamicType, IDAVAware)
         _was_put = None
         title = 'DAV title'
         description = 'DAV description'
@@ -857,15 +1015,47 @@ def _makeDAVAware(id):
     return aware
 
 
+TEST_DAV_FOLDER = 'Test DAV Folder'
+
+
+def _makeDAVAwareFolder(id):
+    from ...PortalFolder import PortalFolder
+    from zope.interface import implementer
+    from ...interfaces import IDynamicType
+    from Products.GenericSetup.interfaces import IDAVAware
+
+    @implementer(IDynamicType, IDAVAware)
+    class _TestDAVAwareFolder(PortalFolder):
+        _was_put = None
+        body = 'DAV body'
+        portal_type = TEST_DAV_FOLDER
+
+        def getPortalTypeName(self):
+            return self.portal_type
+
+        def manage_FTPget(self):
+            return KNOWN_DAV % (self.title, self.description, self.body)
+
+        def PUT(self, REQUEST, RESPONSE):
+            self._was_put = REQUEST.get('BODY', '')
+            stream = REQUEST.get('BODYFILE', None)
+            self._was_put_as_read = stream.read()
+
+    folder = _TestDAVAwareFolder(id)
+    folder.portal_type = TEST_DAV_FOLDER
+    return folder
+
+
 TEST_CONTENT = 'Test Content'
 
+
 def _makeItem(self):
     from OFS.SimpleItem import SimpleItem
-    from zope.interface import implements
-    from Products.CMFCore.interfaces import IDynamicType
+    from zope.interface import implementer
+    from ...interfaces import IDynamicType
 
+    @implementer(IDynamicType)
     class _TestContent(SimpleItem):
-        implements(IDynamicType)
         portal_type = TEST_CONTENT
 
         def getPortalTypeName(self):
@@ -879,18 +1069,22 @@ def _makeItem(self):
 
 TEST_FOLDER = 'Test Folder'
 
+
 def _makeFolder(id, site_folder=False):
-    from Products.CMFCore.PortalFolder import PortalFolder
-    from Products.CMFCore.TypesTool import TypesTool
-    from Products.CMFCore.tests.base.dummy import DummyType
+    from ...PortalFolder import PortalFolder
+    from ...TypesTool import TypesTool
+    from ...tests.base.dummy import DummyType
 
     class _TypeInfo(DummyType):
         def _getId(self):
             return self._id
+
         def constructInstance(self, container, id, *args, **kw):
             portal_type = self._getId()
             if portal_type == TEST_FOLDER:
                 content = PortalFolder(id)
+            elif portal_type == TEST_DAV_FOLDER:
+                content = _makeDAVAwareFolder(id)
             elif portal_type == TEST_CONTENT:
                 content = _makeItem()
                 content._setId(id)
@@ -899,7 +1093,7 @@ def _makeFolder(id, site_folder=False):
             elif portal_type == TEST_CSV_AWARE:
                 content = _makeCSVAware(id)
             else:
-                raise ValueError, 'Ugh'
+                raise ValueError('Ugh')
             content.portal_type = portal_type
             container._setObject(id, content)
             return container._getOb(id)
@@ -907,11 +1101,13 @@ def _makeFolder(id, site_folder=False):
     folder = PortalFolder(id)
     folder.portal_type = TEST_FOLDER
     if site_folder:
-        tool = folder.portal_types = TypesTool()
-        tool._setObject(TEST_CSV_AWARE, _TypeInfo(TEST_CSV_AWARE))
-        tool._setObject(TEST_INI_AWARE, _TypeInfo(TEST_INI_AWARE))
-        tool._setObject(TEST_CONTENT, _TypeInfo(TEST_CONTENT))
-        tool._setObject(TEST_FOLDER, _TypeInfo(TEST_FOLDER))
+        ttool = TypesTool()
+        ttool._setObject(TEST_CSV_AWARE, _TypeInfo(TEST_CSV_AWARE))
+        ttool._setObject(TEST_INI_AWARE, _TypeInfo(TEST_INI_AWARE))
+        ttool._setObject(TEST_CONTENT, _TypeInfo(TEST_CONTENT))
+        ttool._setObject(TEST_FOLDER, _TypeInfo(TEST_FOLDER))
+        ttool._setObject(TEST_DAV_FOLDER, _TypeInfo(TEST_DAV_FOLDER))
+        getSiteManager().registerUtility(ttool, ITypesTool)
 
     return folder
 
@@ -920,6 +1116,3 @@ def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(SiteStructureExporterTests))
     return suite
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
