@@ -10,19 +10,21 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Content type registry xml adapter and setup handler unit tests. """
+"""Content type registry xml adapter and setup handler unit tests.
+"""
 
 import unittest
-import Testing
 
 from OFS.Folder import Folder
-
 from Products.GenericSetup.testing import BodyAdapterTestCase
 from Products.GenericSetup.tests.common import BaseRegistryTests
 from Products.GenericSetup.tests.common import DummyExportContext
 from Products.GenericSetup.tests.common import DummyImportContext
+from zope.component import getSiteManager
+
+from ...interfaces import IContentTypeRegistry
+from ...testing import ExportImportZCMLLayer
 
-from Products.CMFCore.testing import ExportImportZCMLLayer
 
 _TEST_PREDICATES = (
  ('plain_text', 'major_minor', ('text', 'plain,javascript'), 'File'),
@@ -31,8 +33,8 @@ _TEST_PREDICATES = (
  ('logfiles', 'name_regex', ('error_log-.*',), 'Log File'),
 )
 
-_CTR_BODY = """\
-<?xml version="1.0"?>
+_CTR_BODY = b"""\
+<?xml version="1.0" encoding="utf-8"?>
 <object name="content_type_registry" meta_type="Content Type Registry">
  <predicate name="foo_predicate" content_type_name="Foo Type"
     predicate_type="major_minor">
@@ -54,16 +56,30 @@ _CTR_BODY = """\
 </object>
 """
 
+_FRAGMENT1_IMPORT = """\
+<?xml version="1.0"?>
+<object name="content_type_registry">
+ <predicate name="plain_text" insert-after="*"/>
+ <predicate name="logfiles" insert-before="*"/>
+</object>
+"""
+
+_FRAGMENT2_IMPORT = """\
+<?xml version="1.0"?>
+<object name="content_type_registry">
+ <predicate name="plain_text" insert-after="stylesheets"/>
+ <predicate name="logfiles" insert-before="images"/>
+</object>
+"""
+
 
 class ContentTypeRegistryXMLAdapterTests(BodyAdapterTestCase,
-                                         unittest.TestCase,
-                                        ):
+                                         unittest.TestCase):
 
     layer = ExportImportZCMLLayer
 
     def _getTargetClass(self):
-        from Products.CMFCore.exportimport.contenttyperegistry \
-                import ContentTypeRegistryXMLAdapter
+        from ..contenttyperegistry import ContentTypeRegistryXMLAdapter
 
         return ContentTypeRegistryXMLAdapter
 
@@ -82,7 +98,7 @@ class ContentTypeRegistryXMLAdapterTests(BodyAdapterTestCase,
         obj.assignTypeName('foobar_predicate', 'Foobar Type')
 
     def setUp(self):
-        from Products.CMFCore.ContentTypeRegistry import ContentTypeRegistry
+        from ...ContentTypeRegistry import ContentTypeRegistry
 
         self._obj = ContentTypeRegistry()
         self._BODY = _CTR_BODY
@@ -105,12 +121,12 @@ class _ContentTypeRegistrySetup(BaseRegistryTests):
     NAME_REGEX_TYPENAME = _TEST_PREDICATES[3][3]
 
     _EMPTY_EXPORT = """\
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="utf-8"?>
 <object name="content_type_registry" meta_type="Content Type Registry"/>
 """
 
     _WITH_POLICY_EXPORT = """\
-<?xml version="1.0"?>
+<?xml version="1.0"  encoding="utf-8"?>
 <object name="content_type_registry" meta_type="Content Type Registry">
  <predicate name="%s" content_type_name="%s"
     predicate_type="major_minor">
@@ -142,26 +158,24 @@ class _ContentTypeRegistrySetup(BaseRegistryTests):
        MIMETYPE_REGEX,
        NAME_REGEX_ID,
        NAME_REGEX_TYPENAME,
-       NAME_REGEX,
-      )
+       NAME_REGEX)
 
     def _initSite(self, mit_predikat=False):
-        from Products.CMFCore.ContentTypeRegistry import ContentTypeRegistry
+        from ...ContentTypeRegistry import ContentTypeRegistry
 
-        self.root.site = Folder(id='site')
-        site = self.root.site
+        site = Folder(id='site').__of__(self.app)
         ctr = ContentTypeRegistry()
-        site._setObject( ctr.getId(), ctr )
+        getSiteManager().registerUtility(ctr, IContentTypeRegistry)
 
         if mit_predikat:
-            for (predicate_id, predicate_type, edit_args, content_type_name
-                ) in _TEST_PREDICATES:
-                ctr.addPredicate(predicate_id, predicate_type) 
+            for (predicate_id, predicate_type, edit_args,
+                 content_type_name) in _TEST_PREDICATES:
+                ctr.addPredicate(predicate_id, predicate_type)
                 predicate = ctr.getPredicate(predicate_id)
                 predicate.edit(*edit_args)
                 ctr.assignTypeName(predicate_id, content_type_name)
 
-        return site
+        return site, ctr
 
 
 class exportContentTypeRegistryTests(_ContentTypeRegistrySetup):
@@ -169,31 +183,29 @@ class exportContentTypeRegistryTests(_ContentTypeRegistrySetup):
     layer = ExportImportZCMLLayer
 
     def test_empty(self):
-        from Products.CMFCore.exportimport.contenttyperegistry \
-                import exportContentTypeRegistry
+        from ..contenttyperegistry import exportContentTypeRegistry
 
-        site = self._initSite(mit_predikat=False)
+        site, _ctr = self._initSite(mit_predikat=False)
         context = DummyExportContext(site)
         exportContentTypeRegistry(context)
 
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'contenttyperegistry.xml')
-        self._compareDOM(text, self._EMPTY_EXPORT)
+        self._compareDOM(text.decode('utf8'), self._EMPTY_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
     def test_with_policy(self):
-        from Products.CMFCore.exportimport.contenttyperegistry \
-                import exportContentTypeRegistry
+        from ..contenttyperegistry import exportContentTypeRegistry
 
-        site = self._initSite(mit_predikat=True)
+        site, _ctr = self._initSite(mit_predikat=True)
         context = DummyExportContext(site)
         exportContentTypeRegistry(context)
 
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'contenttyperegistry.xml')
-        self._compareDOM(text, self._WITH_POLICY_EXPORT)
+        self._compareDOM(text.decode('utf8'), self._WITH_POLICY_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
 
@@ -201,12 +213,13 @@ class importContentTypeRegistryTests(_ContentTypeRegistrySetup):
 
     layer = ExportImportZCMLLayer
 
-    def test_normal(self):
-        from Products.CMFCore.exportimport.contenttyperegistry \
-                import importContentTypeRegistry
+    _FRAGMENT1_IMPORT = _FRAGMENT1_IMPORT
+    _FRAGMENT2_IMPORT = _FRAGMENT2_IMPORT
 
-        site = self._initSite(mit_predikat=False)
-        ctr = site.content_type_registry
+    def test_normal(self):
+        from ..contenttyperegistry import importContentTypeRegistry
+
+        site, ctr = self._initSite(mit_predikat=False)
         self.assertEqual(len(ctr.listPredicates()), 0)
 
         context = DummyImportContext(site)
@@ -236,6 +249,38 @@ class importContentTypeRegistryTests(_ContentTypeRegistrySetup):
         self.assertEqual(content_type_name, self.NAME_REGEX_TYPENAME)
         self.assertEqual(predicate.pattern.pattern, self.NAME_REGEX)
 
+    def test_fragment1_skip_purge(self):
+        from ..contenttyperegistry import importContentTypeRegistry
+
+        site, ctr = self._initSite(mit_predikat=True)
+        self.assertEqual(len(ctr.listPredicates()), len(_TEST_PREDICATES))
+        self.assertEqual(ctr.predicate_ids, ('plain_text', 'stylesheets',
+                                             'images', 'logfiles'))
+
+        context = DummyImportContext(site, False)
+        context._files['contenttyperegistry.xml'] = self._FRAGMENT1_IMPORT
+        importContentTypeRegistry(context)
+
+        self.assertEqual(len(ctr.listPredicates()), len(_TEST_PREDICATES))
+        self.assertEqual(ctr.predicate_ids, ('logfiles', 'stylesheets',
+                                             'images', 'plain_text'))
+
+    def test_fragment2_skip_purge(self):
+        from ..contenttyperegistry import importContentTypeRegistry
+
+        site, ctr = self._initSite(mit_predikat=True)
+        self.assertEqual(len(ctr.listPredicates()), len(_TEST_PREDICATES))
+        self.assertEqual(ctr.predicate_ids, ('plain_text', 'stylesheets',
+                                             'images', 'logfiles'))
+
+        context = DummyImportContext(site, False)
+        context._files['contenttyperegistry.xml'] = self._FRAGMENT2_IMPORT
+        importContentTypeRegistry(context)
+
+        self.assertEqual(len(ctr.listPredicates()), len(_TEST_PREDICATES))
+        self.assertEqual(ctr.predicate_ids, ('stylesheets', 'plain_text',
+                                             'logfiles', 'images'))
+
 
 def test_suite():
     return unittest.TestSuite((
@@ -243,7 +288,3 @@ def test_suite():
         unittest.makeSuite(exportContentTypeRegistryTests),
         unittest.makeSuite(importContentTypeRegistryTests),
         ))
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
