@@ -11,33 +11,30 @@
 #
 ##############################################################################
 """Cookie crumbler xml adapter and setup handler unit tests.
-
-$Id: test_cookieauth.py 110577 2010-04-07 06:33:17Z jens $
 """
 
 import unittest
-import Testing
 
 from OFS.Folder import Folder
-
 from Products.GenericSetup.testing import BodyAdapterTestCase
 from Products.GenericSetup.tests.common import BaseRegistryTests
 from Products.GenericSetup.tests.common import DummyExportContext
 from Products.GenericSetup.tests.common import DummyImportContext
+from zope.component import getSiteManager
 
-from Products.CMFCore.CookieCrumbler import CookieCrumbler
-from Products.CMFCore.testing import ExportImportZCMLLayer
+from ...CookieCrumbler import CookieCrumbler
+from ...interfaces import ICookieCrumbler
+from ...testing import ExportImportZCMLLayer
 
-_COOKIECRUMBLER_BODY = """\
-<?xml version="1.0"?>
-<object name="foo_cookiecrumbler" meta_type="Cookie Crumbler">
+
+_COOKIECRUMBLER_BODY = b"""\
+<?xml version="1.0" encoding="utf-8"?>
+<object name="cookie_authentication" meta_type="Cookie Crumbler">
+ <property name="title"></property>
  <property name="auth_cookie">__ac</property>
  <property name="name_cookie">__ac_name</property>
  <property name="pw_cookie">__ac_password</property>
  <property name="persist_cookie">__ac_persistent</property>
- <property name="auto_login_page">login_form</property>
- <property name="logout_page">logged_out</property>
- <property name="unauth_page"></property>
  <property name="local_cookie_path">False</property>
  <property name="cache_header_value">private</property>
  <property name="log_username">True</property>
@@ -46,14 +43,12 @@ _COOKIECRUMBLER_BODY = """\
 
 _DEFAULT_EXPORT = """\
 <?xml version="1.0"?>
-<object name="foo_cookiecrumbler" meta_type="Cookie Crumbler">
+<object name="cookie_authentication" meta_type="Cookie Crumbler">
+ <property name="title"></property>
  <property name="auth_cookie">__ac</property>
  <property name="name_cookie">__ac_name</property>
  <property name="pw_cookie">__ac_password</property>
  <property name="persist_cookie">__ac_persistent</property>
- <property name="auto_login_page">login_form</property>
- <property name="logout_page">logged_out</property>
- <property name="unauth_page"></property>
  <property name="local_cookie_path">False</property>
  <property name="cache_header_value">private</property>
  <property name="log_username">True</property>
@@ -62,7 +57,22 @@ _DEFAULT_EXPORT = """\
 
 _CHANGED_EXPORT = """\
 <?xml version="1.0"?>
+<object name="cookie_authentication" meta_type="Cookie Crumbler">
+ <property name="title">I am a cookie</property>
+ <property name="auth_cookie">value1</property>
+ <property name="name_cookie">value3</property>
+ <property name="pw_cookie">value5</property>
+ <property name="persist_cookie">value4</property>
+ <property name="local_cookie_path">True</property>
+ <property name="cache_header_value">value2</property>
+ <property name="log_username">False</property>
+</object>
+"""
+
+_CMF22_IMPORT = """\
+<?xml version="1.0"?>
 <object name="foo_cookiecrumbler" meta_type="Cookie Crumbler">
+ <property name="title"></property>
  <property name="auth_cookie">value1</property>
  <property name="name_cookie">value3</property>
  <property name="pw_cookie">value5</property>
@@ -82,24 +92,24 @@ class CookieCrumblerXMLAdapterTests(BodyAdapterTestCase, unittest.TestCase):
     layer = ExportImportZCMLLayer
 
     def _getTargetClass(self):
-        from Products.CMFCore.exportimport.cookieauth \
-                import CookieCrumblerXMLAdapter
+        from ..cookieauth import CookieCrumblerXMLAdapter
 
         return CookieCrumblerXMLAdapter
 
     def setUp(self):
-        self._obj = CookieCrumbler('foo_cookiecrumbler')
+        self._obj = CookieCrumbler()
         self._BODY = _COOKIECRUMBLER_BODY
 
 
 class _CookieCrumblerSetup(BaseRegistryTests):
 
     def _initSite(self, use_changed=False):
-        self.root.site = Folder(id='site')
-        site = self.root.site
-        cc = site.cookie_authentication = CookieCrumbler('foo_cookiecrumbler')
+        site = Folder(id='site').__of__(self.app)
+        cc = CookieCrumbler()
+        getSiteManager().registerUtility(cc, ICookieCrumbler)
 
         if use_changed:
+            cc.title = 'I am a cookie'
             cc.auth_cookie = 'value1'
             cc.cache_header_value = 'value2'
             cc.name_cookie = 'value3'
@@ -107,11 +117,8 @@ class _CookieCrumblerSetup(BaseRegistryTests):
             cc.persist_cookie = 'value4'
             cc.pw_cookie = 'value5'
             cc.local_cookie_path = 1
-            cc.auto_login_page = 'value6'
-            cc.unauth_page = 'value7'
-            cc.logout_page = 'value8'
 
-        return site
+        return site, cc
 
 
 class exportCookieCrumblerTests(_CookieCrumblerSetup):
@@ -119,31 +126,29 @@ class exportCookieCrumblerTests(_CookieCrumblerSetup):
     layer = ExportImportZCMLLayer
 
     def test_unchanged(self):
-        from Products.CMFCore.exportimport.cookieauth \
-                import exportCookieCrumbler
+        from ..cookieauth import exportCookieCrumbler
 
-        site = self._initSite(use_changed=False)
+        site, _cc = self._initSite(use_changed=False)
         context = DummyExportContext(site)
         exportCookieCrumbler(context)
 
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'cookieauth.xml')
-        self._compareDOM(text, _DEFAULT_EXPORT)
+        self._compareDOM(text.decode('utf8'), _DEFAULT_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
     def test_changed(self):
-        from Products.CMFCore.exportimport.cookieauth \
-                import exportCookieCrumbler
+        from ..cookieauth import exportCookieCrumbler
 
-        site = self._initSite(use_changed=True)
+        site, _cc = self._initSite(use_changed=True)
         context = DummyExportContext(site)
         exportCookieCrumbler(context)
 
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'cookieauth.xml')
-        self._compareDOM(text, _CHANGED_EXPORT)
+        self._compareDOM(text.decode('utf8'), _CHANGED_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
 
@@ -152,26 +157,39 @@ class importCookieCrumblerTests(_CookieCrumblerSetup):
     layer = ExportImportZCMLLayer
 
     def test_normal(self):
-        from Products.CMFCore.exportimport.cookieauth \
-                import importCookieCrumbler
+        from ..cookieauth import importCookieCrumbler
 
-        site = self._initSite()
-        cc = site.cookie_authentication
+        site, cc = self._initSite()
 
         context = DummyImportContext(site)
         context._files['cookieauth.xml'] = _CHANGED_EXPORT
         importCookieCrumbler(context)
 
-        self.assertEqual( cc.auth_cookie, 'value1' )
-        self.assertEqual( cc.cache_header_value, 'value2' )
-        self.assertEqual( cc.name_cookie, 'value3' )
-        self.assertEqual( cc.log_username, 0 )
-        self.assertEqual( cc.persist_cookie, 'value4' )
-        self.assertEqual( cc.pw_cookie, 'value5' )
-        self.assertEqual( cc.local_cookie_path, 1 )
-        self.assertEqual( cc.auto_login_page, 'value6' )
-        self.assertEqual( cc.unauth_page, 'value7' )
-        self.assertEqual( cc.logout_page, 'value8' )
+        self.assertEqual(cc.title, 'I am a cookie')
+        self.assertEqual(cc.auth_cookie, 'value1')
+        self.assertEqual(cc.cache_header_value, 'value2')
+        self.assertEqual(cc.name_cookie, 'value3')
+        self.assertEqual(cc.log_username, 0)
+        self.assertEqual(cc.persist_cookie, 'value4')
+        self.assertEqual(cc.pw_cookie, 'value5')
+        self.assertEqual(cc.local_cookie_path, 1)
+
+    def test_migration(self):
+        from ..cookieauth import importCookieCrumbler
+
+        site, cc = self._initSite()
+
+        context = DummyImportContext(site)
+        context._files['cookieauth.xml'] = _CMF22_IMPORT
+        importCookieCrumbler(context)
+
+        self.assertEqual(cc.auth_cookie, 'value1')
+        self.assertEqual(cc.cache_header_value, 'value2')
+        self.assertEqual(cc.name_cookie, 'value3')
+        self.assertEqual(cc.log_username, 0)
+        self.assertEqual(cc.persist_cookie, 'value4')
+        self.assertEqual(cc.pw_cookie, 'value5')
+        self.assertEqual(cc.local_cookie_path, 1)
 
 
 def test_suite():
@@ -180,7 +198,3 @@ def test_suite():
         unittest.makeSuite(exportCookieCrumblerTests),
         unittest.makeSuite(importCookieCrumblerTests),
         ))
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
