@@ -11,37 +11,36 @@
 #
 ##############################################################################
 """Skins tool xml adapter and setup handler unit tests.
-
-$Id: test_skins.py 110655 2010-04-08 15:38:57Z tseaver $
 """
 
-import unittest
-from Testing import ZopeTestCase
-ZopeTestCase.installProduct('CMFCore', 1)
-
 import os
+import unittest
 
 from OFS.Folder import Folder
-from zope.interface import implements
-
 from Products.GenericSetup.testing import BodyAdapterTestCase
 from Products.GenericSetup.testing import NodeAdapterTestCase
 from Products.GenericSetup.tests.common import BaseRegistryTests
 from Products.GenericSetup.tests.common import DummyExportContext
 from Products.GenericSetup.tests.common import DummyImportContext
+from Testing import ZopeTestCase
+from zope.component import getSiteManager
+from zope.interface import implementer
 
-from Products.CMFCore.interfaces import ISkinsTool
-from Products.CMFCore.testing import ExportImportZCMLLayer
+from ...interfaces import ISkinsTool
+from ...testing import ExportImportZCMLLayer
+
+
+ZopeTestCase.installProduct('CMFCore', 1)
 
 _TESTS_PATH = os.path.split(__file__)[0]
 
-_DIRECTORYVIEW_XML = """\
+_DIRECTORYVIEW_XML = b"""\
 <object name="foo_directoryview" meta_type="Filesystem Directory View"
-   directory="CMFCore/exportimport/tests/one"/>
+   directory="Products.CMFCore.exportimport.tests:one"/>
 """
 
-_SKINSTOOL_BODY = """\
-<?xml version="1.0"?>
+_SKINSTOOL_BODY = b"""\
+<?xml version="1.0" encoding="utf-8"?>
 <object name="portal_skins" meta_type="CMF Skins Tool" allow_any="False"
    cookie_persistence="False" default_skin="" request_varname="portal_skin">
  <object name="foo_directoryview" meta_type="Filesystem Directory View"
@@ -106,9 +105,9 @@ _FRAGMENT3_IMPORT = """\
 <?xml version="1.0"?>
 <object name="portal_skins" meta_type="Dummy Skins Tool">
  <object name="three" meta_type="Filesystem Directory View"
-    directory="CMFCore/exportimport/tests/three"/>
+    directory="Products.CMFCore.exportimport.tests:three"/>
  <object name="four" meta_type="Filesystem Directory View"
-    directory="CMFCore/exportimport/tests/four"/>
+    directory="Products.CMFCore.exportimport.tests:four"/>
  <skin-path name="*">
   <layer name="three" insert-before="*"/>
   <layer name="four" insert-after="*"/>
@@ -177,10 +176,9 @@ class DummySite(Folder):
         self._skin_setup_called = True
 
 
+@implementer(ISkinsTool)
 class DummySkinsTool(Folder):
 
-    implements(ISkinsTool)
-
     meta_type = 'Dummy Skins Tool'
     default_skin = 'default_skin'
     request_varname = 'request_varname'
@@ -202,8 +200,7 @@ class DummySkinsTool(Folder):
         return 'portal_skins'
 
     def getSkinPaths(self):
-        result = list(self._selections.items())
-        result.sort()
+        result = sorted(self._selections.items())
         return result
 
     def addSkinSelection(self, skinname, skinpath, test=0, make_default=0):
@@ -219,7 +216,7 @@ class DummySkinsTool(Folder):
 class _DVRegistrySetup:
 
     def setUp(self):
-        from Products.CMFCore import DirectoryView
+        from ... import DirectoryView
 
         self._olddirreg = DirectoryView._dirreg
         DirectoryView._dirreg = DirectoryView.DirectoryRegistry()
@@ -230,83 +227,85 @@ class _DVRegistrySetup:
         self._dirreg.registerDirectory('four', globals())
 
     def tearDown(self):
-        from Products.CMFCore import DirectoryView
+        from ... import DirectoryView
 
         DirectoryView._dirreg = self._olddirreg
 
 
-class DirectoryViewAdapterTests(_DVRegistrySetup, NodeAdapterTestCase):
+class DirectoryViewAdapterTests(_DVRegistrySetup,
+                                NodeAdapterTestCase,
+                                unittest.TestCase):
 
     layer = ExportImportZCMLLayer
 
     def _getTargetClass(self):
-        from Products.CMFCore.exportimport.skins \
-                import DirectoryViewNodeAdapter
+        from ..skins import DirectoryViewNodeAdapter
 
         return DirectoryViewNodeAdapter
 
     def _populate(self, obj):
-        obj._dirpath = 'CMFCore/exportimport/tests/one'
+        obj._dirpath = 'Products.CMFCore.exportimport.tests:one'
 
     def setUp(self):
-        from Products.CMFCore.DirectoryView import DirectoryView
+        from ...DirectoryView import DirectoryView
 
-        NodeAdapterTestCase.setUp(self)
         _DVRegistrySetup.setUp(self)
         self._obj = DirectoryView('foo_directoryview').__of__(Folder())
         self._XML = _DIRECTORYVIEW_XML
 
     def tearDown(self):
         _DVRegistrySetup.tearDown(self)
-        NodeAdapterTestCase.tearDown(self)
 
 
-class SkinsToolXMLAdapterTests(_DVRegistrySetup, BodyAdapterTestCase):
+class SkinsToolXMLAdapterTests(_DVRegistrySetup,
+                               BodyAdapterTestCase,
+                               unittest.TestCase):
 
     layer = ExportImportZCMLLayer
 
     def _getTargetClass(self):
-        from Products.CMFCore.exportimport.skins import SkinsToolXMLAdapter
+        from ..skins import SkinsToolXMLAdapter
 
         return SkinsToolXMLAdapter
 
     def _populate(self, obj):
-        from Products.CMFCore.DirectoryView import DirectoryView
+        from ...DirectoryView import DirectoryView
 
         obj._setObject('foo_directoryview',
-                       DirectoryView('foo_directoryview',
-                                     'CMFCore/exportimport/tests/one'))
+                       DirectoryView(
+                            'foo_directoryview',
+                            'Products.CMFCore.exportimport.tests:one'))
         obj.addSkinSelection('foo_path', 'one')
 
     def _verifyImport(self, obj):
         pass
 
     def setUp(self):
-        from Products.CMFCore import DirectoryView
-        from Products.CMFCore.SkinsTool import SkinsTool
+        from ...SkinsTool import SkinsTool
 
-        BodyAdapterTestCase.setUp(self)
         _DVRegistrySetup.setUp(self)
         self._obj = SkinsTool()
         self._BODY = _SKINSTOOL_BODY
 
     def tearDown(self):
         _DVRegistrySetup.tearDown(self)
-        BodyAdapterTestCase.tearDown(self)
 
 
 class _SkinsSetup(_DVRegistrySetup, BaseRegistryTests):
 
     def _initSite(self, selections={}, ids=()):
-        from Products.CMFCore.DirectoryView import DirectoryView
+        from ...DirectoryView import DirectoryView
 
         site = DummySite()
-        fsdvs = [ (id, DirectoryView(id, 'CMFCore/exportimport/tests/%s' %
-                                         id)) for id in ids ]
-        site._setObject('portal_skins', DummySkinsTool(selections, fsdvs))
+        fsdvs = [(id,
+                  DirectoryView(id,
+                                'Products.CMFCore.exportimport.tests:%s' % id))
+                 for id in ids]
+        stool = DummySkinsTool(selections, fsdvs).__of__(site)
+        getSiteManager().registerUtility(stool, ISkinsTool)
 
         site.REQUEST = 'exists'
-        return site
+        return site, stool
 
     def setUp(self):
         BaseRegistryTests.setUp(self)
@@ -322,26 +321,26 @@ class exportSkinsToolTests(_SkinsSetup):
     layer = ExportImportZCMLLayer
 
     def test_empty(self):
-        from Products.CMFCore.exportimport.skins import exportSkinsTool
+        from ..skins import exportSkinsTool
 
-        site = self._initSite()
+        site, _stool = self._initSite()
         context = DummyExportContext(site)
         exportSkinsTool(context)
 
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'skins.xml')
-        self._compareDOM(text, _EMPTY_EXPORT)
+        self._compareDOM(text.decode('utf8'), _EMPTY_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
     def test_normal(self):
-        from Products.CMFCore.exportimport.skins import exportSkinsTool
+        from ..skins import exportSkinsTool
 
         _IDS = ('one', 'two', 'three')
         _PATHS = {'basic': 'one', 'fancy': 'three, two, one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        tool = site.portal_skins
+        site, tool = self._initSite(selections=_PATHS, ids=_IDS)
+
         tool.default_skin = 'basic'
         tool.request_varname = 'skin_var'
         tool.allow_any = True
@@ -353,7 +352,7 @@ class exportSkinsToolTests(_SkinsSetup):
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'skins.xml')
-        self._compareDOM(text, _NORMAL_EXPORT)
+        self._compareDOM(text.decode('utf8'), _NORMAL_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
 
@@ -371,34 +370,31 @@ class importSkinsToolTests(_SkinsSetup):
     _FRAGMENT7_IMPORT = _FRAGMENT7_IMPORT
     _NORMAL_EXPORT = _NORMAL_EXPORT
 
-
     def test_remove_skin_path(self):
-        from Products.CMFCore.exportimport.skins import importSkinsTool
+        from ..skins import importSkinsTool
 
         _IDS = ('one', 'two', 'three')
         _PATHS = {'basic': 'one', 'fancy': 'three, two, one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
-        self.failUnless(skins_tool._getSelections().has_key('fancy'))
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
+
+        self.assertTrue('fancy' in skins_tool._getSelections())
 
         context = DummyImportContext(site)
         context._files['skins.xml'] = self._FRAGMENT6_IMPORT
         importSkinsTool(context)
 
-        self.failIf(skins_tool._getSelections().has_key('fancy'))
-
+        self.assertFalse('fancy' in skins_tool._getSelections())
 
     def test_empty_default_purge(self):
-        from Products.CMFCore.exportimport.skins import importSkinsTool
+        from ..skins import importSkinsTool
 
         _IDS = ('one', 'two', 'three')
         _PATHS = {'basic': 'one', 'fancy': 'three, two, one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
-        self.failIf(site._skin_setup_called)
+        self.assertFalse(site._skin_setup_called)
         self.assertEqual(len(skins_tool.getSkinPaths()), 2)
         self.assertEqual(len(skins_tool.objectItems()), 3)
 
@@ -406,24 +402,23 @@ class importSkinsToolTests(_SkinsSetup):
         context._files['skins.xml'] = self._EMPTY_EXPORT
         importSkinsTool(context)
 
-        self.assertEqual(skins_tool.default_skin, "default_skin")
-        self.assertEqual(skins_tool.request_varname, "request_varname")
-        self.failIf(skins_tool.allow_any)
-        self.failIf(skins_tool.cookie_persistence)
-        self.failUnless(site._skin_setup_called)
+        self.assertEqual(skins_tool.default_skin, 'default_skin')
+        self.assertEqual(skins_tool.request_varname, 'request_varname')
+        self.assertFalse(skins_tool.allow_any)
+        self.assertFalse(skins_tool.cookie_persistence)
+        self.assertTrue(site._skin_setup_called)
         self.assertEqual(len(skins_tool.getSkinPaths()), 0)
         self.assertEqual(len(skins_tool.objectItems()), 0)
 
     def test_empty_explicit_purge(self):
-        from Products.CMFCore.exportimport.skins import importSkinsTool
+        from ..skins import importSkinsTool
 
         _IDS = ('one', 'two', 'three')
         _PATHS = {'basic': 'one', 'fancy': 'three, two, one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
-        self.failIf(site._skin_setup_called)
+        self.assertFalse(site._skin_setup_called)
         self.assertEqual(len(skins_tool.getSkinPaths()), 2)
         self.assertEqual(len(skins_tool.objectItems()), 3)
 
@@ -431,24 +426,23 @@ class importSkinsToolTests(_SkinsSetup):
         context._files['skins.xml'] = self._EMPTY_EXPORT
         importSkinsTool(context)
 
-        self.assertEqual(skins_tool.default_skin, "default_skin")
-        self.assertEqual(skins_tool.request_varname, "request_varname")
-        self.failIf(skins_tool.allow_any)
-        self.failIf(skins_tool.cookie_persistence)
-        self.failUnless(site._skin_setup_called)
+        self.assertEqual(skins_tool.default_skin, 'default_skin')
+        self.assertEqual(skins_tool.request_varname, 'request_varname')
+        self.assertFalse(skins_tool.allow_any)
+        self.assertFalse(skins_tool.cookie_persistence)
+        self.assertTrue(site._skin_setup_called)
         self.assertEqual(len(skins_tool.getSkinPaths()), 0)
         self.assertEqual(len(skins_tool.objectItems()), 0)
 
     def test_empty_skip_purge(self):
-        from Products.CMFCore.exportimport.skins import importSkinsTool
+        from ..skins import importSkinsTool
 
         _IDS = ('one', 'two', 'three')
         _PATHS = {'basic': 'one', 'fancy': 'three, two, one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
-        self.failIf(site._skin_setup_called)
+        self.assertFalse(site._skin_setup_called)
         self.assertEqual(len(skins_tool.getSkinPaths()), 2)
         self.assertEqual(len(skins_tool.objectItems()), 3)
 
@@ -456,21 +450,20 @@ class importSkinsToolTests(_SkinsSetup):
         context._files['skins.xml'] = self._EMPTY_EXPORT
         importSkinsTool(context)
 
-        self.assertEqual(skins_tool.default_skin, "default_skin")
-        self.assertEqual(skins_tool.request_varname, "request_varname")
-        self.failIf(skins_tool.allow_any)
-        self.failIf(skins_tool.cookie_persistence)
-        self.failUnless(site._skin_setup_called)
+        self.assertEqual(skins_tool.default_skin, 'default_skin')
+        self.assertEqual(skins_tool.request_varname, 'request_varname')
+        self.assertFalse(skins_tool.allow_any)
+        self.assertFalse(skins_tool.cookie_persistence)
+        self.assertTrue(site._skin_setup_called)
         self.assertEqual(len(skins_tool.getSkinPaths()), 2)
         self.assertEqual(len(skins_tool.objectItems()), 3)
 
     def test_normal(self):
-        from Products.CMFCore.exportimport.skins import importSkinsTool
+        from ..skins import importSkinsTool
 
-        site = self._initSite()
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite()
 
-        self.failIf(site._skin_setup_called)
+        self.assertFalse(site._skin_setup_called)
         self.assertEqual(len(skins_tool.getSkinPaths()), 0)
         self.assertEqual(len(skins_tool.objectItems()), 0)
 
@@ -478,24 +471,23 @@ class importSkinsToolTests(_SkinsSetup):
         context._files['skins.xml'] = self._NORMAL_EXPORT
         importSkinsTool(context)
 
-        self.assertEqual(skins_tool.default_skin, "basic")
-        self.assertEqual(skins_tool.request_varname, "skin_var")
-        self.failUnless(skins_tool.allow_any)
-        self.failUnless(skins_tool.cookie_persistence)
-        self.failUnless(site._skin_setup_called)
+        self.assertEqual(skins_tool.default_skin, 'basic')
+        self.assertEqual(skins_tool.request_varname, 'skin_var')
+        self.assertTrue(skins_tool.allow_any)
+        self.assertTrue(skins_tool.cookie_persistence)
+        self.assertTrue(site._skin_setup_called)
         self.assertEqual(len(skins_tool.getSkinPaths()), 2)
         self.assertEqual(len(skins_tool.objectItems()), 3)
 
     def test_fragment_skip_purge(self):
-        from Products.CMFCore.exportimport.skins import importSkinsTool
+        from ..skins import importSkinsTool
 
         _IDS = ('one', 'two')
         _PATHS = {'basic': 'one', 'fancy': 'two,one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
-        self.failIf(site._skin_setup_called)
+        self.assertFalse(site._skin_setup_called)
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 2)
         self.assertEqual(skin_paths[0], ('basic', 'one'))
@@ -506,11 +498,11 @@ class importSkinsToolTests(_SkinsSetup):
         context._files['skins.xml'] = self._FRAGMENT1_IMPORT
         importSkinsTool(context)
 
-        self.assertEqual(skins_tool.default_skin, "default_skin")
-        self.assertEqual(skins_tool.request_varname, "request_varname")
-        self.failIf(skins_tool.allow_any)
-        self.failIf(skins_tool.cookie_persistence)
-        self.failUnless(site._skin_setup_called)
+        self.assertEqual(skins_tool.default_skin, 'default_skin')
+        self.assertEqual(skins_tool.request_varname, 'request_varname')
+        self.assertFalse(skins_tool.allow_any)
+        self.assertFalse(skins_tool.cookie_persistence)
+        self.assertTrue(site._skin_setup_called)
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 2)
         self.assertEqual(skin_paths[0], ('basic', 'one,three'))
@@ -520,11 +512,11 @@ class importSkinsToolTests(_SkinsSetup):
         context._files['skins.xml'] = self._FRAGMENT2_IMPORT
         importSkinsTool(context)
 
-        self.assertEqual(skins_tool.default_skin, "default_skin")
-        self.assertEqual(skins_tool.request_varname, "request_varname")
-        self.failIf(skins_tool.allow_any)
-        self.failIf(skins_tool.cookie_persistence)
-        self.failUnless(site._skin_setup_called)
+        self.assertEqual(skins_tool.default_skin, 'default_skin')
+        self.assertEqual(skins_tool.request_varname, 'request_varname')
+        self.assertFalse(skins_tool.allow_any)
+        self.assertFalse(skins_tool.cookie_persistence)
+        self.assertTrue(site._skin_setup_called)
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 2)
         self.assertEqual(skin_paths[0], ('basic', 'one,three,four'))
@@ -532,15 +524,14 @@ class importSkinsToolTests(_SkinsSetup):
         self.assertEqual(len(skins_tool.objectItems()), 4)
 
     def test_fragment3_skip_purge(self):
-        from Products.CMFCore.exportimport.skins import importSkinsTool
+        from ..skins import importSkinsTool
 
         _IDS = ('one', 'two')
         _PATHS = {'basic': 'one', 'fancy': 'two,one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
-        self.failIf(site._skin_setup_called)
+        self.assertFalse(site._skin_setup_called)
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 2)
         self.assertEqual(skin_paths[0], ('basic', 'one'))
@@ -551,26 +542,25 @@ class importSkinsToolTests(_SkinsSetup):
         context._files['skins.xml'] = self._FRAGMENT3_IMPORT
         importSkinsTool(context)
 
-        self.assertEqual(skins_tool.default_skin, "default_skin")
-        self.assertEqual(skins_tool.request_varname, "request_varname")
-        self.failIf(skins_tool.allow_any)
-        self.failIf(skins_tool.cookie_persistence)
-        self.failUnless(site._skin_setup_called)
+        self.assertEqual(skins_tool.default_skin, 'default_skin')
+        self.assertEqual(skins_tool.request_varname, 'request_varname')
+        self.assertFalse(skins_tool.allow_any)
+        self.assertFalse(skins_tool.cookie_persistence)
+        self.assertTrue(site._skin_setup_called)
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 2)
         self.assertEqual(skin_paths[0], ('basic', 'three,one,four'))
         self.assertEqual(skin_paths[1],
-                          ('fancy', 'three,two,one,four'))
+                         ('fancy', 'three,two,one,four'))
         self.assertEqual(len(skins_tool.objectItems()), 4)
 
     def test_fragment4_removal(self):
-        from Products.CMFCore.exportimport.skins import importSkinsTool
+        from ..skins import importSkinsTool
 
         _IDS = ('one', 'two')
         _PATHS = {'basic': 'one', 'fancy': 'two,one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 2)
@@ -582,7 +572,7 @@ class importSkinsToolTests(_SkinsSetup):
         context._files['skins.xml'] = self._FRAGMENT3_IMPORT
         importSkinsTool(context)
 
-        self.failUnless(site._skin_setup_called)
+        self.assertTrue(site._skin_setup_called)
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 2)
         self.assertEqual(skin_paths[0], ('basic', 'three,one,four'))
@@ -594,7 +584,7 @@ class importSkinsToolTests(_SkinsSetup):
 
         importSkinsTool(context)
 
-        self.failUnless(site._skin_setup_called)
+        self.assertTrue(site._skin_setup_called)
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 2)
         self.assertEqual(skin_paths[0], ('basic', 'one,four'))
@@ -602,13 +592,12 @@ class importSkinsToolTests(_SkinsSetup):
         self.assertEqual(len(skins_tool.objectItems()), 4)
 
     def test_fragment5_based_skin(self):
-        from Products.CMFCore.exportimport.skins import importSkinsTool
+        from ..skins import importSkinsTool
 
         _IDS = ('one', 'two', 'three', 'four')
         _PATHS = {'basic': 'one,three,four', 'existing': 'one,two,four'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 2)
@@ -621,7 +610,7 @@ class importSkinsToolTests(_SkinsSetup):
 
         importSkinsTool(context)
 
-        self.failUnless(site._skin_setup_called)
+        self.assertTrue(site._skin_setup_called)
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 4)
         self.assertEqual(skin_paths[0], ('basic', 'one,three,four'))
@@ -632,13 +621,12 @@ class importSkinsToolTests(_SkinsSetup):
 
     def test_fragment7_modified_skin(self):
         # https://bugs.launchpad.net/zope-cmf/+bug/161732
-        from Products.CMFCore.exportimport.skins import importSkinsTool
+        from ..skins import importSkinsTool
 
         _IDS = ('one', 'two', 'three', 'four')
         _PATHS = {'existing': 'one,three,four'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 1)
@@ -650,7 +638,7 @@ class importSkinsToolTests(_SkinsSetup):
 
         importSkinsTool(context)
 
-        self.failUnless(site._skin_setup_called)
+        self.assertTrue(site._skin_setup_called)
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 1)
         self.assertEqual(skin_paths[0], ('existing', 'one,two,three,four'))
@@ -658,23 +646,9 @@ class importSkinsToolTests(_SkinsSetup):
 
 
 def test_suite():
-    # reimport to make sure tests are run from Products
-    from Products.CMFCore.exportimport.tests.test_skins \
-            import DirectoryViewAdapterTests
-    from Products.CMFCore.exportimport.tests.test_skins \
-            import exportSkinsToolTests
-    from Products.CMFCore.exportimport.tests.test_skins \
-            import importSkinsToolTests
-    from Products.CMFCore.exportimport.tests.test_skins \
-            import SkinsToolXMLAdapterTests
-
     return unittest.TestSuite((
         unittest.makeSuite(DirectoryViewAdapterTests),
         unittest.makeSuite(SkinsToolXMLAdapterTests),
         unittest.makeSuite(exportSkinsToolTests),
         unittest.makeSuite(importSkinsToolTests),
         ))
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
