@@ -10,29 +10,30 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Types tool xml adapter and setup handler unit tests. """
+"""Types tool xml adapter and setup handler unit tests.
+"""
 
 import unittest
-import Testing
 
 from OFS.Folder import Folder
-
 from Products.GenericSetup.testing import BodyAdapterTestCase
 from Products.GenericSetup.tests.common import BaseRegistryTests
 from Products.GenericSetup.tests.common import DummyExportContext
 from Products.GenericSetup.tests.common import DummyImportContext
+from zope.component import getSiteManager
 
-from Products.CMFCore.permissions import View
-from Products.CMFCore.permissions import AccessContentsInformation
-from Products.CMFCore.permissions import ModifyPortalContent
-from Products.CMFCore.testing import ExportImportZCMLLayer
-from Products.CMFCore.tests.base.testcase import WarningInterceptor
-from Products.CMFCore.TypesTool import FactoryTypeInformation
-from Products.CMFCore.TypesTool import ScriptableTypeInformation
-from Products.CMFCore.TypesTool import TypesTool
+from ...interfaces import ITypesTool
+from ...permissions import AccessContentsInformation
+from ...permissions import ModifyPortalContent
+from ...permissions import View
+from ...testing import ExportImportZCMLLayer
+from ...TypesTool import FactoryTypeInformation
+from ...TypesTool import ScriptableTypeInformation
+from ...TypesTool import TypesTool
 
-_FTI_BODY = """\
-<?xml version="1.0"?>
+
+_FTI_BODY = b"""\
+<?xml version="1.0" encoding="utf-8"?>
 <object name="foo_fti" meta_type="Factory-based Type Information"
    xmlns:i18n="http://xml.zope.org/namespaces/i18n">
  <property name="title"></property>
@@ -56,8 +57,8 @@ _FTI_BODY = """\
 </object>
 """
 
-_TYPESTOOL_BODY = """\
-<?xml version="1.0"?>
+_TYPESTOOL_BODY = b"""\
+<?xml version="1.0" encoding="utf-8"?>
 <object name="portal_types" meta_type="CMF Types Tool">
  <property name="title"></property>
  <object name="foo_type" meta_type="Factory-based Type Information"/>
@@ -124,25 +125,19 @@ _TI_LIST = ({
     'actions': ({'id':     'view',
                  'title':  'View',
                  'action': 'string:${object_url}/bar_view',
-                 'permissions': (View,),
-                 },
+                 'permissions': (View,)},
                 {'id':     'edit',
                  'title':  'Edit',
                  'action': 'string:${object_url}/bar_edit_form',
-                 'permissions': (ModifyPortalContent,),
-                 },
+                 'permissions': (ModifyPortalContent,)},
                 {'id':     'contents',
                  'title':  'Contents',
                  'action': 'string:${object_url}/folder_contents',
-                 'permissions': (AccessContentsInformation,),
-                 },
+                 'permissions': (AccessContentsInformation,)},
                 {'id':     'metadata',
                  'title':  'Metadata',
                  'action': 'string:${object_url}/metadata_edit_form',
-                 'permissions': (ModifyPortalContent,),
-                 },
-               ),
-    })
+                 'permissions': (ModifyPortalContent,)})})
 
 _TI_LIST_WITH_FILENAME = []
 
@@ -167,6 +162,16 @@ _NORMAL_TOOL_EXPORT = """\
 </object>
 """
 
+_EXTENDED_TOOL_EXPORT = """\
+<?xml version="1.0"?>
+<object name="portal_types" meta_type="CMF Types Tool">
+ <property name="title"/>
+ <object name="foo" meta_type="Factory-based Type Information"/>
+ <object name="bar" meta_type="Scriptable Type Information"/>
+ <object name="baz" meta_type="Scriptable Type Information"/>
+</object>
+"""
+
 _FILENAME_EXPORT = """\
 <?xml version="1.0"?>
 <object name="portal_types" meta_type="CMF Types Tool">
@@ -203,20 +208,20 @@ _FOO_EXPORT = """\
  <alias from="(Default)" to="foo_view"/>
  <alias from="view" to="foo_view"/>
  <action title="View" action_id="view" category="object" condition_expr=""
-    url_expr="string:${object_url}/foo_view" 
-    icon_expr="string:${portal_url}/preview_icon.png" link_target="_new" 
+    url_expr="string:${object_url}/foo_view"
+    icon_expr="string:${portal_url}/preview_icon.png" link_target="_new"
     visible="True">
   <permission value="View"/>
  </action>
  <action title="Edit" action_id="edit" category="object" condition_expr=""
-    url_expr="string:${object_url}/foo_edit_form" 
-    icon_expr="string:${portal_url}/edit_icon.png" link_target="" 
+    url_expr="string:${object_url}/foo_edit_form"
+    icon_expr="string:${portal_url}/edit_icon.png" link_target=""
     visible="True">
   <permission value="Modify portal content"/>
  </action>
  <action title="Metadata" action_id="metadata" category="object"
     condition_expr="" url_expr="string:${object_url}/metadata_edit_form"
-    icon_expr="string:${portal_url}/metadata_icon.png" link_target="" 
+    icon_expr="string:${portal_url}/metadata_icon.png" link_target=""
     visible="True">
   <permission value="Modify portal content"/>
  </action>
@@ -245,7 +250,7 @@ _BAR_EXPORT = """\
  <alias from="(Default)" to="bar_view"/>
  <alias from="view" to="bar_view"/>
  <action title="View" action_id="view" category="object" condition_expr=""
-    url_expr="string:${object_url}/bar_view" 
+    url_expr="string:${object_url}/bar_view"
     icon_expr="" link_target="" visible="True">
   <permission value="View"/>
  </action>
@@ -289,7 +294,7 @@ _BAR_CMF21_IMPORT = """\
  <alias from="(Default)" to="bar_view"/>
  <alias from="view" to="bar_view"/>
  <action title="View" action_id="view" category="object" condition_expr=""
-    url_expr="string:${object_url}/bar_view" 
+    url_expr="string:${object_url}/bar_view"
     icon_expr="" link_target="" visible="True">
   <permission value="View"/>
  </action>
@@ -311,6 +316,50 @@ _BAR_CMF21_IMPORT = """\
 </object>
 """
 
+_BAZ_CMF21_IMPORT = """\
+<?xml version="1.0"?>
+<object name="%s" meta_type="Scriptable Type Information"
+   xmlns:i18n="http://xml.zope.org/namespaces/i18n">
+ <property name="title">Baz</property>
+ <property name="description">Baz things</property>
+ <property name="content_icon"></property>
+ <property name="content_meta_type">Baz Thing</property>
+ <property name="permission">Add portal content</property>
+ <property name="constructor_path">make_bar</property>
+ <property name="add_view_expr">string:${folder_url}/baz_add_view</property>
+ <property name="link_target"/>
+ <property name="immediate_view">baz_view</property>
+ <property name="global_allow">True</property>
+ <property name="filter_content_types">True</property>
+ <property name="allowed_content_types">
+  <element value="foo"/>
+ </property>
+ <property name="allow_discussion">True</property>
+ <alias from="(Default)" to="baz_view"/>
+ <alias from="view" to="baz_view"/>
+ <action title="View" action_id="view" category="object" condition_expr=""
+    url_expr="string:${object_url}/baz_view"
+    icon_expr="" link_target="" visible="True">
+  <permission value="View"/>
+ </action>
+ <action title="Edit" action_id="edit" category="object" condition_expr=""
+    url_expr="string:${object_url}/baz_edit_form"
+    icon_expr="" link_target="" visible="True">
+  <permission value="Modify portal content"/>
+ </action>
+ <action title="Contents" action_id="contents" category="object"
+    condition_expr="" url_expr="string:${object_url}/folder_contents"
+    icon_expr="" link_target="" visible="True">
+  <permission value="Access contents information"/>
+ </action>
+ <action title="Metadata" action_id="metadata" category="object"
+    condition_expr="" url_expr="string:${object_url}/metadata_edit_form"
+    icon_expr="" link_target="" visible="True">
+  <permission value="Modify portal content"/>
+ </action>
+</object>
+"""
+
 _UPDATE_FOO_IMPORT = """\
 <object name="foo">
  <alias from="spam" to="eggs"/>
@@ -318,22 +367,20 @@ _UPDATE_FOO_IMPORT = """\
 """
 
 
-class TypeInformationXMLAdapterTests(
-    BodyAdapterTestCase, unittest.TestCase, WarningInterceptor):
+class TypeInformationXMLAdapterTests(BodyAdapterTestCase, unittest.TestCase):
 
     layer = ExportImportZCMLLayer
 
     def _getTargetClass(self):
-        from Products.CMFCore.exportimport.typeinfo \
-                import TypeInformationXMLAdapter
+        from ..typeinfo import TypeInformationXMLAdapter
 
         return TypeInformationXMLAdapter
 
     def _populate(self, obj):
         obj.setMethodAliases({'(Default)': 'foo', 'view': 'foo'})
         obj.addAction('foo_action', 'Foo', 'string:${object_url}/foo',
-                      'python:1', (), 'Bar', 
-                      icon_expr="string:${portal_url}/icon.png")
+                      'python:1', (), 'Bar',
+                      icon_expr='string:${portal_url}/icon.png')
 
     def _verifyImport(self, obj):
         self.assertEqual(type(obj._aliases), dict)
@@ -352,26 +399,20 @@ class TypeInformationXMLAdapterTests(
         self.assertEqual(type(obj._actions[0].condition.text), str)
         self.assertEqual(obj._actions[0].condition.text, 'python:1')
         self.assertEqual(type(obj._actions[0].icon_expr.text), str)
-        self.assertEqual(obj._actions[0].icon_expr.text, 
-                                  "string:${portal_url}/icon.png")
+        self.assertEqual(obj._actions[0].icon_expr.text,
+                         'string:${portal_url}/icon.png')
 
     def setUp(self):
         self._obj = FactoryTypeInformation('foo_fti')
         self._BODY = _FTI_BODY
-        self._trap_warning_output()
-
-    def tearDown(self):
-        self._free_warning_output()
 
 
-class TypesToolXMLAdapterTests(
-    BodyAdapterTestCase, unittest.TestCase, WarningInterceptor):
+class TypesToolXMLAdapterTests(BodyAdapterTestCase, unittest.TestCase):
 
     layer = ExportImportZCMLLayer
 
     def _getTargetClass(self):
-        from Products.CMFCore.exportimport.typeinfo \
-                import TypesToolXMLAdapter
+        from ..typeinfo import TypesToolXMLAdapter
 
         return TypesToolXMLAdapter
 
@@ -381,25 +422,14 @@ class TypesToolXMLAdapterTests(
     def setUp(self):
         self._obj = TypesTool()
         self._BODY = _TYPESTOOL_BODY
-        self._trap_warning_output()
-
-    def tearDown(self):
-        self._free_warning_output()
 
 
-class _TypeInfoSetup(BaseRegistryTests, WarningInterceptor):
-
-    def setUp(self):
-        BaseRegistryTests.setUp(self)
-        self._trap_warning_output()
-
-    def tearDown(self):
-        self._free_warning_output()
+class _TypeInfoSetup(BaseRegistryTests):
 
     def _initSite(self, foo=0):
-        self.root.site = Folder(id='site')
-        site = self.root.site
-        ttool = site.portal_types = TypesTool()
+        site = Folder(id='site').__of__(self.app)
+        ttool = TypesTool()
+        getSiteManager().registerUtility(ttool, ITypesTool)
 
         if foo == 1:
             fti = _TI_LIST[0].copy()
@@ -412,7 +442,7 @@ class _TypeInfoSetup(BaseRegistryTests, WarningInterceptor):
             sti = _TI_LIST_WITH_FILENAME[1].copy()
             ttool._setObject(sti['id'], ScriptableTypeInformation(**sti))
 
-        return site
+        return site, ttool
 
 
 class exportTypesToolTests(_TypeInfoSetup):
@@ -420,7 +450,7 @@ class exportTypesToolTests(_TypeInfoSetup):
     layer = ExportImportZCMLLayer
 
     def test_empty(self):
-        from Products.CMFCore.exportimport.typeinfo import exportTypesTool
+        from ..typeinfo import exportTypesTool
 
         site = self._initSite()
         context = DummyExportContext(site)
@@ -429,51 +459,51 @@ class exportTypesToolTests(_TypeInfoSetup):
         self.assertEqual(len(context._wrote), 1)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'types.xml')
-        self._compareDOM(text, _EMPTY_TOOL_EXPORT)
+        self._compareDOM(text.decode('utf8'), _EMPTY_TOOL_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
     def test_normal(self):
-        from Products.CMFCore.exportimport.typeinfo import exportTypesTool
+        from ..typeinfo import exportTypesTool
 
-        site = self._initSite(1)
+        site, _ttool = self._initSite(1)
         context = DummyExportContext(site)
         exportTypesTool(context)
 
         self.assertEqual(len(context._wrote), 3)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'types.xml')
-        self._compareDOM(text, _NORMAL_TOOL_EXPORT)
+        self._compareDOM(text.decode('utf8'), _NORMAL_TOOL_EXPORT)
         self.assertEqual(content_type, 'text/xml')
 
         filename, text, content_type = context._wrote[2]
         self.assertEqual(filename, 'types/bar.xml')
-        self._compareDOM(text, _BAR_EXPORT % 'bar')
+        self._compareDOM(text.decode('utf8'), _BAR_EXPORT % 'bar')
         self.assertEqual(content_type, 'text/xml')
 
         filename, text, content_type = context._wrote[1]
         self.assertEqual(filename, 'types/foo.xml')
-        self._compareDOM(text, _FOO_EXPORT % 'foo')
+        self._compareDOM(text.decode('utf8'), _FOO_EXPORT % 'foo')
         self.assertEqual(content_type, 'text/xml')
 
     def test_with_filenames(self):
-        from Products.CMFCore.exportimport.typeinfo import exportTypesTool
+        from ..typeinfo import exportTypesTool
 
-        site = self._initSite(2)
+        site, _ttool = self._initSite(2)
         context = DummyExportContext(site)
         exportTypesTool(context)
 
         self.assertEqual(len(context._wrote), 3)
         filename, text, content_type = context._wrote[0]
         self.assertEqual(filename, 'types.xml')
-        self._compareDOM(text, _FILENAME_EXPORT)
+        self._compareDOM(text.decode('utf8'), _FILENAME_EXPORT)
         self.assertEqual(content_type, 'text/xml')
         filename, text, content_type = context._wrote[2]
         self.assertEqual(filename, 'types/bar_object.xml')
-        self._compareDOM(text, _BAR_EXPORT % 'bar object')
+        self._compareDOM(text.decode('utf8'), _BAR_EXPORT % 'bar object')
         self.assertEqual(content_type, 'text/xml')
         filename, text, content_type = context._wrote[1]
         self.assertEqual(filename, 'types/foo_object.xml')
-        self._compareDOM(text, _FOO_EXPORT % 'foo object')
+        self._compareDOM(text.decode('utf8'), _FOO_EXPORT % 'foo object')
         self.assertEqual(content_type, 'text/xml')
 
 
@@ -484,12 +514,12 @@ class importTypesToolTests(_TypeInfoSetup):
     _EMPTY_TOOL_EXPORT = _EMPTY_TOOL_EXPORT
     _FILENAME_EXPORT = _FILENAME_EXPORT
     _NORMAL_TOOL_EXPORT = _NORMAL_TOOL_EXPORT
+    _EXTENDED_TOOL_EXPORT = _EXTENDED_TOOL_EXPORT
 
     def test_empty_default_purge(self):
-        from Products.CMFCore.exportimport.typeinfo import importTypesTool
+        from ..typeinfo import importTypesTool
 
-        site = self._initSite(1)
-        tool = site.portal_types
+        site, tool = self._initSite(1)
 
         self.assertEqual(len(tool.objectIds()), 2)
 
@@ -500,10 +530,9 @@ class importTypesToolTests(_TypeInfoSetup):
         self.assertEqual(len(tool.objectIds()), 0)
 
     def test_empty_explicit_purge(self):
-        from Products.CMFCore.exportimport.typeinfo import importTypesTool
+        from ..typeinfo import importTypesTool
 
-        site = self._initSite(1)
-        tool = site.portal_types
+        site, tool = self._initSite(1)
 
         self.assertEqual(len(tool.objectIds()), 2)
 
@@ -514,10 +543,9 @@ class importTypesToolTests(_TypeInfoSetup):
         self.assertEqual(len(tool.objectIds()), 0)
 
     def test_empty_skip_purge(self):
-        from Products.CMFCore.exportimport.typeinfo import importTypesTool
+        from ..typeinfo import importTypesTool
 
-        site = self._initSite(1)
-        tool = site.portal_types
+        site, tool = self._initSite(1)
 
         self.assertEqual(len(tool.objectIds()), 2)
 
@@ -528,10 +556,9 @@ class importTypesToolTests(_TypeInfoSetup):
         self.assertEqual(len(tool.objectIds()), 2)
 
     def test_normal(self):
-        from Products.CMFCore.exportimport.typeinfo import importTypesTool
+        from ..typeinfo import importTypesTool
 
-        site = self._initSite()
-        tool = site.portal_types
+        site, tool = self._initSite()
 
         self.assertEqual(len(tool.objectIds()), 0)
 
@@ -542,14 +569,13 @@ class importTypesToolTests(_TypeInfoSetup):
         importTypesTool(context)
 
         self.assertEqual(len(tool.objectIds()), 2)
-        self.failUnless('foo' in tool.objectIds())
-        self.failUnless('bar' in tool.objectIds())
+        self.assertTrue('foo' in tool.objectIds())
+        self.assertTrue('bar' in tool.objectIds())
 
     def test_with_filenames(self):
-        from Products.CMFCore.exportimport.typeinfo import importTypesTool
+        from ..typeinfo import importTypesTool
 
-        site = self._initSite()
-        tool = site.portal_types
+        site, tool = self._initSite()
 
         self.assertEqual(len(tool.objectIds()), 0)
 
@@ -560,33 +586,34 @@ class importTypesToolTests(_TypeInfoSetup):
         importTypesTool(context)
 
         self.assertEqual(len(tool.objectIds()), 2)
-        self.failUnless('foo object' in tool.objectIds())
-        self.failUnless('bar object' in tool.objectIds())
+        self.assertTrue('foo object' in tool.objectIds())
+        self.assertTrue('bar object' in tool.objectIds())
 
     def test_migration(self):
-        from Products.CMFCore.exportimport.typeinfo import importTypesTool
+        from ..typeinfo import importTypesTool
 
-        site = self._initSite()
-        tool = site.portal_types
+        site, tool = self._initSite()
 
         self.assertEqual(len(tool.objectIds()), 0)
 
         context = DummyImportContext(site)
-        context._files['types.xml'] = self._NORMAL_TOOL_EXPORT
+        context._files['types.xml'] = self._EXTENDED_TOOL_EXPORT
         context._files['types/foo.xml'] = _FOO_EXPORT % 'foo'
         context._files['types/bar.xml'] = _BAR_CMF21_IMPORT % 'bar'
+        context._files['types/baz.xml'] = _BAZ_CMF21_IMPORT % 'baz'
         importTypesTool(context)
 
-        self.assertEqual(len(tool.objectIds()), 2)
-        self.failUnless('foo' in tool.objectIds())
-        self.failUnless('bar' in tool.objectIds())
+        self.assertEqual(len(tool.objectIds()), 3)
+        self.assertTrue('foo' in tool.objectIds())
+        self.assertTrue('bar' in tool.objectIds())
+        self.assertTrue('baz' in tool.objectIds())
         self.assertEqual(tool.bar.icon_expr, 'string:${portal_url}/bar.png')
+        self.assertEqual(tool.baz.icon_expr, '')
 
     def test_normal_update(self):
-        from Products.CMFCore.exportimport.typeinfo import importTypesTool
+        from ..typeinfo import importTypesTool
 
-        site = self._initSite()
-        tool = site.portal_types
+        site, tool = self._initSite()
 
         context = DummyImportContext(site)
         context._files['types.xml'] = self._NORMAL_TOOL_EXPORT
@@ -611,13 +638,13 @@ class importTypesToolTests(_TypeInfoSetup):
         self.assertEqual(tool.foo.icon_expr, 'string:${portal_url}/foo.png')
         self.assertEqual(tool.foo.immediate_view, 'foo_view')
         self.assertEqual(tool.foo._aliases,
-               {'(Default)': 'foo_view', 'view': 'foo_view', 'spam': 'eggs'})
+                         {'(Default)': 'foo_view', 'view': 'foo_view',
+                          'spam': 'eggs'})
 
     def test_action_remove(self):
-        from Products.CMFCore.exportimport.typeinfo import importTypesTool
+        from ..typeinfo import importTypesTool
 
-        site = self._initSite()
-        tool = site.portal_types
+        site, tool = self._initSite()
 
         self.assertEqual(len(tool.objectIds()), 0)
 
@@ -637,7 +664,7 @@ class importTypesToolTests(_TypeInfoSetup):
         <object name="%s" meta_type="Factory-based Type Information">
          <property name="title">Baz</property>
          <action title="View" action_id="view" category="object"
-            condition_expr="" url_expr="string:${object_url}/baz_view" 
+            condition_expr="" url_expr="string:${object_url}/baz_view"
             icon_expr="" visible="True">
           <permission value="View"/>
          </action>
@@ -648,7 +675,7 @@ class importTypesToolTests(_TypeInfoSetup):
         importTypesTool(context)
 
         self.assertEqual(len(tool.objectIds()), 1)
-        self.failUnless('baz' in tool.objectIds())
+        self.assertTrue('baz' in tool.objectIds())
         baz = tool['baz']
         actions = baz.listActions()
         self.assertEqual(len(actions), 1)
@@ -666,7 +693,7 @@ class importTypesToolTests(_TypeInfoSetup):
         importTypesTool(context)
 
         self.assertEqual(len(tool.objectIds()), 1)
-        self.failUnless('baz' in tool.objectIds())
+        self.assertTrue('baz' in tool.objectIds())
         baz = tool['baz']
         actions = baz.listActions()
         self.assertEqual(len(actions), 0)
@@ -679,7 +706,3 @@ def test_suite():
         unittest.makeSuite(exportTypesToolTests),
         unittest.makeSuite(importTypesToolTests),
         ))
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
