@@ -10,21 +10,21 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Types tool xml adapters and setup handlers. """
-
-from zope.component import adapts
+"""Types tool xml adapters and setup handlers.
+"""
 
 from Products.GenericSetup.interfaces import ISetupEnviron
-from Products.GenericSetup.utils import exportObjects
 from Products.GenericSetup.utils import I18NURI
-from Products.GenericSetup.utils import importObjects
 from Products.GenericSetup.utils import ObjectManagerHelpers
 from Products.GenericSetup.utils import PropertyManagerHelpers
 from Products.GenericSetup.utils import XMLAdapterBase
+from Products.GenericSetup.utils import exportObjects
+from Products.GenericSetup.utils import importObjects
+from zope.component import adapts
+from zope.component import getSiteManager
 
-from Products.CMFCore.interfaces import ITypeInformation
-from Products.CMFCore.interfaces import ITypesTool
-from Products.CMFCore.utils import getToolByName
+from ..interfaces import ITypeInformation
+from ..interfaces import ITypesTool
 
 
 class TypeInformationXMLAdapter(XMLAdapterBase, PropertyManagerHelpers):
@@ -76,7 +76,8 @@ class TypeInformationXMLAdapter(XMLAdapterBase, PropertyManagerHelpers):
                 continue
             if child.getAttribute('name') != 'content_icon':
                 continue
-            icon = 'string:${portal_url}/%s' % self._getNodeText(child)
+            text = self._getNodeText(child)
+            icon = 'string:${portal_url}/%s' % text if text else ''
             new_child = self._doc.createElement('property')
             new_child.setAttribute('name', 'icon_expr')
             new_child.appendChild(self._doc.createTextNode(icon))
@@ -84,8 +85,7 @@ class TypeInformationXMLAdapter(XMLAdapterBase, PropertyManagerHelpers):
 
     def _extractAliases(self):
         fragment = self._doc.createDocumentFragment()
-        aliases = self.context.getMethodAliases().items()
-        aliases.sort()
+        aliases = sorted(self.context.getMethodAliases().items())
         for k, v in aliases:
             child = self._doc.createElement('alias')
             child.setAttribute('from', k)
@@ -113,7 +113,6 @@ class TypeInformationXMLAdapter(XMLAdapterBase, PropertyManagerHelpers):
             ai_info = ai.getMapping()
             child = self._doc.createElement('action')
             child.setAttribute('title', ai_info['title'])
-            child.setAttribute('description', ai_info['description'])
             child.setAttribute('action_id', ai_info['id'])
             child.setAttribute('category', ai_info['category'])
             child.setAttribute('condition_expr', ai_info['condition'])
@@ -137,7 +136,6 @@ class TypeInformationXMLAdapter(XMLAdapterBase, PropertyManagerHelpers):
                 continue
             title = str(child.getAttribute('title'))
             id = str(child.getAttribute('action_id'))
-            description = str(child.getAttribute('description'))
             category = str(child.getAttribute('category'))
             condition = str(child.getAttribute('condition_expr'))
             action = str(child.getAttribute('url_expr'))
@@ -165,14 +163,12 @@ class TypeInformationXMLAdapter(XMLAdapterBase, PropertyManagerHelpers):
             else:
                 if action_obj is None:
                     self.context.addAction(id, title, action, condition,
-                                           tuple(permissions), category, visible,
-                                           icon_expr=icon_expr, 
-                                           link_target=link_target,
-                                           description=description)
+                                           tuple(permissions), category,
+                                           visible, icon_expr=icon_expr,
+                                           link_target=link_target)
                 else:
-                    action_obj.edit(title=title, description=description,
-                                    action=action, icon_expr=icon_expr, 
-                                    condition=condition, 
+                    action_obj.edit(title=title, action=action,
+                                    icon_expr=icon_expr, condition=condition,
                                     permissions=tuple(permissions),
                                     visible=visible, link_target=link_target)
 
@@ -215,8 +211,8 @@ class TypesToolXMLAdapter(XMLAdapterBase, ObjectManagerHelpers,
 def importTypesTool(context):
     """Import types tool and content types from XML files.
     """
-    site = context.getSite()
-    tool = getToolByName(site, 'portal_types', None)
+    sm = getSiteManager(context.getSite())
+    tool = sm.queryUtility(ITypesTool)
     if tool is None:
         logger = context.getLogger('types')
         logger.debug('Nothing to import.')
@@ -224,11 +220,12 @@ def importTypesTool(context):
 
     importObjects(tool, '', context)
 
+
 def exportTypesTool(context):
     """Export types tool content types as a set of XML files.
     """
-    site = context.getSite()
-    tool = getToolByName(site, 'portal_types', None)
+    sm = getSiteManager(context.getSite())
+    tool = sm.queryUtility(ITypesTool)
     if tool is None:
         logger = context.getLogger('types')
         logger.debug('Nothing to export.')
