@@ -11,48 +11,48 @@
 #
 ##############################################################################
 """ Unit test mixin classes and layers.
-
-$Id: testing.py 114574 2010-07-11 11:20:20Z hannosch $
 """
 
 from OFS.SimpleItem import SimpleItem
-from Testing.ZopeTestCase import installPackage
+from Products.GenericSetup.utils import BodyAdapterBase
 from Testing.ZopeTestCase.layer import ZopeLite
+from Zope2.App import zcml
 from zope.component import adapts
+from zope.component.hooks import setHooks
 from zope.i18n.interfaces import IUserPreferredLanguages
-from zope.interface import implements
+from zope.interface import implementer
 from zope.interface.verify import verifyClass
 from zope.publisher.interfaces.http import IHTTPRequest
-from zope.site.hooks import setHooks
-from zope.testing import testrunner
 from zope.testing.cleanup import cleanUp
 
-from Products.CMFCore.interfaces import IWorkflowDefinition
-from Products.GenericSetup.utils import BodyAdapterBase
-
-# BBB for Zope 2.12
-try:
-    from Zope2.App import zcml
-except ImportError:
-    from Products.Five import zcml
+from .interfaces import IWorkflowDefinition
+from .utils import HAS_ZSERVER
 
 
 class ConformsToFolder:
 
-    def test_folder_interfaces(self):
-        from webdav.interfaces import IWriteLock
-        from Products.CMFCore.interfaces import IDynamicType
-        from Products.CMFCore.interfaces import IFolderish
-        from Products.CMFCore.interfaces import IMutableMinimalDublinCore
-
-        verifyClass(IDynamicType, self._getTargetClass())
-        verifyClass(IFolderish, self._getTargetClass())
-        verifyClass(IMutableMinimalDublinCore, self._getTargetClass())
+    def test_conforms_to_IWritelock(self):
+        try:
+            from OFS.interfaces import IWriteLock
+        except ImportError:
+            from webdav.interfaces import IWriteLock
         verifyClass(IWriteLock, self._getTargetClass())
 
+    def test_conforms_to_IDynamicType(self):
+        from .interfaces import IDynamicType
+        verifyClass(IDynamicType, self._getTargetClass())
+
+    def test_conforms_to_IFolderish(self):
+        from .interfaces import IFolderish
+        verifyClass(IFolderish, self._getTargetClass())
+
+    def test_conforms_to_IMutableDublinCore(self):
+        from .interfaces import IMutableMinimalDublinCore
+        verifyClass(IMutableMinimalDublinCore, self._getTargetClass())
+
     def test_folder_extra_interfaces(self):
         # in the long run this interface will become deprecated
-        from Products.CMFCore.interfaces import IOpaqueItemManager
+        from .interfaces import IOpaqueItemManager
 
         verifyClass(IOpaqueItemManager, self._getTargetClass())
 
@@ -60,34 +60,35 @@ class ConformsToFolder:
 class ConformsToContent:
 
     def test_content_interfaces(self):
-        from Products.CMFCore.interfaces import ICatalogableDublinCore
-        from Products.CMFCore.interfaces import IContentish
-        from Products.CMFCore.interfaces import IDublinCore
-        from Products.CMFCore.interfaces import IDynamicType
-        from Products.CMFCore.interfaces import IMutableDublinCore
+        from .interfaces import ICatalogableDublinCore
+        from .interfaces import IContentish
+        from .interfaces import IDublinCore
+        from .interfaces import IDynamicType
+        from .interfaces import IMutableDublinCore
         from Products.GenericSetup.interfaces import IDAVAware
 
         verifyClass(ICatalogableDublinCore, self._getTargetClass())
         verifyClass(IContentish, self._getTargetClass())
-        verifyClass(IDAVAware, self._getTargetClass())
         verifyClass(IDublinCore, self._getTargetClass())
         verifyClass(IDynamicType, self._getTargetClass())
         verifyClass(IMutableDublinCore, self._getTargetClass())
+        if HAS_ZSERVER:
+            verifyClass(IDAVAware, self._getTargetClass())
 
     def test_content_extra_interfaces(self):
         # in the long run these interfaces will become deprecated
-        from Products.CMFCore.interfaces import ICatalogAware
-        from Products.CMFCore.interfaces import IOpaqueItemManager
-        from Products.CMFCore.interfaces import IWorkflowAware
+        from .interfaces import ICatalogAware
+        from .interfaces import IOpaqueItemManager
+        from .interfaces import IWorkflowAware
 
         verifyClass(ICatalogAware, self._getTargetClass())
         verifyClass(IOpaqueItemManager, self._getTargetClass())
         verifyClass(IWorkflowAware, self._getTargetClass())
 
 
+@implementer(IUserPreferredLanguages)
 class BrowserLanguages(object):
 
-    implements(IUserPreferredLanguages)
     adapts(IHTTPRequest)
 
     def __init__(self, context):
@@ -97,28 +98,6 @@ class BrowserLanguages(object):
         return ('test',)
 
 
-class OFSZCMLLayer(ZopeLite):
-
-    @classmethod
-    def setUp(cls):
-        import zope.component
-        import OFS
-        import Products.Five
-        zcml.load_config('meta.zcml', zope.component)
-        try:
-            zcml.load_config('meta.zcml', OFS)
-            zcml.load_config('configure.zcml', OFS)
-        except IOError:  # Zope <= 2.13.0a2
-            zcml.load_config('meta.zcml', Products.Five)
-        # In Zope 2.12 this does an implicit commit
-        installPackage('OFS')
-        setHooks()
-
-    @classmethod
-    def tearDown(cls):
-        cleanUp()
-
-
 class EventZCMLLayer(ZopeLite):
 
     @classmethod
@@ -127,10 +106,7 @@ class EventZCMLLayer(ZopeLite):
         import Products
 
         zcml.load_config('meta.zcml', Products.Five)
-        try:
-            zcml.load_config('event.zcml', OFS)
-        except IOError:  # Zope <= 2.12.x
-            zcml.load_config('event.zcml', Products.Five)
+        zcml.load_config('event.zcml', OFS)
         zcml.load_config('event.zcml', Products.CMFCore)
         setHooks()
 
@@ -159,13 +135,15 @@ class TraversingEventZCMLLayer(ZopeLite):
 
     @classmethod
     def testSetUp(cls):
+        import OFS
         import Products.Five
         import zope.traversing
 
         zcml.load_config('meta.zcml', Products.Five)
         zcml.load_config('configure.zcml', zope.traversing)
-        zcml.load_config('event.zcml', Products.Five)
+        zcml.load_config('event.zcml', OFS)
         zcml.load_config('event.zcml', Products.CMFCore)
+        zcml.load_config('tool.zcml', Products.CMFCore)
         setHooks()
 
     @classmethod
@@ -210,10 +188,9 @@ _DUMMY_ZCML = """\
 """
 
 
+@implementer(IWorkflowDefinition)
 class DummyWorkflow(SimpleItem):
 
-    implements(IWorkflowDefinition)
-
     meta_type = 'Dummy Workflow'
 
     def __init__(self, id):
@@ -239,20 +216,10 @@ class ExportImportZCMLLayer(ZopeLite):
         import Products.CMFCore
         import Products.CMFCore.exportimport
 
-        try:
-            zcml.load_config('meta.zcml', Zope2.App)
-        except IOError:  # Zope <= 2.12.x
-            pass
-
+        zcml.load_config('meta.zcml', Zope2.App)
         zcml.load_config('meta.zcml', Products.Five)
-
-        try:
-            zcml.load_config('permissions.zcml', AccessControl)
-        except IOError:  # Zope <= 2.12.x
-            pass
-
+        zcml.load_config('permissions.zcml', AccessControl)
         zcml.load_config('permissions.zcml', Products.Five)
-
         zcml.load_config('meta.zcml', Products.GenericSetup)
         zcml.load_config('configure.zcml', Products.GenericSetup)
         zcml.load_config('permissions.zcml', Products.CMFCore)
@@ -264,10 +231,3 @@ class ExportImportZCMLLayer(ZopeLite):
     @classmethod
     def testTearDown(cls):
         cleanUp()
-
-
-def run(test_suite):
-    options = testrunner.get_options()
-    options.resume_layer = None
-    options.resume_number = 0
-    testrunner.run_with_options(options, test_suite)
