@@ -11,30 +11,31 @@
 #
 ##############################################################################
 """ Unit test dummies.
-
-$Id: dummy.py 110577 2010-04-07 06:33:17Z jens $
 """
 
-from Acquisition import Implicit, aq_base, aq_inner, aq_parent
+from Acquisition import Implicit
+from Acquisition import aq_base
+from Acquisition import aq_inner
+from Acquisition import aq_parent
+from App.Common import rfc1123_date
 from OFS.event import ObjectWillBeAddedEvent
 from OFS.event import ObjectWillBeRemovedEvent
 from OFS.interfaces import IObjectManager
 from OFS.SimpleItem import Item
-from webdav.common import rfc1123_date
 from zope.component.factory import Factory
-from zope.container.contained import notifyContainerModified
 from zope.container.contained import ObjectAddedEvent
 from zope.container.contained import ObjectRemovedEvent
+from zope.container.contained import notifyContainerModified
 from zope.event import notify
-from zope.interface import implements
+from zope.interface import implementer
 
-from Products.CMFCore.interfaces import IContentish
-from Products.CMFCore.interfaces import ISiteRoot
-from Products.CMFCore.interfaces import ITypeInformation
-from Products.CMFCore.ActionProviderBase import ActionProviderBase
-from Products.CMFCore.PortalContent import PortalContent
-
-from security import OmnipotentUser
+from ...ActionProviderBase import ActionProviderBase
+from ...interfaces import IContentish
+from ...interfaces import ISiteRoot
+from ...interfaces import ITypeInformation
+from ...PortalContent import PortalContent
+from ..base.security import DummyUser
+from ..base.security import OmnipotentUser
 
 
 class DummyObject(Implicit):
@@ -43,9 +44,9 @@ class DummyObject(Implicit):
     Comes with getIconURL and restrictedTraverse
     methods.
     """
-    def __init__(self, id='dummy',**kw):
+    def __init__(self, id='dummy', **kw):
         self._id = id
-        self.__dict__.update( kw )
+        self.__dict__.update(kw)
 
     def __str__(self):
         return self._id
@@ -62,7 +63,7 @@ class DummyObject(Implicit):
         path_elements.reverse()
         while path_elements:
             path_element = path_elements.pop()
-            parent = getattr(parent, path_element) 
+            parent = getattr(parent, path_element)
 
         return parent
 
@@ -76,14 +77,14 @@ class DummyObject(Implicit):
         return self._id
 
 
+@implementer(ITypeInformation)
 class DummyType(DummyObject):
     """ A Dummy Type object """
-    implements(ITypeInformation)
 
     def __init__(self, id='Dummy Content', title='Dummy Content', actions=()):
         """ To fake out some actions, pass in a sequence of tuples where the
         first element represents the ID or alias of the action and the
-        second element is the path to the object to be invoked, such as 
+        second element is the path to the object to be invoked, such as
         a page template.
         """
 
@@ -113,27 +114,27 @@ class DummyType(DummyObject):
         return True
 
 
-class DummyContent( PortalContent, Item ):
+@implementer(IContentish)
+class DummyContent(PortalContent, Item):
     """
     A Dummy piece of PortalContent
     """
-    implements(IContentish)
 
     meta_type = 'Dummy'
     portal_type = 'Dummy Content'
     url = 'foo_url'
     after_add_called = before_delete_called = 0
 
-    def __init__( self, id='dummy', *args, **kw ):
+    def __init__(self, id='dummy', *args, **kw):
         self.id = id
         self._args = args
         self._kw = {}
-        self._kw.update( kw )
+        self._kw.update(kw)
 
         self.reset()
-        self.catalog = kw.get('catalog',0)
-        self.url = kw.get('url',None)
-        self.view_id = kw.get('view_id',None)
+        self.catalog = kw.get('catalog', 0)
+        self.url = kw.get('url', None)
+        self.view_id = kw.get('view_id', None)
 
     def manage_afterAdd(self, item, container):
         self.after_add_called = 1
@@ -144,38 +145,38 @@ class DummyContent( PortalContent, Item ):
     def absolute_url(self):
         return self.url
 
-    def reset( self ):
+    def reset(self):
         self.after_add_called = self.before_delete_called = 0
 
     # Make sure normal Database export/import stuff doesn't trip us up.
     def _getCopy(self, container):
-        return DummyContent( self.id, catalog=self.catalog )
+        return DummyContent(self.id, catalog=self.catalog)
 
-    def _safe_get(self,attr):
+    def _safe_get(self, attr):
         if self.catalog:
-            return getattr(self,attr,'')
+            return getattr(self, attr, '')
         else:
-            return getattr(self,attr)
+            return getattr(self, attr)
 
-    def Title( self ):
+    def Title(self):
         return self.title
 
     def listCreators(self):
         return self._safe_get('creators')
 
-    def Subject( self ):
+    def Subject(self):
         return self._safe_get('subject')
 
-    def Description( self ):
+    def Description(self):
         return self._safe_get('description')
 
-    def created( self ):
+    def created(self):
         return self._safe_get('created_date')
 
-    def modified( self ):
+    def modified(self):
         return self._safe_get('modified_date')
 
-    def Type( self ):
+    def Type(self):
         return 'Dummy Content Title'
 
     def __call__(self):
@@ -189,6 +190,7 @@ class DummyContent( PortalContent, Item ):
             else:
                 return template()
 
+
 DummyFactory = Factory(DummyContent)
 
 
@@ -197,31 +199,31 @@ class DummyFactoryDispatcher:
     """
     Dummy Product Factory Dispatcher
     """
-    def __init__( self, folder ):
+    def __init__(self, folder):
         self._folder = folder
 
     def getId(self):
         return 'DummyFactoryDispatcher'
 
-    def addFoo( self, id, *args, **kw ):
+    def addFoo(self, id, *args, **kw):
         if getattr(self._folder, '_prefix', None):
-            id = '%s_%s' % ( self._folder._prefix, id )
+            id = '%s_%s' % (self._folder._prefix, id)
         foo = DummyContent(id, *args, **kw)
         self._folder._setObject(id, foo, suppress_events=True)
         if getattr(self._folder, '_prefix', None):
             return id
 
-    __roles__ = ( 'FooAdder', )
-    __allow_access_to_unprotected_subobjects__ = { 'addFoo' : 1 }
+    __roles__ = ('FooAdder',)
+    __allow_access_to_unprotected_subobjects__ = {'addFoo': 1}
 
 
+@implementer(IObjectManager)
 class DummyFolder(DummyObject):
 
     """Dummy Container for testing.
     """
-    implements(IObjectManager)
 
-    def __init__( self, id='dummy', fake_product=0, prefix='' ):
+    def __init__(self, id='dummy', fake_product=0, prefix=''):
         self._prefix = prefix
         self._id = id
 
@@ -235,7 +237,7 @@ class DummyFolder(DummyObject):
     def _delOb(self, id):
         delattr(self, id)
 
-    def _getOb( self, id ):
+    def _getOb(self, id):
         return getattr(self, id)
 
     def _setObject(self, id, object, suppress_events=False):
@@ -261,7 +263,7 @@ class DummyFolder(DummyObject):
 
     def getPhysicalPath(self):
         p = aq_parent(aq_inner(self))
-        path = (self._id, )
+        path = (self._id,)
         if p is not None:
             path = p.getPhysicalPath() + path
         return path
@@ -281,16 +283,17 @@ class DummyFolder(DummyObject):
     def getTypeInfo(self):
         return self.portal_types.getTypeInfo(self)  # Can return None.
 
+
+@implementer(ISiteRoot)
 class DummySite(DummyFolder):
     """ A dummy portal folder.
     """
 
     _domain = 'http://www.foobar.com'
     _path = 'bar'
-    implements(ISiteRoot)
 
     def absolute_url(self, relative=0):
-        return '/'.join( (self._domain, self._path, self._id) )
+        return '/'.join((self._domain, self._path, self._id))
 
     def getPhysicalPath(self):
         return ('', self._path, self._id)
@@ -314,33 +317,6 @@ class DummySite(DummyFolder):
         return getattr(self, id, default)
 
 
-class DummyUser(Implicit):
-    """ A dummy User.
-    """
-
-    def __init__(self, id='dummy'):
-        self.id = id
-
-    def getId(self):
-        return self.id
-
-    getUserName = getId
-
-    def allowed(self, object, object_roles=None):
-        if object_roles is None or 'Anonymous' in object_roles:
-            return 1
-        for role in object_roles:
-            if role in self.getRolesInContext(object):
-                return 1
-        return 0
-
-    def getRolesInContext(self, object):
-        return ('Authenticated', 'Dummy', 'Member')
-
-    def _check_context(self, object):
-        return 1
-
-
 class DummyUserFolder(Implicit):
     """ A dummy User Folder with 2 dummy Users.
     """
@@ -348,9 +324,9 @@ class DummyUserFolder(Implicit):
     id = 'acl_users'
 
     def __init__(self):
-        setattr( self, 'user_foo', DummyUser(id='user_foo') )
-        setattr( self, 'user_bar', DummyUser(id='user_bar') )
-        setattr( self, 'all_powerful_Oz', OmnipotentUser() )
+        setattr(self, 'user_foo', DummyUser(id='user_foo'))
+        setattr(self, 'user_bar', DummyUser(id='user_bar'))
+        setattr(self, 'all_powerful_Oz', OmnipotentUser())
 
     def getUsers(self):
         pass
@@ -366,7 +342,7 @@ class DummyUserFolder(Implicit):
             delattr(self, user_id)
 
 
-class DummyTool(Implicit,ActionProviderBase):
+class DummyTool(Implicit, ActionProviderBase):
     """
     This is a Dummy Tool that behaves as a
     a MemberShipTool, a URLTool and an
@@ -428,7 +404,7 @@ class DummyCachingManager:
         return (
              ('foo', 'Foo'), ('bar', 'Bar'),
              ('test_path', '/'.join(content.getPhysicalPath())),
-             )
+            )
 
     def getModTimeAndETag(self, content, view_method, keywords, time=None):
         return (None, None, False)
@@ -437,7 +413,8 @@ class DummyCachingManager:
         return ('baz',)
 
 
-FAKE_ETAG = None # '--FAKE ETAG--'
+FAKE_ETAG = None  # '--FAKE ETAG--'
+
 
 class DummyCachingManagerWithPolicy(DummyCachingManager):
 
@@ -448,7 +425,7 @@ class DummyCachingManagerWithPolicy(DummyCachingManager):
     def getHTTPCachingHeaders(self, content, view_name, keywords, time=None):
         # if the object has a modified method, add it as last-modified
         if hasattr(content, 'modified'):
-            headers = ( ('Last-modified', rfc1123_date(content.modified()) ), )
+            headers = (('Last-modified', rfc1123_date(content.modified())),)
         return headers
 
     def getModTimeAndETag(self, content, view_method, keywords, time=None):
