@@ -10,68 +10,71 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for ActionInformation module. """
+""" Unit tests for ActionInformation module.
+"""
 
 import unittest
-import Testing
 
 from OFS.Folder import manage_addFolder
 from Products.PythonScripts.PythonScript import manage_addPythonScript
+from zope.component import getSiteManager
 from zope.interface.verify import verifyClass
+from zope.testing.cleanup import cleanUp
 
-from Products.CMFCore.Expression import createExprContext
-from Products.CMFCore.Expression import Expression
-from Products.CMFCore.testing import FunctionalZCMLLayer
-from Products.CMFCore.tests.base.dummy import DummyContent
-from Products.CMFCore.tests.base.dummy import DummySite
-from Products.CMFCore.tests.base.dummy import DummyTool as DummyMembershipTool
-from Products.CMFCore.tests.base.testcase import SecurityTest
-from Products.CMFCore.tests.base.testcase import TransactionalTest
+from ..Expression import Expression
+from ..Expression import createExprContext
+from ..interfaces import IMembershipTool
+from ..testing import FunctionalZCMLLayer
+from .base.dummy import DummyContent
+from .base.dummy import DummySite
+from .base.dummy import DummyTool as DummyMembershipTool
+from .base.testcase import SecurityTest
+from .base.testcase import TransactionalTest
 
 
 class ActionCategoryTests(unittest.TestCase):
 
     def _makeOne(self, *args, **kw):
-        from Products.CMFCore.ActionInformation import ActionCategory
+        from ..ActionInformation import ActionCategory
 
         return ActionCategory(*args, **kw)
 
     def test_interfaces(self):
-        from Products.CMFCore.ActionInformation import ActionCategory
-        from Products.CMFCore.interfaces import IActionCategory
+        from ..ActionInformation import ActionCategory
+        from ..interfaces import IActionCategory
 
         verifyClass(IActionCategory, ActionCategory)
 
     def test_listActions(self):
-        from Products.CMFCore.ActionInformation import Action
+        from ..ActionInformation import Action
 
         ac = self._makeOne('foo')
-        self.assertEqual( ac.listActions(), () )
+        self.assertEqual(ac.listActions(), ())
 
         baz = Action('baz')
         ac._setObject('baz', baz)
-        self.assertEqual( ac.listActions(), (baz,) )
+        self.assertEqual(ac.listActions(), (baz,))
 
 
 class ActionTests(unittest.TestCase):
 
     def _makeOne(self, *args, **kw):
-        from Products.CMFCore.ActionInformation import Action
+        from ..ActionInformation import Action
 
         return Action(*args, **kw)
 
     def test_interfaces(self):
-        from Products.CMFCore.ActionInformation import Action
-        from Products.CMFCore.interfaces import IAction
+        from ..ActionInformation import Action
+        from ..interfaces import IAction
 
         verifyClass(IAction, Action)
 
     def test_getInfoData_empty(self):
-        WANTED = ( {'available': True, 'category': '', 'description': '',
-                    'id': 'foo', 'icon': '', 'permissions': (), 'title': '',
-                    'url': '', 'visible': True, 'link_target': None}, [] )
+        WANTED = ({'available': True, 'category': '', 'description': '',
+                   'id': 'foo', 'icon': '', 'permissions': (), 'title': '',
+                   'url': '', 'visible': True, 'link_target': None}, [])
         a = self._makeOne('foo')
-        self.assertEqual( a.getInfoData(), WANTED )
+        self.assertEqual(a.getInfoData(), WANTED)
 
     def test_getInfoData_normal(self):
         a = self._makeOne('foo',
@@ -83,27 +86,40 @@ class ActionTests(unittest.TestCase):
                           permissions=('View',),
                           visible=False,
                           link_target='_top')
-        WANTED = ( {'available': True, 'category': '',
-                    'description': 'Foo description.',
-                    'id': 'foo', 'icon': a.icon_expr_object,
-                    'permissions': ('View',), 'title': 'Foo Title',
-                    'url': a.url_expr_object, 'visible': False,
-                    'link_target': a.link_target },
-                   ['url', 'icon'] )
-        self.assertEqual( a.getInfoData(), WANTED )
+        WANTED = ({'available': True, 'category': '',
+                   'description': 'Foo description.',
+                   'id': 'foo', 'icon': a.icon_expr_object,
+                   'permissions': ('View',), 'title': 'Foo Title',
+                   'url': a.url_expr_object, 'visible': False,
+                   'link_target': a.link_target},
+                  ['url', 'icon'])
+        self.assertEqual(a.getInfoData(), WANTED)
 
     def test_manage_propertiesForm_allows_adding(self):
-        from OFS.SimpleItem import SimpleItem
+        from OFS.Folder import Folder
+
         def _header(*args, **kw):
             return 'HEADER'
+
         def _footer(*args, **kw):
             return 'HEADER'
-        container = SimpleItem()
+
+        def _main(*args, **kw):
+            return 'MAIN'
+
+        container = Folder('folder')
+        # Mocking out a bit of the ZMI
+        container.ZopeVersion = lambda **kw: '4.99'
 
         container.REQUEST = request = DummyRequest()
         request.set('manage_page_header', _header)
         request.set('manage_page_footer', _footer)
+        request.set('manage_main', _main)
+        request.set('RESPONSE', None)
         request.set('BASEPATH1', '/one/two')
+        request.set('URL', '/one/two/manage_propertiesForm')
+        request.set('URL0', '/one')
+        request.set('URL1', '/one/two')
         setattr(request, 'URL1', '/one/two')
         request._steps = ['one', 'two']
 
@@ -111,9 +127,12 @@ class ActionTests(unittest.TestCase):
         container._getProductRegistryData = prd.get
 
         a = self._makeOne('extensible').__of__(container)
+        # EEK short-term solution until a new Zope release is out
+        from App.special_dtml import DTMLFile
+        DTMLFile.encoding = None
         form_html = a.manage_propertiesForm(request)
 
-        self.failUnless('value=" Add "' in form_html)
+        self.assertIn('value="Add"', form_html)
 
     def test_clearExprObjects(self):
         """When a *_expr property is set, a *_expr_object attribute is
@@ -128,43 +147,55 @@ class ActionTests(unittest.TestCase):
                           permissions=('View',),
                           visible=False,
                           link_target='_top')
-        self.failUnless(hasattr(a, 'icon_expr_object'))
-        self.failUnless(hasattr(a, 'url_expr_object'))
-        self.failIf(hasattr(a, 'available_expr_object'))
+        self.assertTrue(hasattr(a, 'icon_expr_object'))
+        self.assertTrue(hasattr(a, 'url_expr_object'))
+        self.assertFalse(hasattr(a, 'available_expr_object'))
         a.manage_changeProperties(
             icon_expr='', url_expr='', available_expr='')
-        self.failIf(hasattr(a, 'icon_expr_object'))
-        self.failIf(hasattr(a, 'url_expr_object'))
-        self.failIf(hasattr(a, 'available_expr_object'))
+        self.assertFalse(hasattr(a, 'icon_expr_object'))
+        self.assertFalse(hasattr(a, 'url_expr_object'))
+        self.assertFalse(hasattr(a, 'available_expr_object'))
 
 
 class DummyRequest:
+
+    charset = 'UTF-8'
+    URL = ''
+
     def __init__(self):
         self._data = {}
+
     def set(self, k, v):
         self._data[k] = v
+
     def get(self, k, default):
         return self._data.get(k, default)
+
     def __getitem__(self, k):
         return self._data[k]
+
     def __len__(self):
         return len(self._data)
 
+    def getVirtualRoot(self):
+        return '/'
+
+
 class ActionInfoTests(unittest.TestCase):
 
     def _makeOne(self, *args, **kw):
-        from Products.CMFCore.ActionInformation import ActionInfo
+        from ..ActionInformation import ActionInfo
 
         return ActionInfo(*args, **kw)
 
     def test_interfaces(self):
-        from Products.CMFCore.ActionInformation import ActionInfo
-        from Products.CMFCore.interfaces import IActionInfo
+        from ..ActionInformation import ActionInfo
+        from ..interfaces import IActionInfo
 
         verifyClass(IActionInfo, ActionInfo)
 
     def test_create_from_Action(self):
-        from Products.CMFCore.ActionInformation import Action
+        from ..ActionInformation import Action
 
         WANTED = {'allowed': True, 'available': True, 'category': '',
                   'description': '', 'icon': '', 'id': 'foo', 'title': '',
@@ -174,18 +205,18 @@ class ActionInfoTests(unittest.TestCase):
         ec = None
         ai = self._makeOne(action, ec)
 
-        self.assertEqual( ai['id'], WANTED['id'] )
-        self.assertEqual( ai['title'], WANTED['title'] )
-        self.assertEqual( ai['description'], WANTED['description'] )
-        self.assertEqual( ai['url'], WANTED['url'] )
-        self.assertEqual( ai['category'], WANTED['category'] )
-        self.assertEqual( ai['visible'], WANTED['visible'] )
-        self.assertEqual( ai['available'], WANTED['available'] )
-        self.assertEqual( ai['allowed'], WANTED['allowed'] )
-        self.assertEqual( ai, WANTED )
+        self.assertEqual(ai['id'], WANTED['id'])
+        self.assertEqual(ai['title'], WANTED['title'])
+        self.assertEqual(ai['description'], WANTED['description'])
+        self.assertEqual(ai['url'], WANTED['url'])
+        self.assertEqual(ai['category'], WANTED['category'])
+        self.assertEqual(ai['visible'], WANTED['visible'])
+        self.assertEqual(ai['available'], WANTED['available'])
+        self.assertEqual(ai['allowed'], WANTED['allowed'])
+        self.assertEqual(ai, WANTED)
 
     def test_create_from_ActionInformation(self):
-        from Products.CMFCore.ActionInformation import ActionInformation
+        from ..ActionInformation import ActionInformation
 
         WANTED = {'allowed': True, 'available': True, 'category': 'object',
                   'description': '', 'id': 'foo', 'title': 'foo', 'url': '',
@@ -195,46 +226,51 @@ class ActionInfoTests(unittest.TestCase):
         ec = None
         ai = self._makeOne(action, ec)
 
-        self.assertEqual( ai['id'], WANTED['id'] )
-        self.assertEqual( ai['title'], WANTED['title'] )
-        self.assertEqual( ai['description'], WANTED['description'] )
-        self.assertEqual( ai['url'], WANTED['url'] )
-        self.assertEqual( ai['icon'], WANTED['icon'] )
-        self.assertEqual( ai['category'], WANTED['category'] )
-        self.assertEqual( ai['visible'], WANTED['visible'] )
-        self.assertEqual( ai['available'], WANTED['available'] )
-        self.assertEqual( ai['allowed'], WANTED['allowed'] )
-        self.assertEqual( ai, WANTED )
+        self.assertEqual(ai['id'], WANTED['id'])
+        self.assertEqual(ai['title'], WANTED['title'])
+        self.assertEqual(ai['description'], WANTED['description'])
+        self.assertEqual(ai['url'], WANTED['url'])
+        self.assertEqual(ai['icon'], WANTED['icon'])
+        self.assertEqual(ai['category'], WANTED['category'])
+        self.assertEqual(ai['visible'], WANTED['visible'])
+        self.assertEqual(ai['available'], WANTED['available'])
+        self.assertEqual(ai['allowed'], WANTED['allowed'])
+        self.assertEqual(ai, WANTED)
 
     def test_create_from_dict(self):
         WANTED = {'allowed': True, 'available': True, 'category': 'object',
                   'id': 'foo', 'title': 'foo', 'url': '', 'visible': True,
-                  'icon': '' , 'link_target': None}
+                  'icon': '', 'link_target': None}
 
         action = {'name': 'foo', 'url': ''}
         ec = None
         ai = self._makeOne(action, ec)
 
-        self.assertEqual( ai['id'], WANTED['id'] )
-        self.assertEqual( ai['title'], WANTED['title'] )
-        self.assertEqual( ai['url'], WANTED['url'] )
-        self.assertEqual( ai['icon'], WANTED['icon'] )
-        self.assertEqual( ai['category'], WANTED['category'] )
-        self.assertEqual( ai['visible'], WANTED['visible'] )
-        self.assertEqual( ai['available'], WANTED['available'] )
-        self.assertEqual( ai['allowed'], WANTED['allowed'] )
-        self.assertEqual( ai, WANTED )
+        self.assertEqual(ai['id'], WANTED['id'])
+        self.assertEqual(ai['title'], WANTED['title'])
+        self.assertEqual(ai['url'], WANTED['url'])
+        self.assertEqual(ai['icon'], WANTED['icon'])
+        self.assertEqual(ai['category'], WANTED['category'])
+        self.assertEqual(ai['visible'], WANTED['visible'])
+        self.assertEqual(ai['available'], WANTED['available'])
+        self.assertEqual(ai['allowed'], WANTED['allowed'])
+        self.assertEqual(ai, WANTED)
 
 
 class ActionInfoSecurityTests(SecurityTest):
 
     def setUp(self):
         SecurityTest.setUp(self)
-        self.site = DummySite('site').__of__(self.root)
-        self.site._setObject( 'portal_membership', DummyMembershipTool() )
+        self.site = DummySite('site').__of__(self.app)
+        sm = getSiteManager()
+        sm.registerUtility(DummyMembershipTool(), IMembershipTool)
+
+    def tearDown(self):
+        cleanUp()
+        SecurityTest.tearDown(self)
 
     def _makeOne(self, *args, **kw):
-        from Products.CMFCore.ActionInformation import ActionInfo
+        from ..ActionInformation import ActionInfo
 
         return ActionInfo(*args, **kw)
 
@@ -247,15 +283,15 @@ class ActionInfoSecurityTests(SecurityTest):
         ec = createExprContext(self.site, self.site, None)
         ai = self._makeOne(action, ec)
 
-        self.assertEqual( ai['id'], WANTED['id'] )
-        self.assertEqual( ai['title'], WANTED['title'] )
-        self.assertEqual( ai['url'], WANTED['url'] )
-        self.assertEqual( ai['icon'], WANTED['icon'] )
-        self.assertEqual( ai['category'], WANTED['category'] )
-        self.assertEqual( ai['visible'], WANTED['visible'] )
-        self.assertEqual( ai['available'], WANTED['available'] )
-        self.assertEqual( ai['allowed'], WANTED['allowed'] )
-        self.assertEqual( ai, WANTED )
+        self.assertEqual(ai['id'], WANTED['id'])
+        self.assertEqual(ai['title'], WANTED['title'])
+        self.assertEqual(ai['url'], WANTED['url'])
+        self.assertEqual(ai['icon'], WANTED['icon'])
+        self.assertEqual(ai['category'], WANTED['category'])
+        self.assertEqual(ai['visible'], WANTED['visible'])
+        self.assertEqual(ai['available'], WANTED['available'])
+        self.assertEqual(ai['allowed'], WANTED['allowed'])
+        self.assertEqual(ai, WANTED)
 
     def test_category_object(self):
         # Permissions for action category 'object*' should be
@@ -270,8 +306,8 @@ class ActionInfoSecurityTests(SecurityTest):
         ec = createExprContext(self.site, self.site, self.object)
         ai = self._makeOne(action, ec)
 
-        self.assertEqual( ai['category'], WANTED['category'] )
-        self.assertEqual( ai['allowed'], WANTED['allowed'] )
+        self.assertEqual(ai['category'], WANTED['category'])
+        self.assertEqual(ai['allowed'], WANTED['allowed'])
 
     def test_category_folder(self):
         # Permissions for action category 'folder*' should be
@@ -285,10 +321,10 @@ class ActionInfoSecurityTests(SecurityTest):
         action = {'name': 'foo', 'url': '', 'permissions': ('View',)}
         ec = createExprContext(self.folder, self.site, None)
         ai = self._makeOne(action, ec)
-        ai['category'] = 'folder' # pfff
+        ai['category'] = 'folder'  # pfff
 
-        self.assertEqual( ai['category'], WANTED['category'] )
-        self.assertEqual( ai['allowed'], WANTED['allowed'] )
+        self.assertEqual(ai['category'], WANTED['category'])
+        self.assertEqual(ai['allowed'], WANTED['allowed'])
 
     def test_category_workflow(self):
         # Permissions for action category 'workflow*' should be
@@ -302,10 +338,10 @@ class ActionInfoSecurityTests(SecurityTest):
         action = {'name': 'foo', 'url': '', 'permissions': ('View',)}
         ec = createExprContext(self.site, self.site, self.object)
         ai = self._makeOne(action, ec)
-        ai['category'] = 'workflow' # pfff
+        ai['category'] = 'workflow'  # pfff
 
-        self.assertEqual( ai['category'], WANTED['category'] )
-        self.assertEqual( ai['allowed'], WANTED['allowed'] )
+        self.assertEqual(ai['category'], WANTED['category'])
+        self.assertEqual(ai['allowed'], WANTED['allowed'])
 
     def test_category_document(self):
         # Permissions for action category 'document*' should be
@@ -319,10 +355,10 @@ class ActionInfoSecurityTests(SecurityTest):
         action = {'name': 'foo', 'url': '', 'permissions': ('View',)}
         ec = createExprContext(self.site, self.site, self.object)
         ai = self._makeOne(action, ec)
-        ai['category'] = 'document' # pfff
+        ai['category'] = 'document'  # pfff
 
-        self.assertEqual( ai['category'], WANTED['category'] )
-        self.assertEqual( ai['allowed'], WANTED['allowed'] )
+        self.assertEqual(ai['category'], WANTED['category'])
+        self.assertEqual(ai['allowed'], WANTED['allowed'])
 
     def test_copy(self):
         action = {'name': 'foo', 'url': '', 'permissions': ('View',)}
@@ -330,11 +366,11 @@ class ActionInfoSecurityTests(SecurityTest):
         ai = self._makeOne(action, ec)
         ai2 = ai.copy()
 
-        self.assertEqual( ai._lazy_keys, ['allowed'] )
-        self.assertEqual( ai2._lazy_keys, ['allowed'] )
-        self.failIf( ai2._lazy_keys is ai._lazy_keys )
-        self.assertEqual( ai['allowed'], True )
-        self.assertEqual( ai2['allowed'], True )
+        self.assertEqual(ai._lazy_keys, ['allowed'])
+        self.assertEqual(ai2._lazy_keys, ['allowed'])
+        self.assertFalse(ai2._lazy_keys is ai._lazy_keys)
+        self.assertEqual(ai['allowed'], True)
+        self.assertEqual(ai2['allowed'], True)
 
 
 class ActionInformationTests(TransactionalTest):
@@ -344,21 +380,25 @@ class ActionInformationTests(TransactionalTest):
     def setUp(self):
         TransactionalTest.setUp(self)
 
-        root = self.root
-        root._setObject('portal', DummyContent('portal', 'url_portal'))
-        portal = self.portal = root.portal
-        portal.portal_membership = DummyMembershipTool()
+        self.app._setObject('portal', DummyContent('portal'))
+        self.portal = self.app.portal
+        sm = getSiteManager()
+        sm.registerUtility(DummyMembershipTool(), IMembershipTool)
         self.folder = DummyContent('foo', 'url_foo')
         self.object = DummyContent('bar', 'url_bar')
 
+    def tearDown(self):
+        getSiteManager().unregisterUtility(provided=IMembershipTool)
+        TransactionalTest.tearDown(self)
+
     def _makeOne(self, *args, **kw):
-        from Products.CMFCore.ActionInformation import ActionInformation
+        from ..ActionInformation import ActionInformation
 
         return ActionInformation(*args, **kw)
 
     def test_interfaces(self):
-        from Products.CMFCore.ActionInformation import ActionInformation
-        from Products.CMFCore.interfaces import IAction
+        from ..ActionInformation import ActionInformation
+        from ..interfaces import IAction
 
         verifyClass(IAction, ActionInformation)
 
@@ -388,19 +428,18 @@ class ActionInformationTests(TransactionalTest):
         self.assertEqual(ai.getPermissions(), ())
 
     def test_setActionExpression_with_string_prefix(self):
-        from Products.CMFCore.Expression import Expression
         ai = self._makeOne(id='view', category='folder')
         ai.setActionExpression('string:blah')
-        self.failUnless(isinstance(ai.action,Expression))
+        self.assertTrue(isinstance(ai.action, Expression))
         self.assertEqual(ai.getActionExpression(), 'string:blah')
 
     def test_construction_with_Expressions(self):
-        ai = self._makeOne( id='view',
-                            title='View',
-                            action=Expression(text='view'),
-                            condition=Expression(text='member'),
-                            category='global',
-                            visible=False )
+        ai = self._makeOne(id='view',
+                           title='View',
+                           action=Expression(text='view'),
+                           condition=Expression(text='member'),
+                           category='global',
+                           visible=False)
 
         self.assertEqual(ai.getId(), 'view')
         self.assertEqual(ai.Title(), 'View')
@@ -415,40 +454,40 @@ class ActionInformationTests(TransactionalTest):
         portal = self.portal
         folder = self.folder
         object = self.object
-        ai = self._makeOne( id='view',
-                            title='View',
-                            action=Expression(text='view'),
-                            condition=Expression(text='member'),
-                            category='global',
-                            visible=True )
+        ai = self._makeOne(id='view',
+                           title='View',
+                           action=Expression(text='view'),
+                           condition=Expression(text='member'),
+                           category='global',
+                           visible=True)
         ec = createExprContext(folder, portal, object)
 
-        self.failIf(ai.testCondition(ec))
+        self.assertFalse(ai.testCondition(ec))
 
     def test_Condition_PathExpression(self):
         portal = self.portal
         folder = self.folder
         object = self.object
-        manage_addPythonScript(self.root, 'test_script')
-        script = self.root.test_script
+        manage_addPythonScript(self.app, 'test_script')
+        script = self.app.test_script
         script.ZPythonScript_edit('', 'return context.getId()')
-        ai = self._makeOne( id='view',
-                            title='View',
-                            action=Expression(text='view'),
-                            condition=Expression(text='portal/test_script'),
-                            category='global',
-                            visible=True )
+        ai = self._makeOne(id='view',
+                           title='View',
+                           action=Expression(text='view'),
+                           condition=Expression(text='portal/test_script'),
+                           category='global',
+                           visible=True)
         ec = createExprContext(folder, portal, object)
 
-        self.failUnless(ai.testCondition(ec))
+        self.assertTrue(ai.testCondition(ec))
 
     def test_getInfoData_empty(self):
-        WANTED = ( {'available': True, 'category': 'object',
-                    'description': '', 'id': 'foo', 'permissions': (),
-                    'title': 'foo', 'url': '', 'visible': True, 'icon': '',
-                    'link_target': None},[])
+        WANTED = ({'available': True, 'category': 'object',
+                   'description': '', 'id': 'foo', 'permissions': (),
+                   'title': 'foo', 'url': '', 'visible': True, 'icon': '',
+                   'link_target': None}, [])
         a = self._makeOne('foo')
-        self.assertEqual( a.getInfoData(), WANTED )
+        self.assertEqual(a.getInfoData(), WANTED)
 
     def test_getInfoData_normal(self):
         a = self._makeOne('foo',
@@ -460,14 +499,14 @@ class ActionInformationTests(TransactionalTest):
                           permissions=('View',),
                           visible=False,
                           link_target='_top')
-        WANTED = ( {'available': True, 'category': 'object',
-                    'description': 'Foo description.', 'id': 'foo',
-                    'permissions': ('View',), 'title': 'Foo Title',
-                    'url': a._getActionObject(), 'visible': False,
-                    'icon': a._getIconExpressionObject(), 
-                    'link_target': a.link_target },
-                   ['url', 'icon'] )
-        self.assertEqual( a.getInfoData(), WANTED )
+        WANTED = ({'available': True, 'category': 'object',
+                   'description': 'Foo description.', 'id': 'foo',
+                   'permissions': ('View',), 'title': 'Foo Title',
+                   'url': a._getActionObject(), 'visible': False,
+                   'icon': a._getIconExpressionObject(),
+                   'link_target': a.link_target},
+                  ['url', 'icon'])
+        self.assertEqual(a.getInfoData(), WANTED)
 
 
 def test_suite():
@@ -478,7 +517,3 @@ def test_suite():
         unittest.makeSuite(ActionInfoSecurityTests),
         unittest.makeSuite(ActionInformationTests),
         ))
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
