@@ -10,33 +10,34 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for ActionsTool module. """
+""" Unit tests for ActionsTool module.
+"""
 
 import unittest
-import Testing
+import warnings
 
+from AccessControl.SecurityManagement import newSecurityManager
 from zope.component import getSiteManager
 from zope.interface.verify import verifyClass
 from zope.testing.cleanup import cleanUp
 
-from Products.CMFCore.ActionInformation import Action
-from Products.CMFCore.ActionInformation import ActionCategory
-from Products.CMFCore.ActionInformation import ActionInformation
-from Products.CMFCore.Expression import Expression
-from Products.CMFCore.interfaces import ISiteRoot
-from Products.CMFCore.MembershipTool import MembershipTool
-from Products.CMFCore.tests.base.testcase import SecurityRequestTest
-from Products.CMFCore.tests.base.testcase import WarningInterceptor
-from Products.CMFCore.URLTool import URLTool
+from ..ActionInformation import Action
+from ..ActionInformation import ActionCategory
+from ..ActionInformation import ActionInformation
+from ..Expression import Expression
+from ..interfaces import IMembershipTool
+from ..interfaces import ISiteRoot
+from ..interfaces import IURLTool
+from ..MembershipTool import MembershipTool
+from ..URLTool import URLTool
+from .base.security import OmnipotentUser
+from .base.testcase import SecurityTest
 
 
-class ActionsToolTests(unittest.TestCase, WarningInterceptor):
-
-    def tearDown(self):
-        self._free_warning_output()
+class ActionsToolTests(unittest.TestCase):
 
     def _getTargetClass(self):
-        from Products.CMFCore.ActionsTool import ActionsTool
+        from ..ActionsTool import ActionsTool
 
         return ActionsTool
 
@@ -44,8 +45,8 @@ class ActionsToolTests(unittest.TestCase, WarningInterceptor):
         return self._getTargetClass()(*args, **kw)
 
     def test_interfaces(self):
-        from Products.CMFCore.interfaces import IActionProvider
-        from Products.CMFCore.interfaces import IActionsTool
+        from ..interfaces import IActionProvider
+        from ..interfaces import IActionsTool
 
         verifyClass(IActionProvider, self._getTargetClass())
         verifyClass(IActionsTool, self._getTargetClass())
@@ -62,11 +63,11 @@ class ActionsToolTests(unittest.TestCase, WarningInterceptor):
         tool.action_providers = ('portal_actions',)
         tool.addActionProvider('foo')
         self.assertEqual(tool.listActionProviders(),
-                          ('portal_actions', 'foo'))
+                         ('portal_actions', 'foo'))
         tool.addActionProvider('portal_url')
         tool.addActionProvider('foo')
         self.assertEqual(tool.listActionProviders(),
-                          ('portal_actions', 'foo', 'portal_url'))
+                         ('portal_actions', 'foo', 'portal_url'))
 
     def test_deleteActionProvider(self):
         tool = self._makeOne()
@@ -77,21 +78,22 @@ class ActionsToolTests(unittest.TestCase, WarningInterceptor):
     def test_getActionObject_oldskool_action_deprecated(self):
         # We have to clear APB's __warningregistry__, or else we may not see
         # the warning we expect (i.e., if somebody else triggered it first).
-        from Products.CMFCore import ActionProviderBase
+        from .. import ActionProviderBase
         try:
             del ActionProviderBase.__warningregistry__
         except AttributeError:
             pass
-        self._trap_warning_output()
         tool = self._makeOne()
         tool.addAction('an_id', 'name', '', '', '', 'object')
-        rval = tool.getActionObject('object/an_id')
-        self.assertEqual(rval, tool._actions[0])
-        warning = self._our_stderr_stream.getvalue()
-        self.assertTrue(
-            'DeprecationWarning: '
-            'Old-style actions are deprecated and will be removed in CMF '
-            '2.4. Use Action and Action Category objects instead.' in warning)
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter('always')
+            tool.getActionObject('object/an_id')
+            self.assertEqual(len(w), 1)
+            self.assertTrue(issubclass(w[-1].category, DeprecationWarning))
+            self.assertTrue(
+                'Old-style actions are deprecated and will be removed in CMF '
+                '2.4. Use Action and Action Category objects instead.'
+                in str(w[-1].message))
 
     def test_getActionObject_skips_newstyle_actions(self):
         tool = self._makeOne()
@@ -111,10 +113,10 @@ class ActionsToolTests(unittest.TestCase, WarningInterceptor):
         self.assertRaises(ValueError, tool.getActionObject, 'wrong_format')
 
 
-class ActionsToolSecurityRequestTests(SecurityRequestTest):
+class ActionsToolSecurityTests(SecurityTest):
 
     def _getTargetClass(self):
-        from Products.CMFCore.ActionsTool import ActionsTool
+        from ..ActionsTool import ActionsTool
 
         return ActionsTool
 
@@ -122,39 +124,42 @@ class ActionsToolSecurityRequestTests(SecurityRequestTest):
         return self._getTargetClass()(*args, **kw)
 
     def setUp(self):
-        SecurityRequestTest.setUp(self)
+        from ..interfaces import IActionsTool
 
-        root = self.root
-        sm = getSiteManager()
-        sm.registerUtility(root, ISiteRoot)
-        root._setObject( 'portal_actions', self._makeOne() )
-        root._setObject( 'portal_url', URLTool() )
-        root._setObject( 'foo', URLTool() )
-        root._setObject('portal_membership', MembershipTool())
-        self.tool = root.portal_actions
+        SecurityTest.setUp(self)
+        self.tool = self._makeOne()
         self.tool.action_providers = ('portal_actions',)
+        self.app._setObject('foo', URLTool())
+        sm = getSiteManager()
+        sm.registerUtility(self.tool, IActionsTool)
+        sm.registerUtility(MembershipTool(), IMembershipTool)
+        sm.registerUtility(self.app, ISiteRoot)
+        sm.registerUtility(URLTool(), IURLTool)
+
+    def tearDown(self):
+        cleanUp()
+        SecurityTest.tearDown(self)
 
     def test_listActionInformationActions(self):
         # Check that listFilteredActionsFor works for objects that return
         # ActionInformation objects
-        root = self.root
         tool = self.tool
+        act = 'string:${folder_url}/folder_contents'
         tool._actions = (
               ActionInformation(id='folderContents',
                                 title='Folder contents',
-                                action=Expression(text='string:'
-                                             '${folder_url}/folder_contents'),
+                                action=Expression(text=act),
                                 icon_expr=Expression(text='string:'
-                                             '${folder_url}/icon.gif'),
+                                                     '${folder_url}/icon.gif'),
                                 condition=Expression(text='python: '
-                                                      'folder is not object'),
+                                                     'folder is not object'),
                                 permissions=('List folder contents',),
                                 category='folder',
                                 link_target='_top',
-                                visible=1)
-            ,
-            )
-        self.assertEqual(tool.listFilteredActionsFor(root.foo),
+                                visible=1),)
+
+        newSecurityManager(None, OmnipotentUser().__of__(self.app.acl_users))
+        self.assertEqual(tool.listFilteredActionsFor(self.app.foo),
                          {'workflow': [],
                           'user': [],
                           'object': [],
@@ -170,16 +175,9 @@ class ActionsToolSecurityRequestTests(SecurityRequestTest):
                                       'link_target': '_top'}],
                           'global': []})
 
-    def tearDown(self):
-        cleanUp()
-        SecurityRequestTest.tearDown(self)
-
 
 def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite(ActionsToolTests),
-        unittest.makeSuite(ActionsToolSecurityRequestTests),
+        unittest.makeSuite(ActionsToolSecurityTests),
         ))
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
