@@ -16,23 +16,27 @@
 import unittest
 
 from Acquisition import Implicit
-from zope.interface import implements
-from Products.CMFCore.interfaces import ICatalogTool
-from Products.CMFCore.tests.base.dummy import DummyContent
-from Products.CMFCore.interfaces import IIndexableObject
-from Products.CMFCore.interfaces import IContentish
-from Products.CMFCore.tests.base.testcase import SecurityTest
+from Testing.ZopeTestCase import installProduct
+from zope.component import getSiteManager
+from zope.globalrequest import clearRequest
+from zope.globalrequest import setRequest
+from zope.interface import implementer
+from zope.testing.cleanup import cleanUp
+
+from ..interfaces import IContentish
+from ..interfaces import IWorkflowTool
+from .base.dummy import DummyContent
+from .base.dummy import DummySite
+from .base.testcase import SecurityTest
+
+
+installProduct('PluginIndexes')
 
 
 class FakeFolder(Implicit):
     id = 'portal'
 
 
-class FakeCatalog(Implicit):
-    implements(ICatalogTool)
-    id = 'portal_catalog'
-
-
 class FakeWorkflowTool(Implicit):
     id = 'portal_workflow'
 
@@ -43,38 +47,33 @@ class FakeWorkflowTool(Implicit):
         return self._vars
 
 
-class CatalogDummyContent(DummyContent):
-
-    """ Dummy content that already provides IIndexableObject
-        and therefore does not need a wrapper to be registered
-    """
-
-    implements(IIndexableObject)
-    allowedRolesAndUsers = ['Manager'] # default value
-
-
 class IndexableObjectWrapperTests(unittest.TestCase):
 
     def _getTargetClass(self):
-        from Products.CMFCore.CatalogTool import IndexableObjectWrapper
+        from ..CatalogTool import IndexableObjectWrapper
 
         return IndexableObjectWrapper
 
     def _makeOne(self, vars, obj):
-        self.root = FakeFolder()
-        self.root.portal_catalog = FakeCatalog()
-        self.root.portal_workflow = FakeWorkflowTool(vars)
-        catalog = self.root.portal_catalog
+        from ..interfaces import ICatalogTool
+
+        @implementer(ICatalogTool)
+        class FakeCatalog(Implicit):
+            id = 'portal_catalog'
+
+        getSiteManager().registerUtility(FakeWorkflowTool(vars), IWorkflowTool)
+        catalog = FakeCatalog().__of__(FakeFolder())
         return self._getTargetClass()(obj, catalog)
 
     def _makeContent(self, *args, **kw):
-        from Products.CMFCore.tests.base.dummy import DummyContent
-
         return DummyContent(*args, **kw)
 
+    def tearDown(self):
+        cleanUp()
+
     def test_interfaces(self):
         from zope.interface.verify import verifyClass
-        from Products.CMFCore.interfaces import IIndexableObjectWrapper
+        from ..interfaces import IIndexableObjectWrapper
 
         verifyClass(IIndexableObjectWrapper, self._getTargetClass())
 
@@ -105,28 +104,35 @@ class IndexableObjectWrapperTests(unittest.TestCase):
         self.assertEqual(w.baz, 2)
 
     def test_provided(self):
-        from Products.CMFCore.interfaces import IIndexableObjectWrapper
-        from Products.CMFCore.interfaces import IIndexableObject
+        from ..interfaces import IIndexableObjectWrapper
+        from ..interfaces import IIndexableObject
 
         obj = self._makeContent()
         w = self._makeOne({}, obj)
-        self.failUnless(IContentish.providedBy(w))
-        self.failUnless(IIndexableObjectWrapper.providedBy(w))
-        self.failUnless(IIndexableObject.providedBy(w))
+        self.assertTrue(IContentish.providedBy(w))
+        self.assertTrue(IIndexableObjectWrapper.providedBy(w))
+        self.assertTrue(IIndexableObject.providedBy(w))
 
     def test_adapts(self):
         from zope.component import adaptedBy
-        from Products.CMFCore.interfaces import ICatalogTool
+        from ..interfaces import ICatalogTool
 
         w = self._getTargetClass()
         adapts = adaptedBy(w)
         self.assertEqual(adapts, (IContentish, ICatalogTool))
 
+    def test_portal_type(self):
+        obj = self._makeContent()
+        w = self._makeOne({}, obj)
+        self.assertEqual(w.portal_type, 'Dummy Content')
+        obj.portal_type = None
+        self.assertEqual(w.portal_type, '')
+
 
 class CatalogToolTests(SecurityTest):
 
     def _getTargetClass(self):
-        from Products.CMFCore.CatalogTool import CatalogTool
+        from ..CatalogTool import CatalogTool
 
         return CatalogTool
 
@@ -134,12 +140,21 @@ class CatalogToolTests(SecurityTest):
         return self._getTargetClass()(*args, **kw)
 
     def _makeContent(self, *args, **kw):
+        from ..interfaces import IIndexableObject
+
+        @implementer(IIndexableObject)
+        class CatalogDummyContent(DummyContent):
+            """ Dummy content that already provides IIndexableObject
+                and therefore does not need a wrapper to be registered
+            """
+            allowedRolesAndUsers = ['Manager']  # default value
+
         return CatalogDummyContent(*args, **kw)
 
     def test_interfaces(self):
         from zope.interface.verify import verifyClass
-        from Products.CMFCore.interfaces import IActionProvider
-        from Products.CMFCore.interfaces import ICatalogTool
+        from ..interfaces import IActionProvider
+        from ..interfaces import ICatalogTool
         from Products.ZCatalog.interfaces import IZCatalog
 
         verifyClass(IActionProvider, self._getTargetClass())
@@ -148,20 +163,22 @@ class CatalogToolTests(SecurityTest):
 
     def loginWithRoles(self, *roles):
         from AccessControl.SecurityManagement import newSecurityManager
-        from Products.CMFCore.tests.base.security import UserWithRoles
-        user = UserWithRoles(*roles).__of__(self.root)
+        from .base.security import UserWithRoles
+        user = UserWithRoles(*roles).__of__(self.app)
         newSecurityManager(None, user)
 
     def loginManager(self):
         from AccessControl.SecurityManagement import newSecurityManager
-        from Products.CMFCore.tests.base.security import OmnipotentUser
-        user = OmnipotentUser().__of__(self.root)
+        from .base.security import OmnipotentUser
+        user = OmnipotentUser().__of__(self.app)
         newSecurityManager(None, user)
 
     def setupProxyRoles(self, *proxy_roles):
         from AccessControl import getSecurityManager
+
         class FauxExecutable:
             _proxy_roles = proxy_roles
+
         sm = getSecurityManager()
         sm.addContext(FauxExecutable())
 
@@ -193,7 +210,7 @@ class CatalogToolTests(SecurityTest):
         catalog.addIndex('allowedRolesAndUsers', 'KeywordIndex')
         catalog.addIndex('meta_type', 'FieldIndex')
         dummy = self._makeContent(catalog=1)
-        dummy.allowedRolesAndUsers = ('Blob', )
+        dummy.allowedRolesAndUsers = ('Blob',)
         catalog.catalog_object(dummy, '/dummy')
 
         self.loginWithRoles('Blob')
@@ -207,7 +224,7 @@ class CatalogToolTests(SecurityTest):
         catalog.addIndex('allowedRolesAndUsers', 'KeywordIndex')
         catalog.addIndex('meta_type', 'FieldIndex')
         dummy = self._makeContent(catalog=1)
-        dummy.allowedRolesAndUsers = ('Blob', )
+        dummy.allowedRolesAndUsers = ('Blob',)
         catalog.catalog_object(dummy, '/dummy')
 
         self.loginWithRoles('Blob')
@@ -222,7 +239,7 @@ class CatalogToolTests(SecurityTest):
         catalog.addIndex('allowedRolesAndUsers', 'KeywordIndex')
         catalog.addIndex('meta_type', 'FieldIndex')
         dummy = self._makeContent(catalog=1)
-        dummy.allowedRoleAndUsers = ('Blob', )
+        dummy.allowedRoleAndUsers = ('Blob',)
         catalog.catalog_object(dummy, '/dummy')
 
         self.loginWithRoles('Waggle')
@@ -236,7 +253,7 @@ class CatalogToolTests(SecurityTest):
         catalog.addIndex('allowedRolesAndUsers', 'KeywordIndex')
         catalog.addIndex('meta_type', 'FieldIndex')
         dummy = self._makeContent(catalog=1)
-        dummy.allowedRolesAndUsers = ('Blob', )
+        dummy.allowedRolesAndUsers = ('Blob',)
         catalog.catalog_object(dummy, '/dummy')
 
         self.loginWithRoles('Waggle')
@@ -255,21 +272,21 @@ class CatalogToolTests(SecurityTest):
         catalog.addIndex('meta_type', 'FieldIndex')
         now = DateTime()
         dummy = self._makeContent(catalog=1)
-        dummy.allowedRolesAndUsers = ('Blob', )
+        dummy.allowedRolesAndUsers = ('Blob',)
 
         self.loginWithRoles('Blob')
 
         # not yet effective
-        dummy.effective = now+1
-        dummy.expires = now+2
+        dummy.effective = now + 1
+        dummy.expires = now + 2
         catalog.catalog_object(dummy, '/dummy')
         query = {'meta_type': 'Dummy'}
         self.assertEqual(1, len(catalog._catalog.searchResults(query)))
         self.assertEqual(0, len(catalog.searchResults(query)))
 
         # already expired
-        dummy.effective = now-2
-        dummy.expires = now-1
+        dummy.effective = now - 2
+        dummy.expires = now - 1
         catalog.catalog_object(dummy, '/dummy')
         self.assertEqual(1, len(catalog._catalog.searchResults(query)))
         self.assertEqual(0, len(catalog.searchResults(query)))
@@ -287,29 +304,29 @@ class CatalogToolTests(SecurityTest):
         self.loginManager()
 
         # already expired
-        dummy.effective = now-4
-        dummy.expires = now-2
+        dummy.effective = now - 4
+        dummy.expires = now - 2
         catalog.catalog_object(dummy, '/dummy')
         query = {'meta_type': 'Dummy'}
         self.assertEqual(1, len(catalog._catalog.searchResults(query)))
         self.assertEqual(1, len(catalog.searchResults(query)))
 
         self.assertEqual(1, len(catalog.searchResults(
-            expires={'query': now-3, 'range': 'min'})))
+            expires={'query': now - 3, 'range': 'min'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': now-1, 'range': 'min'})))
+            expires={'query': now - 1, 'range': 'min'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': now-3, 'range': 'max'})))
+            expires={'query': now - 3, 'range': 'max'})))
         self.assertEqual(1, len(catalog.searchResults(
-            expires={'query': now-1, 'range': 'max'})))
+            expires={'query': now - 1, 'range': 'max'})))
         self.assertEqual(1, len(catalog.searchResults(
-            expires={'query': (now-3, now-1), 'range': 'min:max'})))
+            expires={'query': (now - 3, now - 1), 'range': 'min:max'})))
         self.assertEqual(1, len(catalog.searchResults(
-            expires={'query': (now-3, now-1), 'range': 'minmax'})))
+            expires={'query': (now - 3, now - 1), 'range': 'minmax'})))
         self.assertEqual(1, len(catalog.searchResults(
-            expires={'query': now-2})))
+            expires={'query': now - 2})))
         self.assertEqual(1, len(catalog.searchResults(
-            expires={'query': now-2, 'range': None})))
+            expires={'query': now - 2, 'range': None})))
 
     def test_search_restrict_inactive(self):
         from DateTime.DateTime import DateTime
@@ -320,31 +337,31 @@ class CatalogToolTests(SecurityTest):
         catalog.addIndex('meta_type', 'FieldIndex')
         now = DateTime()
         dummy = self._makeContent(catalog=1)
-        dummy.allowedRolesAndUsers = ('Blob', )
+        dummy.allowedRolesAndUsers = ('Blob',)
 
         self.loginWithRoles('Blob')
 
         # already expired
-        dummy.effective = now-4
-        dummy.expires = now-2
+        dummy.effective = now - 4
+        dummy.expires = now - 2
         catalog.catalog_object(dummy, '/dummy')
         query = {'meta_type': 'Dummy'}
         self.assertEqual(1, len(catalog._catalog.searchResults(query)))
         self.assertEqual(0, len(catalog.searchResults(query)))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': now-3, 'range': 'min'})))
+            expires={'query': now - 3, 'range': 'min'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': now-3, 'range': 'max'})))
+            expires={'query': now - 3, 'range': 'max'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': now+3, 'range': 'min'})))
+            expires={'query': now + 3, 'range': 'min'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': now+3, 'range': 'max'})))
+            expires={'query': now + 3, 'range': 'max'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': (now-3, now-1), 'range': 'min:max'})))
+            expires={'query': (now - 3, now - 1), 'range': 'min:max'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': (now-3, now-1), 'range': 'minmax'})))
+            expires={'query': (now - 3, now - 1), 'range': 'minmax'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': now-2, 'range': None})))
+            expires={'query': now - 2, 'range': None})))
 
     def test_search_restrict_visible(self):
         from DateTime.DateTime import DateTime
@@ -356,79 +373,79 @@ class CatalogToolTests(SecurityTest):
 
         now = DateTime()
         dummy = self._makeContent(catalog=1)
-        dummy.allowedRolesAndUsers = ('Blob', )
+        dummy.allowedRolesAndUsers = ('Blob',)
 
         self.loginWithRoles('Blob')
 
         # visible
-        dummy.effective = now-2
-        dummy.expires = now+2
+        dummy.effective = now - 2
+        dummy.expires = now + 2
         catalog.catalog_object(dummy, '/dummy')
         query = {'meta_type': 'Dummy'}
         self.assertEqual(1, len(catalog._catalog.searchResults(query)))
         self.assertEqual(1, len(catalog.searchResults(query)))
 
         self.assertEqual(0, len(catalog.searchResults(
-            effective={'query': now-1, 'range': 'min'})))
+            effective={'query': now - 1, 'range': 'min'})))
         self.assertEqual(1, len(catalog.searchResults(
-            effective={'query': now-1, 'range': 'max'})))
+            effective={'query': now - 1, 'range': 'max'})))
         self.assertEqual(0, len(catalog.searchResults(
-            effective={'query': now+1, 'range': 'min'})))
+            effective={'query': now + 1, 'range': 'min'})))
         self.assertEqual(1, len(catalog.searchResults(
-            effective={'query': now+1, 'range': 'max'})))
+            effective={'query': now + 1, 'range': 'max'})))
         self.assertEqual(0, len(catalog.searchResults(
-            effective={'query': (now-1, now+1), 'range': 'min:max'})))
+            effective={'query': (now - 1, now + 1), 'range': 'min:max'})))
         self.assertEqual(0, len(catalog.searchResults(
-            effective={'query': (now-1, now+1), 'range': 'minmax'})))
+            effective={'query': (now - 1, now + 1), 'range': 'minmax'})))
         self.assertEqual(1, len(catalog.searchResults(
-            expires={'query': now-2, 'range': None})))
+            expires={'query': now - 2, 'range': None})))
 
         self.assertEqual(1, len(catalog.searchResults(
-            effective={'query': now-3, 'range': 'min'})))
+            effective={'query': now - 3, 'range': 'min'})))
         self.assertEqual(0, len(catalog.searchResults(
-            effective={'query': now-3, 'range': 'max'})))
+            effective={'query': now - 3, 'range': 'max'})))
         self.assertEqual(0, len(catalog.searchResults(
-            effective={'query': now+3, 'range': 'min'})))
+            effective={'query': now + 3, 'range': 'min'})))
         self.assertEqual(1, len(catalog.searchResults(
-            effective={'query': now+3, 'range': 'max'})))
+            effective={'query': now + 3, 'range': 'max'})))
         self.assertEqual(1, len(catalog.searchResults(
-            effective={'query': (now-3, now+3), 'range': 'min:max'})))
+            effective={'query': (now - 3, now + 3), 'range': 'min:max'})))
         self.assertEqual(1, len(catalog.searchResults(
-            effective={'query': (now-3, now+3), 'range': 'minmax'})))
+            effective={'query': (now - 3, now + 3), 'range': 'minmax'})))
 
         self.assertEqual(1, len(catalog.searchResults(
-            expires={'query': now-1, 'range': 'min'})))
+            expires={'query': now - 1, 'range': 'min'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': now-1, 'range': 'max'})))
+            expires={'query': now - 1, 'range': 'max'})))
         self.assertEqual(1, len(catalog.searchResults(
-            expires={'query': now+1, 'range': 'min'})))
+            expires={'query': now + 1, 'range': 'min'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': now+1, 'range': 'max'})))
+            expires={'query': now + 1, 'range': 'max'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': (now-1, now+1), 'range': 'min:max'})))
+            expires={'query': (now - 1, now + 1), 'range': 'min:max'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': (now-1, now+1), 'range': 'minmax'})))
+            expires={'query': (now - 1, now + 1), 'range': 'minmax'})))
 
         self.assertEqual(1, len(catalog.searchResults(
-            expires={'query': now-3, 'range': 'min'})))
+            expires={'query': now - 3, 'range': 'min'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': now-3, 'range': 'max'})))
+            expires={'query': now - 3, 'range': 'max'})))
         self.assertEqual(0, len(catalog.searchResults(
-            expires={'query': now+3, 'range': 'min'})))
+            expires={'query': now + 3, 'range': 'min'})))
         self.assertEqual(1, len(catalog.searchResults(
-            expires={'query': now+3, 'range': 'max'})))
+            expires={'query': now + 3, 'range': 'max'})))
         self.assertEqual(1, len(catalog.searchResults(
-            expires={'query': (now-3, now+3), 'range': 'min:max'})))
+            expires={'query': (now - 3, now + 3), 'range': 'min:max'})))
         self.assertEqual(1, len(catalog.searchResults(
-            expires={'query': (now-3, now+3), 'range': 'minmax'})))
+            expires={'query': (now - 3, now + 3), 'range': 'minmax'})))
 
         self.assertEqual(1, len(catalog.searchResults(
-            effective={'query': now-1, 'range': 'max'},
-            expires={'query': now+1, 'range': 'min'})))
+            effective={'query': now - 1, 'range': 'max'},
+            expires={'query': now + 1, 'range': 'min'})))
 
         self.assertEqual(0, len(catalog.searchResults(
-            effective={'query': now+1, 'range': 'max'},
-            expires={'query': now+3, 'range': 'min'})))
+            effective={'query': now + 1, 'range': 'max'},
+            expires={'query': now + 3, 'range': 'min'})))
 
     def test_convertQuery(self):
         convert = self._makeOne()._convertQuery
@@ -457,12 +474,27 @@ class CatalogToolTests(SecurityTest):
         self.assertEqual(kw, {'expires':
                               {'query': (5, 7), 'range': 'min:max'}})
 
-    def test_refreshCatalog(self):
-        from Products.CMFCore.tests.base.dummy import DummySite
-        site = DummySite('site').__of__(self.root)
+    def test_searchResults_brain(self):
+        site = DummySite('site')
         site._setObject('dummy', self._makeContent(catalog=1))
-        site._setObject('portal_catalog', self._makeOne())
-        ctool = site.portal_catalog
+        ctool = self._makeOne().__of__(site)
+        ctool.addIndex('meta_type', 'FieldIndex')
+        ctool.catalog_object(site.dummy, '/dummy')
+
+        query = {'meta_type': 'Dummy'}
+        brain = ctool.searchResults(query)[0]
+
+        setRequest(self.REQUEST)
+        self.assertEqual('/dummy', brain.getPath())
+        self.assertEqual('http://nohost/dummy', brain.getURL())
+        self.assertEqual(site.dummy, brain.getObject())
+        self.assertTrue(hasattr(brain.getObject(), 'REQUEST'))
+        clearRequest()
+
+    def test_refreshCatalog(self):
+        site = DummySite('site')
+        site._setObject('dummy', self._makeContent(catalog=1))
+        ctool = self._makeOne().__of__(site)
         ctool.addIndex('meta_type', 'FieldIndex')
         ctool.catalog_object(site.dummy, '/dummy')
 
@@ -471,7 +503,7 @@ class CatalogToolTests(SecurityTest):
         ctool.refreshCatalog(clear=1)
         length = len(ctool._catalog.searchResults(query))
         self.assertEqual(1, length,
-                         'CMF Collector issue #379 (\'Update Catalog\' '
+                         "CMF Collector issue #379 ('Update Catalog' "
                          'fails): %s entries after refreshCatalog'
                          % length)
 
@@ -484,28 +516,28 @@ class CatalogToolTests(SecurityTest):
 
         # First case, no proxy roles set at all
         arus = catalog._listAllowedRolesAndUsers(user)
-        self.assertEquals(len(arus), 3)
-        self.failUnless('Anonymous' in arus)
-        self.failUnless('Blob' in arus)
-        self.failUnless('user:%s' % user.getId() in arus)
+        self.assertEqual(len(arus), 3)
+        self.assertTrue('Anonymous' in arus)
+        self.assertTrue('Blob' in arus)
+        self.assertTrue('user:%s' % user.getId() in arus)
 
         # Second case, a proxy role is set
         self.setupProxyRoles('Waggle')
         arus = catalog._listAllowedRolesAndUsers(user)
-        self.assertEquals(len(arus), 3)
-        self.failUnless('Anonymous' in arus)
-        self.failUnless('Waggle' in arus)
-        self.failUnless('user:%s' % user.getId() in arus)
+        self.assertEqual(len(arus), 3)
+        self.assertTrue('Anonymous' in arus)
+        self.assertTrue('Waggle' in arus)
+        self.assertTrue('user:%s' % user.getId() in arus)
 
         # Third case, proxy roles are an empty tuple. This happens if
         # proxy roles are unset using the ZMI. The behavior should
         # mirror the first case with no proxy role setting at all.
         self.setupProxyRoles()
         arus = catalog._listAllowedRolesAndUsers(user)
-        self.assertEquals(len(arus), 3)
-        self.failUnless('Anonymous' in arus)
-        self.failUnless('Blob' in arus)
-        self.failUnless('user:%s' % user.getId() in arus)
+        self.assertEqual(len(arus), 3)
+        self.assertTrue('Anonymous' in arus)
+        self.assertTrue('Blob' in arus)
+        self.assertTrue('user:%s' % user.getId() in arus)
 
     def test_wrapping1(self):
         # DummyContent implements IIndexableObject
@@ -531,15 +563,16 @@ class CatalogToolTests(SecurityTest):
     def test_wrapping3(self):
         # DummyContent does not implement IIndexableObject
         # wrapper registered - should look this up
+        from ..interfaces import ICatalogTool
+        from ..interfaces import IIndexableObject
 
         def FakeWrapper(object, catalog):
             return object
 
-        from zope.component import getSiteManager
-        self.sm = getSiteManager()
-        self.sm.registerAdapter(FakeWrapper,
-                                (IContentish, ICatalogTool),
-                                IIndexableObject)
+        sm = getSiteManager()
+        sm.registerAdapter(FakeWrapper,
+                           (IContentish, ICatalogTool),
+                           IIndexableObject)
 
         dummy = DummyContent(catalog=1)
         ctool = self._makeOne()
