@@ -10,50 +10,69 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for FSPythonScript module. """
+""" Unit tests for FSPythonScript module.
+"""
 
+import os
 import unittest
-from Testing import ZopeTestCase
-ZopeTestCase.installProduct('PythonScripts', 1)
-
+import warnings
 from os.path import join
 from sys import exc_info
-from thread import start_new_thread
 from time import sleep
 
+from six.moves._thread import start_new_thread
+
 from Acquisition import aq_base
+from DateTime.DateTime import DateTime
 from OFS.Folder import Folder
 from OFS.SimpleItem import SimpleItem
 from Products.StandardCacheManagers import RAMCacheManager
+from Testing import ZopeTestCase
+from zope.testing.cleanup import cleanUp
 
-from Products.CMFCore.FSMetadata import FSMetadata
-from Products.CMFCore.FSPythonScript import FSPythonScript
-from Products.CMFCore.tests.base.testcase import FSDVTest
-from Products.CMFCore.tests.base.testcase import SecurityTest
-from Products.CMFCore.tests.base.testcase import WarningInterceptor
+from ..FSMetadata import FSMetadata
+from ..FSPythonScript import FSPythonScript
+from .base.testcase import FSDVTest
+from .base.testcase import SecurityTest
+
+
+ZopeTestCase.installProduct('PythonScripts', 1)
 
 
 class FSPSMaker(FSDVTest):
 
-    def _makeOne( self, id, filename ):
+    def _makeOne(self, id, filename):
         path = join(self.skin_path_name, filename)
         metadata = FSMetadata(path)
         metadata.read()
-        return FSPythonScript( id, path, properties=metadata.getProperties() ) 
+        return FSPythonScript(id, path, properties=metadata.getProperties())
 
 
 class FSPythonScriptTests(FSPSMaker):
 
-    def test_get_size( self ):
+    def test_get_size(self):
         # Test get_size returns correct value
         script = self._makeOne('test1', 'test1.py')
-        self.assertEqual(len(script.read()),script.get_size())
+        self.assertEqual(len(script.read()), script.get_size())
+
+    def test_getModTime(self):
+        script = self._makeOne('test1', 'test1.py')
+        self.assertTrue(isinstance(script.getModTime(), DateTime))
+        self.assertEqual(script.getModTime(),
+                         DateTime(os.stat(script._filepath).st_mtime))
+
+    def test_bobobase_modification_time(self):
+        script = self._makeOne('test1', 'test1.py')
+        self.assertTrue(isinstance(script.bobobase_modification_time(),
+                                   DateTime))
+        self.assertEqual(script.bobobase_modification_time(),
+                         DateTime(os.stat(script._filepath).st_mtime))
 
     def test_initialization_race_condition(self):
         # Tries to exercise a former race condition where
         # FSObject._updateFromFS() set self._parsed before the
         # object was really parsed.
-        for n in range(10):
+        for _n in range(10):
             f = Folder()
             script = self._makeOne('test1', 'test1.py').__of__(f)
             res = []
@@ -61,7 +80,7 @@ class FSPythonScriptTests(FSPSMaker):
             def call_script(script=script, res=res):
                 try:
                     res.append(script())
-                except:
+                except Exception:
                     res.append('%s: %s' % exc_info()[:2])
 
             start_new_thread(call_script, ())
@@ -70,99 +89,76 @@ class FSPythonScriptTests(FSPSMaker):
                 sleep(0.05)
             self.assertEqual(res, ['test1', 'test1'], res)
 
-    def test_foreign_line_endings( self ):
+    def test_foreign_line_endings(self):
         # Load the various line ending files and get their output
         container = Folder('container_for_execution')
         for fformat in ('unix', 'dos', 'mac'):
             container._setObject(fformat,
-                self._makeOne(fformat, 'test_%s.py' % fformat))
+                                 self._makeOne(fformat,
+                                               'test_%s.py' % fformat))
             script = getattr(container, fformat)
             self.assertEqual(script(), fformat)
 
 
 class FSPythonScriptCustomizationTests(SecurityTest, FSPSMaker):
 
-    def setUp( self ):
+    def setUp(self):
         FSPSMaker.setUp(self)
-        SecurityTest.setUp( self )
+        SecurityTest.setUp(self)
 
     def tearDown(self):
+        cleanUp()
         SecurityTest.tearDown(self)
         FSPSMaker.tearDown(self)
 
-    def _makeSkins(self):
+    def test_customize(self):
+        from ..FSPythonScript import CustomizedPythonScript
 
-        root = self.root
-        root._setObject( 'portal_skins', Folder( 'portal_skins' ) )
-        tool = self.root.portal_skins
+        _stool, custom, _fsdir, fsPS = self._makeContext('test6', 'test6.py')
 
-        tool._setObject( 'custom', Folder( 'custom' ) )
-        custom = tool.custom
+        fsPS.manage_doCustomize(folder_path='custom')
 
-        tool._setObject( 'fsdir', Folder( 'fsdir' ) )
-        fsdir = tool.fsdir
-
-        fsdir._setObject( 'test6'
-                        , self._makeOne( 'test6', 'test6.py' ) )
-
-        fsPS = fsdir.test6
-
-        return root, tool, custom, fsdir, fsPS
-
-    def test_customize( self ):
-
-        from Products.CMFCore.FSPythonScript import CustomizedPythonScript
-
-        root, tool, custom, fsdir, fsPS = self._makeSkins()
-
-        fsPS.manage_doCustomize( folder_path='custom' )
-
-        self.assertEqual( len( custom.objectIds() ), 1 )
-        self.assertTrue( 'test6' in custom.objectIds() )  
+        self.assertEqual(len(custom.objectIds()), 1)
+        self.assertTrue('test6' in custom.objectIds())
 
         test6 = custom._getOb('test6')
 
         self.assertTrue(isinstance(test6, CustomizedPythonScript))
         self.assertEqual(test6.original_source, fsPS.read())
 
-    def test_customize_alternate_root( self ):
+    def test_customize_alternate_root(self):
+        _stool, custom, _fsdir, fsPS = self._makeContext('test6', 'test6.py')
+        self.app.other = Folder('other')
 
-        root, tool, custom, fsdir, fsPS = self._makeSkins()
-        root.other = Folder('other')
+        fsPS.manage_doCustomize(folder_path='other', root=self.app)
 
-        fsPS.manage_doCustomize( folder_path='other', root=root )
+        self.assertFalse('test6' in custom.objectIds())
+        self.assertTrue('test6' in self.app.other.objectIds())
 
-        self.assertFalse( 'test6' in custom.objectIds() )  
-        self.assertTrue( 'test6' in root.other.objectIds() )  
+    def test_customize_fspath_as_dot(self):
+        stool, custom, _fsdir, fsPS = self._makeContext('test6', 'test6.py')
 
-    def test_customize_fspath_as_dot( self ):
+        fsPS.manage_doCustomize(folder_path='.')
 
-        root, tool, custom, fsdir, fsPS = self._makeSkins()
+        self.assertFalse('test6' in custom.objectIds())
+        self.assertTrue('test6' in stool.objectIds())
 
-        fsPS.manage_doCustomize( folder_path='.' )
-
-        self.assertFalse( 'test6' in custom.objectIds() )  
-        self.assertTrue( 'test6' in root.portal_skins.objectIds() )  
-
-    def test_customize_manual_clone( self ):
-
-        root, tool, custom, fsdir, fsPS = self._makeSkins()
+    def test_customize_manual_clone(self):
+        _stool, custom, _fsdir, fsPS = self._makeContext('test6', 'test6.py')
         clone = Folder('test6')
 
-        fsPS.manage_doCustomize( folder_path='custom', obj=clone )
+        fsPS.manage_doCustomize(folder_path='custom', obj=clone)
 
-        self.assertTrue( 'test6' in custom.objectIds() )  
-        self.assertTrue( aq_base(custom._getOb('test6')) is clone )  
+        self.assertTrue('test6' in custom.objectIds())
+        self.assertTrue(aq_base(custom._getOb('test6')) is clone)
 
     def test_customize_caching(self):
         # Test to ensure that cache manager associations survive customizing
-        root, tool, custom, fsdir, fsPS = self._makeSkins()
+        _stool, custom, _fsdir, fsPS = self._makeContext('test6', 'test6.py')
 
         cache_id = 'gofast'
-        RAMCacheManager.manage_addRAMCacheManager( root
-                                                 , cache_id
-                                                 , REQUEST=None
-                                                 )
+        RAMCacheManager.manage_addRAMCacheManager(self.app, cache_id,
+                                                  REQUEST=None)
         fsPS.ZCacheable_setManagerId(cache_id, REQUEST=None)
 
         self.assertEqual(fsPS.ZCacheable_getManagerId(), cache_id)
@@ -174,7 +170,7 @@ class FSPythonScriptCustomizationTests(SecurityTest, FSPSMaker):
 
     def test_customize_proxyroles(self):
         # Test to ensure that proxy roles survive customizing
-        root, tool, custom, fsdir, fsPS = self._makeSkins()
+        _stool, custom, _fsdir, fsPS = self._makeContext('test6', 'test6.py')
 
         fsPS._proxy_roles = ('Manager', 'Anonymous')
         self.assertTrue(fsPS.manage_haveProxy('Anonymous'))
@@ -187,14 +183,11 @@ class FSPythonScriptCustomizationTests(SecurityTest, FSPSMaker):
 
     def test_customization_permissions(self):
         # Test to ensure that permission settings survive customizing
-        root, tool, custom, fsdir, fsPS = self._makeSkins()
+        _stool, custom, _fsdir, fsPS = self._makeContext('test6', 'test6.py')
         perm = 'View management screens'
 
         # First, set a permission to an odd role and verify
-        fsPS.manage_permission( perm
-                              , roles=('Anonymous',)
-                              , acquire=0
-                              )
+        fsPS.manage_permission(perm, roles=('Anonymous',), acquire=0)
         rop = fsPS.rolesOfPermission(perm)
         for rop_info in rop:
             if rop_info['name'] == 'Anonymous':
@@ -212,6 +205,7 @@ class FSPythonScriptCustomizationTests(SecurityTest, FSPSMaker):
             else:
                 self.assertTrue(rop_info['selected'] == '')
 
+
 _ORIGINAL_TEXT = """\
 ## Script (Python) "cps"
 ##bind container=container
@@ -239,8 +233,8 @@ return 'cps -- replaced'
 """
 
 _DIFF_TEXT = """\
---- original 
-+++ modified 
+--- original
++++ modified
 @@ -7,4 +7,4 @@
  ##parameters=
  ##title=
@@ -249,10 +243,11 @@ _DIFF_TEXT = """\
 +return 'cps -- replaced'
 """
 
+
 class CustomizedPythonScriptTests(unittest.TestCase):
 
     def _getTargetClass(self):
-        from Products.CMFCore.FSPythonScript import CustomizedPythonScript
+        from ..FSPythonScript import CustomizedPythonScript
         return CustomizedPythonScript
 
     def _makeOne(self, id, text):
@@ -271,7 +266,8 @@ class CustomizedPythonScriptTests(unittest.TestCase):
         self.assertEqual(len(list(cps.getDiff())), 0)
 
         cps.write(_REPLACEMENT_TEXT)
-        self.assertEqual(list(cps.getDiff()), _DIFF_TEXT.splitlines())
+        self.assertEqual([line.rstrip() for line in cps.getDiff()],
+                         _DIFF_TEXT.splitlines())
 
 
 class WarnMe(SimpleItem):
@@ -281,30 +277,31 @@ class WarnMe(SimpleItem):
         self._stacklevel = stacklevel
 
     def __call__(self):
-        import warnings
         warnings.warn('foo', stacklevel=self._stacklevel)
 
 
-class FSPythonScriptWarningsTests(SecurityTest, FSPSMaker, WarningInterceptor):
+class FSPythonScriptWarningsTests(SecurityTest, FSPSMaker):
 
-    def setUp( self ):
+    def setUp(self):
         SecurityTest.setUp(self)
         FSPSMaker.setUp(self)
-        self._trap_warning_output()
 
     def tearDown(self):
-        self._free_warning_output()
         FSPSMaker.tearDown(self)
         SecurityTest.tearDown(self)
 
     def testFSPSWarn(self):
-        self.root._setObject('warn_me', WarnMe(2))
-        self.root._setObject('warn1', self._makeOne('warn1', 'test_warn.py'))
+        self.app._setObject('warn_me', WarnMe(2))
+        self.app._setObject('warn1', self._makeOne('warn1', 'test_warn.py'))
         # This used to raise an error:
-        #   File "/usr/local/python2.3/lib/python2.3/warnings.py", line 63, in warn_explicit
+        #   File "/usr/local/python2.3/lib/python2.3/warnings.py", line 63,
+        #   in warn_explicit
         #     if module[-3:].lower() == ".py":
         # TypeError: unsubscriptable object
-        self.root.warn1()
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore')
+            self.app.warn_me()
+            self.app.warn1()
 
 
 def test_suite():
@@ -314,6 +311,3 @@ def test_suite():
         unittest.makeSuite(CustomizedPythonScriptTests),
         unittest.makeSuite(FSPythonScriptWarningsTests),
         ))
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
