@@ -10,31 +10,39 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for FSSTXMethod module. """
-import unittest
-import Testing
+""" Unit tests for FSSTXMethod module.
+"""
 
 import os
 import re
+import unittest
 
 from Acquisition import aq_base
+from App.Common import rfc1123_date
+from DateTime import DateTime
+from zope.component import getSiteManager
 from zope.testing.cleanup import cleanUp
 
-from Products.CMFCore.testing import TraversingZCMLLayer
-from Products.CMFCore.tests.base.testcase import FSDVTest
-from Products.CMFCore.tests.base.testcase import RequestTest
-from Products.CMFCore.tests.base.testcase import SecurityTest
+from ..interfaces import ICachingPolicyManager
+from ..testing import TraversingZCMLLayer
+from .base.dummy import DummyCachingManager
+from .base.dummy import DummyCachingManagerWithPolicy
+from .base.testcase import FSDVTest
+from .base.testcase import SecurityTest
+from .base.testcase import TransactionalTest
 
 
 class FSSTXMaker(FSDVTest):
 
-    def _makeOne( self, id, filename ):
-        from Products.CMFCore.FSMetadata import FSMetadata
-        from Products.CMFCore.FSSTXMethod import FSSTXMethod
+    def _makeOne(self, id, filename):
+        from ..FSMetadata import FSMetadata
+        from ..FSSTXMethod import FSSTXMethod
+
         path = os.path.join(self.skin_path_name, filename)
         metadata = FSMetadata(path)
         metadata.read()
-        return FSSTXMethod( id, path, properties=metadata.getProperties() )
+        return FSSTXMethod(id, path, properties=metadata.getProperties())
+
 
 _EXPECTED_HTML = """\
 <html>
@@ -62,6 +70,7 @@ BODY GOES HERE
 
 WS = re.compile(r'\s+')
 
+
 def _normalize_whitespace(text):
     return ' '.join(WS.split(text.rstrip()))
 
@@ -69,164 +78,140 @@ def _normalize_whitespace(text):
 class _TemplateSwitcher:
 
     def setUp(self):
-        import Products.CMFCore.FSSTXMethod
-        self._old_STX_TEMPLATE = Products.CMFCore.FSSTXMethod._STX_TEMPLATE
+        from .. import FSSTXMethod
+        self._old_STX_TEMPLATE = FSSTXMethod._STX_TEMPLATE
 
     def tearDown(self):
-        RequestTest.tearDown(self)
-        FSSTXMaker.tearDown(self)
         self._setWhichTemplate(self._old_STX_TEMPLATE)
+        TransactionalTest.tearDown(self)
+        FSSTXMaker.tearDown(self)
 
     def _setWhichTemplate(self, which):
-        import Products.CMFCore.FSSTXMethod
+        from .. import FSSTXMethod
         from Products.PageTemplates.ZopePageTemplate import ZopePageTemplate
-        Products.CMFCore.FSSTXMethod._STX_TEMPLATE = which
+        FSSTXMethod._STX_TEMPLATE = which
 
         if which == 'DTML':
-            self.root.standard_html_header = (
+            self.app.standard_html_header = (
                     lambda *args, **kw: '<html>\n<body>\n')
-            self.root.standard_html_footer = (
+            self.app.standard_html_footer = (
                     lambda *args, **kw: '</body>\n</html>\n')
         elif which == 'ZPT':
             main = ZopePageTemplate('main_template', _TEST_MAIN_TEMPLATE)
-            self.root._setOb('main_template', main)
+            self.app._setOb('main_template', main)
 
-class FSSTXMethodTests(RequestTest,
-                       FSSTXMaker,
-                       _TemplateSwitcher,
-                      ):
+
+class FSSTXMethodTests(TransactionalTest, FSSTXMaker, _TemplateSwitcher):
 
     layer = TraversingZCMLLayer
 
     def setUp(self):
         _TemplateSwitcher.setUp(self)
-        RequestTest.setUp(self)
+        TransactionalTest.setUp(self)
         FSSTXMaker.setUp(self)
 
     def tearDown(self):
         FSSTXMaker.tearDown(self)
-        RequestTest.tearDown(self)
         _TemplateSwitcher.tearDown(self)
+        TransactionalTest.tearDown(self)
 
-    def test___call___with_DTML( self ):
+    def test___call___with_DTML(self):
         self._setWhichTemplate('DTML')
-        script = self._makeOne( 'testSTX', 'testSTX.stx' )
-        script = script.__of__(self.app)
-        self.assertEqual(_normalize_whitespace(script(self.REQUEST)),
-                         _normalize_whitespace(_EXPECTED_HTML))
-
-    def test___call___with_ZPT( self ):
-        self._setWhichTemplate('ZPT')
-        script = self._makeOne( 'testSTX', 'testSTX.stx' )
-        script = script.__of__(self.app)
-        self.assertEqual(_normalize_whitespace(script(self.REQUEST)),
-                         _normalize_whitespace(_EXPECTED_HTML))
-
-    def test_caching( self ):
-        #   Test HTTP caching headers.
-        from Products.CMFCore.tests.base.dummy import DummyCachingManager
-        self._setWhichTemplate('DTML')
-        self.root.caching_policy_manager = DummyCachingManager()
-        original_len = len( self.RESPONSE.headers )
         script = self._makeOne('testSTX', 'testSTX.stx')
-        script = script.__of__(self.root)
-        script(self.REQUEST, self.RESPONSE)
-        self.failUnless( len( self.RESPONSE.headers ) >= original_len + 2 )
-        self.failUnless( 'foo' in self.RESPONSE.headers.keys() )
-        self.failUnless( 'bar' in self.RESPONSE.headers.keys() )
+        script = script.__of__(self.app)
+        self.assertEqual(_normalize_whitespace(script(self.REQUEST)),
+                         _normalize_whitespace(_EXPECTED_HTML))
 
-    def test_ownership( self ):
-        script = self._makeOne( 'testSTX', 'testSTX.stx' )
-        script = script.__of__(self.root)
+    def test___call___with_ZPT(self):
+        self._setWhichTemplate('ZPT')
+        script = self._makeOne('testSTX', 'testSTX.stx')
+        script = script.__of__(self.app)
+        self.assertEqual(_normalize_whitespace(script(self.REQUEST)),
+                         _normalize_whitespace(_EXPECTED_HTML))
+
+    def test_caching(self):
+        #   Test HTTP caching headers.
+        self._setWhichTemplate('DTML')
+        cpm = DummyCachingManager()
+        getSiteManager().registerUtility(cpm, ICachingPolicyManager)
+        original_len = len(self.RESPONSE.headers)
+        obj = self._makeOne('testSTX', 'testSTX.stx')
+        obj = obj.__of__(self.app)
+        obj(self.REQUEST, self.RESPONSE)
+        self.assertTrue(len(self.RESPONSE.headers) >= original_len + 2)
+        self.assertTrue('foo' in self.RESPONSE.headers)
+        self.assertTrue('bar' in self.RESPONSE.headers)
+
+    def test_ownership(self):
+        script = self._makeOne('testSTX', 'testSTX.stx')
+        script = script.__of__(self.app)
         # FSSTXMethod has no owner
         owner_tuple = script.getOwnerTuple()
         self.assertEqual(owner_tuple, None)
 
         # and ownership is not acquired [CMF/450]
-        self.root._owner= ('/foobar', 'baz')
+        self.app._owner = ('/foobar', 'baz')
         owner_tuple = script.getOwnerTuple()
         self.assertEqual(owner_tuple, None)
 
-    def test_304_response_from_cpm( self ):
+    def test_304_response_from_cpm(self):
         # test that we get a 304 response from the cpm via this template
-        from DateTime import DateTime
-        from webdav.common import rfc1123_date
-        from Products.CMFCore.tests.base.dummy \
-            import DummyCachingManagerWithPolicy
-
         mod_time = DateTime()
-        self.root.caching_policy_manager = DummyCachingManagerWithPolicy()
+        cpm = DummyCachingManagerWithPolicy()
+        getSiteManager().registerUtility(cpm, ICachingPolicyManager)
         script = self._makeOne('testSTX', 'testSTX.stx')
-        script = script.__of__(self.root)
-        self.REQUEST.environ[ 'IF_MODIFIED_SINCE'
-                            ] = '%s;' % rfc1123_date( mod_time+3600 )
+        script = script.__of__(self.app)
+        self.REQUEST.environ['IF_MODIFIED_SINCE'] = '%s;' % \
+            rfc1123_date(mod_time + 3600)
         data = script(self.REQUEST, self.RESPONSE)
 
-        self.assertEqual( data, '' )
-        self.assertEqual( self.RESPONSE.getStatus(), 304 )
+        self.assertEqual(data, '')
+        self.assertEqual(self.RESPONSE.getStatus(), 304)
 
 
 ADD_ZPT = 'Add page templates'
-ZPT_META_TYPES = ( { 'name'        : 'Page Template'
-                   , 'action'      : 'manage_addPageTemplate'
-                   , 'permission'  : ADD_ZPT
-                   }
-                 ,
-                 )
+ZPT_META_TYPES = ({'name': 'Page Template',
+                   'action': 'manage_addPageTemplate',
+                   'permission': ADD_ZPT},)
 
 
 class FSSTXMethodCustomizationTests(SecurityTest,
                                     FSSTXMaker,
-                                    _TemplateSwitcher,
-                                   ):
+                                    _TemplateSwitcher):
 
     def setUp(self):
-        from OFS.Folder import Folder
-
         _TemplateSwitcher.setUp(self)
         SecurityTest.setUp(self)
         FSSTXMaker.setUp(self)
-
-        self.root._setObject( 'portal_skins', Folder( 'portal_skins' ) )
-        self.skins = self.root.portal_skins
-
-        self.skins._setObject( 'custom', Folder( 'custom' ) )
-        self.custom = self.skins.custom
-
-        self.skins._setObject( 'fsdir', Folder( 'fsdir' ) )
-        self.fsdir = self.skins.fsdir
-
-        self.fsdir._setObject( 'testSTX'
-                             , self._makeOne( 'testSTX', 'testSTX.stx' ) )
-
-        self.fsSTX = self.fsdir.testSTX
+        self.skins, self.custom, self.fsdir, self.fsSTX = self._makeContext(
+                                                      'testSTX', 'testSTX.stx')
 
     def tearDown(self):
         cleanUp()
         FSSTXMaker.tearDown(self)
-        SecurityTest.tearDown(self)
         _TemplateSwitcher.tearDown(self)
+        SecurityTest.tearDown(self)
 
-    def test_customize_alternate_root( self ):
+    def test_customize_alternate_root(self):
         from OFS.Folder import Folder
 
         self._setWhichTemplate('DTML')
-        self.root.other = Folder('other')
+        self.app.other = Folder('other')
 
-        self.fsSTX.manage_doCustomize(folder_path='other', root=self.root)
+        self.fsSTX.manage_doCustomize(folder_path='other', root=self.app)
 
-        self.failIf('testSTX' in self.custom.objectIds())
-        self.failUnless('testSTX' in self.root.other.objectIds())
+        self.assertFalse('testSTX' in self.custom.objectIds())
+        self.assertTrue('testSTX' in self.app.other.objectIds())
 
-    def test_customize_fspath_as_dot( self ):
+    def test_customize_fspath_as_dot(self):
         self._setWhichTemplate('DTML')
 
         self.fsSTX.manage_doCustomize(folder_path='.')
 
-        self.failIf('testSTX' in self.custom.objectIds())
-        self.failUnless('testSTX' in self.skins.objectIds())
+        self.assertFalse('testSTX' in self.custom.objectIds())
+        self.assertTrue('testSTX' in self.skins.objectIds())
 
-    def test_customize_manual_clone( self ):
+    def test_customize_manual_clone(self):
         from OFS.Folder import Folder
 
         clone = Folder('testSTX')
@@ -235,22 +220,22 @@ class FSSTXMethodCustomizationTests(SecurityTest,
 
         self.fsSTX.manage_doCustomize(folder_path='custom', obj=clone)
 
-        self.failUnless('testSTX' in self.custom.objectIds())
-        self.failUnless(aq_base(self.custom._getOb('testSTX')) is clone)
+        self.assertTrue('testSTX' in self.custom.objectIds())
+        self.assertTrue(aq_base(self.custom._getOb('testSTX')) is clone)
 
-    def test_customize_with_DTML( self ):
+    def test_customize_with_DTML(self):
         from OFS.DTMLDocument import DTMLDocument
-        from Products.CMFCore.FSSTXMethod import _CUSTOMIZED_TEMPLATE_DTML
+        from ..FSSTXMethod import _CUSTOMIZED_TEMPLATE_DTML
 
         self._setWhichTemplate('DTML')
 
         self.fsSTX.manage_doCustomize(folder_path='custom')
 
         self.assertEqual(len(self.custom.objectIds()), 1)
-        self.failUnless('testSTX' in self.custom.objectIds())
+        self.assertTrue('testSTX' in self.custom.objectIds())
         target = self.custom._getOb('testSTX')
 
-        self.failUnless(isinstance(target, DTMLDocument))
+        self.assertTrue(isinstance(target, DTMLDocument))
 
         propinfo = target.propdict()['stx']
         self.assertEqual(propinfo['type'], 'text')
@@ -258,9 +243,9 @@ class FSSTXMethodCustomizationTests(SecurityTest,
 
         self.assertEqual(target.document_src(), _CUSTOMIZED_TEMPLATE_DTML)
 
-    def test_customize_with_ZPT( self ):
+    def test_customize_with_ZPT(self):
         from Products.PageTemplates.ZopePageTemplate import ZopePageTemplate
-        from Products.CMFCore.FSSTXMethod import _CUSTOMIZED_TEMPLATE_ZPT
+        from ..FSSTXMethod import _CUSTOMIZED_TEMPLATE_ZPT
 
         self._setWhichTemplate('ZPT')
         self.custom.all_meta_types = ZPT_META_TYPES
@@ -268,10 +253,10 @@ class FSSTXMethodCustomizationTests(SecurityTest,
         self.fsSTX.manage_doCustomize(folder_path='custom')
 
         self.assertEqual(len(self.custom.objectIds()), 1)
-        self.failUnless('testSTX' in self.custom.objectIds())
+        self.assertTrue('testSTX' in self.custom.objectIds())
         target = self.custom._getOb('testSTX')
 
-        self.failUnless(isinstance(target, ZopePageTemplate))
+        self.assertTrue(isinstance(target, ZopePageTemplate))
 
         propinfo = target.propdict()['stx']
         self.assertEqual(propinfo['type'], 'text')
@@ -286,10 +271,8 @@ class FSSTXMethodCustomizationTests(SecurityTest,
         cache_id = 'gofast'
         self._setWhichTemplate('ZPT')
         self.custom.all_meta_types = ZPT_META_TYPES
-        RAMCacheManager.manage_addRAMCacheManager( self.root
-                                                 , cache_id
-                                                 , REQUEST=None
-                                                 )
+        RAMCacheManager.manage_addRAMCacheManager(self.app, cache_id,
+                                                  REQUEST=None)
         self.fsSTX.ZCacheable_setManagerId(cache_id, REQUEST=None)
 
         self.assertEqual(self.fsSTX.ZCacheable_getManagerId(), cache_id)
@@ -305,7 +288,3 @@ def test_suite():
         unittest.makeSuite(FSSTXMethodTests),
         unittest.makeSuite(FSSTXMethodCustomizationTests),
         ))
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
