@@ -10,22 +10,25 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for IOpaqueItems implementations. """
+""" Unit tests for IOpaqueItems implementations.
+"""
 
 import unittest
-import Testing
 
-from zope.interface import implements
+import six
 
-from Products.CMFCore.interfaces import ICallableOpaqueItem
-from Products.CMFCore.interfaces import ICallableOpaqueItemEvents
-from Products.CMFCore.interfaces import IContentish
-from Products.CMFCore.PortalFolder import PortalFolder
-from Products.CMFCore.testing import TraversingEventZCMLLayer
-from Products.CMFCore.tests.base.dummy \
-    import DummyContent as OriginalDummyContent
-from Products.CMFCore.tests.base.testcase import SecurityTest
-from Products.CMFCore.TypesTool import TypesTool
+from zope.component import getSiteManager
+from zope.interface import implementer
+
+from ..interfaces import ICallableOpaqueItem
+from ..interfaces import ICallableOpaqueItemEvents
+from ..interfaces import IContentish
+from ..interfaces import ITypesTool
+from ..PortalFolder import PortalFolder
+from ..testing import TraversingEventZCMLLayer
+from ..TypesTool import TypesTool
+from .base.dummy import DummyContent as OriginalDummyContent
+from .base.testcase import SecurityTest
 
 
 # -------------------------------------------
@@ -36,23 +39,25 @@ def extra_meta_types():
     return [{'name': 'Dummy', 'action': 'manage_addFolder',
              'permission': 'View'}]
 
+
 def addDummyContent(container, id, opaqueItem):
-    container._setObject(id, DummyContent(id, opaqueItem=opaqueItem, catalog=1))
+    container._setObject(id,
+                         DummyContent(id, opaqueItem=opaqueItem, catalog=1))
     return getattr(container, id)
 
 
+@implementer(IContentish)
 class DummyContent(OriginalDummyContent):
 
     """ A Dummy piece of PortalContent with additional attributes
     """
-    implements(IContentish)
 
     def __init__(self, id='dummy', opaqueItem=None, *args, **kw):
         OriginalDummyContent.__init__(self, id, *args, **kw)
         if opaqueItem is None:
             self.opaqueItem = 'noncallable'
             self.opaqueItemsId = 'opaqueItem'
-        elif isinstance(opaqueItem, basestring):
+        elif isinstance(opaqueItem, six.string_types):
             Hooks(self, opaqueItem)
             self.opaqueItemsId = opaqueItem
         else:
@@ -84,28 +89,25 @@ class OpaqueBase:
         self.id = id
         setattr(obj, id, self)
 
-    def __call__():
+    def __call__(self):
         return
 
     def getId(self):
         return self.id
 
 
+@implementer(ICallableOpaqueItem)
 class Marker(OpaqueBase):
-
     """ Opaque item without manage_after/before hookes but marked as callable
     """
-
-    implements(ICallableOpaqueItem)
+    pass
 
 
+@implementer(ICallableOpaqueItemEvents)
 class Hooks(OpaqueBase):
-
     """ Opaque item with manage_after/before hooks but not marked as callable
     """
 
-    implements(ICallableOpaqueItemEvents)
-
     def manage_afterAdd(self, item, container):
         self.addCount = self.addCounter
         self.addCounter += 1
@@ -136,26 +138,24 @@ class ManageBeforeAfterTests(SecurityTest):
     def setUp(self):
         SecurityTest.setUp(self)
 
-        root = self.root
-
         # setting up types tool
-        root._setObject( 'portal_types', TypesTool() )
+        getSiteManager().registerUtility(TypesTool(), ITypesTool)
 
         # setup portal
         try:
-            root._delObject('test')
+            self.app._delObject('test')
         except AttributeError:
             pass
-        root._setObject('test', PortalFolder('test', ''))
-        self.test = test = self.root.test
+        self.app._setObject('test', PortalFolder('test', ''))
+        self.test = test = self.app.test
 
         # setting up folders
-        test._setObject( 'folder', PortalFolder( 'folder', '' ) )
+        test._setObject('folder', PortalFolder('folder', ''))
         folder = self.folder = test.folder
-        folder._setObject( 'sub', PortalFolder( 'sub', '' ) )
+        folder._setObject('sub', PortalFolder('sub', ''))
         sub = self.sub = folder.sub
 
-        #----- hacks to allow pasting (see also test_PortalFolder)
+        # ----- hacks to allow pasting (see also test_PortalFolder)
         # WAAA! force sub to allow paste of Dummy object.
         sub.all_meta_types = extra_meta_types()
 
@@ -176,7 +176,7 @@ class ManageBeforeAfterTests(SecurityTest):
         dummy = addDummyContent(folder, 'dummy', None)
 
         # WAAAA! must get _p_jar set
-        old, dummy._p_jar = sub._p_jar, self.root._p_jar
+        old, dummy._p_jar = sub._p_jar, self.app._p_jar
         try:
             cp = folder.manage_copyObjects(ids=['dummy'])
             sub.manage_pasteObjects(cp)
@@ -188,42 +188,42 @@ class ManageBeforeAfterTests(SecurityTest):
         sub = self.sub
         dummy = addDummyContent(folder, 'dummy', Marker)
 
-        self.failIf(dummy.isNotifiedByAfterAdd())
-        self.failIf(dummy.isNotifiedByAfterClone())
-        self.failIf(dummy.isNotifiedByBeforeDelete())
+        self.assertFalse(dummy.isNotifiedByAfterAdd())
+        self.assertFalse(dummy.isNotifiedByAfterClone())
+        self.assertFalse(dummy.isNotifiedByBeforeDelete())
 
         # WAAAA! must get _p_jar set
-        old, dummy._p_jar = sub._p_jar, self.root._p_jar
+        old, dummy._p_jar = sub._p_jar, self.app._p_jar
         try:
             cp = folder.manage_copyObjects(ids=['dummy'])
             sub.manage_pasteObjects(cp)
         finally:
             dummy._p_jar = old
 
-        self.failIf(dummy.isNotifiedByAfterAdd())
-        self.failIf(dummy.isNotifiedByAfterClone())
-        self.failIf(dummy.isNotifiedByBeforeDelete())
+        self.assertFalse(dummy.isNotifiedByAfterAdd())
+        self.assertFalse(dummy.isNotifiedByAfterClone())
+        self.assertFalse(dummy.isNotifiedByBeforeDelete())
 
     def test_callableItemWithHooksOnly(self):
         folder = self.folder
         sub = self.sub
         dummy = addDummyContent(folder, 'dummy', Hooks)
 
-        self.failIf(dummy.isNotifiedByAfterAdd())
-        self.failIf(dummy.isNotifiedByAfterClone())
-        self.failIf(dummy.isNotifiedByBeforeDelete())
+        self.assertFalse(dummy.isNotifiedByAfterAdd())
+        self.assertFalse(dummy.isNotifiedByAfterClone())
+        self.assertFalse(dummy.isNotifiedByBeforeDelete())
 
         # WAAAA! must get _p_jar set
-        old, dummy._p_jar = sub._p_jar, self.root._p_jar
+        old, dummy._p_jar = sub._p_jar, self.app._p_jar
         try:
             cp = folder.manage_copyObjects(ids=['dummy'])
             sub.manage_pasteObjects(cp)
         finally:
             dummy._p_jar = old
 
-        self.failIf(dummy.isNotifiedByAfterAdd())
-        self.failIf(dummy.isNotifiedByAfterClone())
-        self.failIf(dummy.isNotifiedByBeforeDelete())
+        self.assertFalse(dummy.isNotifiedByAfterAdd())
+        self.assertFalse(dummy.isNotifiedByAfterClone())
+        self.assertFalse(dummy.isNotifiedByBeforeDelete())
 
     def test_callableItemWithMarkerAndHooks(self):
         folder = self.folder
@@ -231,11 +231,11 @@ class ManageBeforeAfterTests(SecurityTest):
         dummy = addDummyContent(folder, 'dummy', MarkerAndHooks)
 
         self.assertEqual(dummy.isNotifiedByAfterAdd(), 1)
-        self.failIf(dummy.isNotifiedByAfterClone())
-        self.failIf(dummy.isNotifiedByBeforeDelete())
+        self.assertFalse(dummy.isNotifiedByAfterClone())
+        self.assertFalse(dummy.isNotifiedByBeforeDelete())
 
         # WAAAA! must get _p_jar set
-        old, dummy._p_jar = sub._p_jar, self.root._p_jar
+        old, dummy._p_jar = sub._p_jar, self.app._p_jar
         try:
             cp = folder.manage_copyObjects(ids=['dummy'])
             sub.manage_pasteObjects(cp)
@@ -244,7 +244,7 @@ class ManageBeforeAfterTests(SecurityTest):
 
         self.assertEqual(dummy.isNotifiedByAfterAdd(), 2)
         self.assertEqual(dummy.isNotifiedByAfterClone(), 1)
-        self.failIf(dummy.isNotifiedByBeforeDelete())
+        self.assertFalse(dummy.isNotifiedByBeforeDelete())
 
     def test_talkbackItem(self):
         folder = self.folder
@@ -253,11 +253,11 @@ class ManageBeforeAfterTests(SecurityTest):
         dummy = addDummyContent(folder, 'dummy', 'talkback')
 
         self.assertEqual(dummy.isNotifiedByAfterAdd(), 1)
-        self.failIf(dummy.isNotifiedByAfterClone())
-        self.failIf(dummy.isNotifiedByBeforeDelete())
+        self.assertFalse(dummy.isNotifiedByAfterClone())
+        self.assertFalse(dummy.isNotifiedByBeforeDelete())
 
         # WAAAA! must get _p_jar set
-        old, dummy._p_jar = sub._p_jar, self.root._p_jar
+        old, dummy._p_jar = sub._p_jar, self.app._p_jar
         try:
             cp = folder.manage_copyObjects(ids=['dummy'])
             sub.manage_pasteObjects(cp)
@@ -266,14 +266,10 @@ class ManageBeforeAfterTests(SecurityTest):
 
         self.assertEqual(dummy.isNotifiedByAfterAdd(), 2)
         self.assertEqual(dummy.isNotifiedByAfterClone(), 1)
-        self.failIf(dummy.isNotifiedByBeforeDelete())
+        self.assertFalse(dummy.isNotifiedByBeforeDelete())
 
 
 def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite(ManageBeforeAfterTests),
         ))
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
