@@ -10,10 +10,10 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Unit tests for RegistrationTool module. """
+""" Unit tests for RegistrationTool module.
+"""
 
 import unittest
-import Testing
 
 from zope.interface.verify import verifyClass
 
@@ -21,25 +21,22 @@ from zope.interface.verify import verifyClass
 class RegistrationToolTests(unittest.TestCase):
 
     def _makeOne(self):
-        from Products.CMFCore.RegistrationTool import RegistrationTool
+        from ..RegistrationTool import RegistrationTool
 
         return RegistrationTool()
 
     def test_interfaces(self):
-        from Products.CMFCore.interfaces import IRegistrationTool
-        from Products.CMFCore.RegistrationTool import RegistrationTool
+        from ..interfaces import IRegistrationTool
+        from ..RegistrationTool import RegistrationTool
 
         verifyClass(IRegistrationTool, RegistrationTool)
 
     def test_generatePassword(self):
         rtool = self._makeOne()
-        self.failUnless( len( rtool.generatePassword() ) >= 5 )
+        self.assertTrue(len(rtool.generatePassword()) >= 5)
 
 
 def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite(RegistrationToolTests),
         ))
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
