@@ -11,56 +11,68 @@
 #
 ##############################################################################
 """ Utility functions.
-
-$Id: utils.py 116642 2010-09-20 05:42:58Z davisagli $
 """
 
+import base64
 import re
+import sys
 from copy import deepcopy
 from os import path as os_path
 from os.path import abspath
 from warnings import warn
-import sys
 
+import pkg_resources
+import six
+from six.moves._thread import allocate_lock
+
+import Products
+from AccessControl.class_init import InitializeClass
 from AccessControl.Permission import Permission
 from AccessControl.PermissionRole import rolesForPermissionOn
 from AccessControl.Role import gather_permissions
 from AccessControl.SecurityInfo import ClassSecurityInfo
 from AccessControl.SecurityInfo import ModuleSecurityInfo
 from AccessControl.SecurityManagement import getSecurityManager
-from Acquisition.interfaces import IAcquirer
+from Acquisition import Implicit
 from Acquisition import aq_get
 from Acquisition import aq_parent
-from Acquisition import Implicit
-from App.class_init import InitializeClass
+from Acquisition.interfaces import IAcquirer
 from App.Common import package_home
+from App.Common import rfc1123_date
 from App.ImageFile import ImageFile
 from App.special_dtml import HTMLFile
 from DateTime.DateTime import DateTime
+from DateTime.interfaces import DateTimeError
 from ExtensionClass import Base
-from OFS.misc_ import misc_ as misc_images
 from OFS.misc_ import Misc_ as MiscImage
+from OFS.misc_ import misc_ as misc_images
 from OFS.ObjectManager import UNIQUE
 from OFS.PropertyManager import PropertyManager
-from OFS.PropertySheets import PropertySheets
 from OFS.SimpleItem import SimpleItem
-from thread import allocate_lock
-from webdav.common import rfc1123_date
 from zope.component import getUtility
-from zope.component.interfaces import ComponentLookupError
+from zope.component import queryUtility
 from zope.dottedname.resolve import resolve as resolve_dotted_name
 from zope.i18nmessageid import MessageFactory
+from zope.interface.interfaces import ComponentLookupError
 
-from Products.CMFCore.exceptions import AccessControl_Unauthorized
-from Products.CMFCore.exceptions import NotFound
+from .exceptions import AccessControl_Unauthorized
+from .exceptions import NotFound
+from .interfaces import ICachingPolicyManager
+
+
+HAS_ZSERVER = True
+try:
+    dist = pkg_resources.get_distribution('ZServer')
+except pkg_resources.DistributionNotFound:
+    HAS_ZSERVER = False
 
 SUBTEMPLATE = '__SUBTEMPLATE__'
-
-security = ModuleSecurityInfo( 'Products.CMFCore.utils' )
+ProductsPath = [abspath(ppath) for ppath in Products.__path__]
+security = ModuleSecurityInfo('Products.CMFCore.utils')
 
 _globals = globals()
-_dtmldir = os_path.join( package_home( globals() ), 'dtml' )
-_wwwdir = os_path.join( package_home( globals() ), 'www' )
+_dtmldir = os_path.join(package_home(globals()), 'dtml')
+_wwwdir = os_path.join(package_home(globals()), 'www')
 
 #
 #   Simple utility functions, callable from restricted code.
@@ -69,23 +81,26 @@ _marker = []  # Create a new marker object.
 
 _tool_interface_registry = {}
 
-security.declarePrivate('registerToolInterface')
+
+@security.private
 def registerToolInterface(tool_id, tool_interface):
     """ Register a tool ID for an interface
 
-    This method can go away when getToolByName is going away (CMF 2.3).
+    This method can go away when getToolByName is going away
     """
-    global  _tool_interface_registry
+    global _tool_interface_registry
     _tool_interface_registry[tool_id] = tool_interface
 
-security.declarePrivate('getToolInterface')
+
+@security.private
 def getToolInterface(tool_id):
     """ Get the interface registered for a tool ID
     """
-    global  _tool_interface_registry
+    global _tool_interface_registry
     return _tool_interface_registry.get(tool_id, None)
 
-security.declarePublic('getToolByName')
+
+@security.public
 def getToolByName(obj, name, default=_marker):
 
     """ Get the tool, 'toolname', by acquiring it.
@@ -100,8 +115,8 @@ def getToolByName(obj, name, default=_marker):
         try:
             utility = getUtility(tool_interface)
             # Site managers, except for five.localsitemanager, return unwrapped
-            # utilities. If the result is something which is acquisition-unaware
-            # but unwrapped we wrap it on the context.
+            # utilities. If the result is something which is
+            # acquisition-unaware but unwrapped we wrap it on the context.
             if IAcquirer.providedBy(obj) and \
                     aq_parent(utility) is None and \
                     IAcquirer.providedBy(utility):
@@ -111,7 +126,7 @@ def getToolByName(obj, name, default=_marker):
             # behave in backwards-compatible way
             # fall through to old implementation
             pass
-    
+
     try:
         tool = aq_get(obj, name, default, 1)
     except AttributeError:
@@ -120,19 +135,11 @@ def getToolByName(obj, name, default=_marker):
         return default
     else:
         if tool is _marker:
-            raise AttributeError, name
+            raise AttributeError(name)
         return tool
 
-security.declarePublic('getToolByInterfaceName')
-def getToolByInterfaceName(dotted_name, default=_marker):
-    warn('getToolByInterfaceName() is deprecated and will be removed in CMF '
-         '2.3. Use getUtilityByInterfaceName instead.',
-         DeprecationWarning, stacklevel=2)
 
-    return getUtilityByInterfaceName(dotted_name, default)
-
-
-security.declarePublic('getUtilityByInterfaceName')
+@security.public
 def getUtilityByInterfaceName(dotted_name, default=_marker):
     """ Get a tool by its fully-qualified dotted interface path
 
@@ -143,7 +150,7 @@ def getUtilityByInterfaceName(dotted_name, default=_marker):
         iface = resolve_dotted_name(dotted_name)
     except ImportError:
         if default is _marker:
-            raise ComponentLookupError, dotted_name
+            raise ComponentLookupError(dotted_name)
         return default
 
     try:
@@ -153,7 +160,8 @@ def getUtilityByInterfaceName(dotted_name, default=_marker):
             raise
         return default
 
-security.declarePublic('cookString')
+
+@security.public
 def cookString(text):
 
     """ Make a Zope-friendly ID from 'text'.
@@ -163,11 +171,12 @@ def cookString(text):
     o Lowercase the ID.
     """
     rgx = re.compile(r'(^_|[^a-zA-Z0-9-_~\,\.])')
-    cooked = re.sub(rgx, "",text).lower()
+    cooked = re.sub(rgx, '', text).lower()
     return cooked
 
-security.declarePublic('tuplize')
-def tuplize( valueName, value ):
+
+@security.public
+def tuplize(valueName, value):
 
     """ Make a tuple from 'value'.
 
@@ -176,29 +185,35 @@ def tuplize( valueName, value ):
     if isinstance(value, tuple):
         return value
     if isinstance(value, list):
-        return tuple( value )
-    if isinstance(value, basestring):
-        return tuple( value.split() )
-    raise ValueError, "%s of unsupported type" % valueName
+        return tuple(value)
+    if isinstance(value, six.string_types):
+        return tuple(value.split())
+    raise ValueError('%s of unsupported type' % valueName)
+
 
 #
 #   Security utilities, callable only from unrestricted code.
 #
-security.declarePrivate('_getAuthenticatedUser')
+# deprecated alias
+@security.private
 def _getAuthenticatedUser(self):
     return getSecurityManager().getUser()
 
-security.declarePrivate('_checkPermission')
+
+@security.private
 def _checkPermission(permission, obj):
+    if not isinstance(permission, six.string_types):
+        permission = permission.decode()
     return getSecurityManager().checkPermission(permission, obj)
 
+
 # If Zope ever provides a call to getRolesInContext() through
 # the SecurityManager API, the method below needs to be updated.
-security.declarePrivate('_limitGrantedRoles')
+@security.private
 def _limitGrantedRoles(roles, context, special_roles=()):
     # Only allow a user to grant roles already possessed by that user,
     # with the exception that all special_roles can also be granted.
-    user = _getAuthenticatedUser(context)
+    user = getSecurityManager().getUser()
     if user is None:
         user_roles = ()
     else:
@@ -210,7 +225,8 @@ def _limitGrantedRoles(roles, context, special_roles=()):
         if role not in special_roles and role not in user_roles:
             raise AccessControl_Unauthorized('Too many roles specified.')
 
-security.declarePrivate('_mergedLocalRoles')
+
+@security.private
 def _mergedLocalRoles(object):
     """Returns a merging of object and its ancestors'
     __ac_local_roles__."""
@@ -220,44 +236,48 @@ def _mergedLocalRoles(object):
     while 1:
         if hasattr(object, '__ac_local_roles__'):
             dict = object.__ac_local_roles__ or {}
-            if callable(dict): dict = dict()
+            if callable(dict):
+                dict = dict()
             for k, v in dict.items():
-                if merged.has_key(k):
+                if k in merged:
                     merged[k] = merged[k] + v
                 else:
                     merged[k] = v
         if hasattr(object, 'aq_parent'):
-            object=object.aq_parent
-            object=getattr(object, 'aq_inner', object)
+            object = object.aq_parent
+            object = getattr(object, 'aq_inner', object)
             continue
-        if hasattr(object, 'im_self'):
-            object=object.im_self
-            object=getattr(object, 'aq_inner', object)
+        if hasattr(object, '__self__'):
+            object = object.__self__
+            object = getattr(object, 'aq_inner', object)
             continue
         break
 
     return deepcopy(merged)
 
-security.declarePrivate('_ac_inherited_permissions')
+
+@security.private
 def _ac_inherited_permissions(ob, all=0):
     # Get all permissions not defined in ourself that are inherited
     # This will be a sequence of tuples with a name as the first item and
     # an empty tuple as the second.
     d = {}
     perms = getattr(ob, '__ac_permissions__', ())
-    for p in perms: d[p[0]] = None
+    for p in perms:
+        d[p[0]] = None
     r = gather_permissions(ob.__class__, [], d)
     if all:
-       if hasattr(ob, '_subobject_permissions'):
-           for p in ob._subobject_permissions():
-               pname=p[0]
-               if not d.has_key(pname):
-                   d[pname]=1
-                   r.append(p)
-       r = list(perms) + r
+        if hasattr(ob, '_subobject_permissions'):
+            for p in ob._subobject_permissions():
+                pname = p[0]
+                if pname not in d:
+                    d[pname] = 1
+                    r.append(p)
+        r = list(perms) + r
     return r
 
-security.declarePrivate('_modifyPermissionMappings')
+
+@security.private
 def _modifyPermissionMappings(ob, map):
     """
     Modifies multiple role to permission mappings.
@@ -268,7 +288,7 @@ def _modifyPermissionMappings(ob, map):
     perm_info = _ac_inherited_permissions(ob, 1)
     for name, settings in map.items():
         cur_roles = rolesForPermissionOn(name, ob)
-        if isinstance(cur_roles, basestring):
+        if isinstance(cur_roles, six.string_types):
             cur_roles = [cur_roles]
         else:
             cur_roles = list(cur_roles)
@@ -295,20 +315,36 @@ def _modifyPermissionMappings(ob, map):
     return something_changed
 
 
+class FakeExecutableObject:
+
+    """Fake ExecutableObject used to set proxy roles in trusted code.
+    """
+
+    def __init__(self, proxy_roles):
+        self._proxy_roles = tuple(proxy_roles)
+
+    def getOwner(self):
+        return None
+
+    getWrappedOwner = getOwner
+
+
 # Parse a string of etags from an If-None-Match header
 # Code follows ZPublisher.HTTPRequest.parse_cookie
-parse_etags_lock=allocate_lock()
-def parse_etags( text
-               , result=None
-                # quoted etags (assumed separated by whitespace + a comma)
-               , etagre_quote = re.compile('(\s*\"([^\"]*)\"\s*,{0,1})')
-                # non-quoted etags (assumed separated by whitespace + a comma)
-               , etagre_noquote = re.compile('(\s*([^,]*)\s*,{0,1})')
-               , acquire=parse_etags_lock.acquire
-               , release=parse_etags_lock.release
-               ):
+parse_etags_lock = allocate_lock()
 
-    if result is None: result=[]
+
+def parse_etags(text,
+                result=None,
+                # quoted etags (assumed separated by whitespace + a comma)
+                etagre_quote=re.compile(r'(\s*\"([^\"]*)\"\s*,{0,1})'),
+                # non-quoted etags (assumed separated by whitespace + a comma)
+                etagre_noquote=re.compile(r'(\s*([^,]*)\s*,{0,1})'),
+                acquire=parse_etags_lock.acquire,
+                release=parse_etags_lock.release):
+
+    if result is None:
+        result = []
     if not len(text):
         return result
 
@@ -317,21 +353,23 @@ def parse_etags( text
         m = etagre_quote.match(text)
         if m:
             # Match quoted etag (spec-observing client)
-            l     = len(m.group(1))
+            tl = len(m.group(1))
             value = m.group(2)
         else:
             # Match non-quoted etag (lazy client)
             m = etagre_noquote.match(text)
             if m:
-                l     = len(m.group(1))
+                tl = len(m.group(1))
                 value = m.group(2)
             else:
                 return result
-    finally: release()
+    finally:
+        release()
 
     if value:
         result.append(value)
-    return apply(parse_etags,(text[l:],result))
+    return parse_etags(*(text[tl:], result))
+
 
 def _checkConditionalGET(obj, extra_context):
     """A conditional GET is done using one or both of the request
@@ -361,18 +399,18 @@ def _checkConditionalGET(obj, extra_context):
 
     # check whether we need to suppress subtemplates
     call_count = getattr(REQUEST, SUBTEMPLATE, 0)
-    setattr(REQUEST, SUBTEMPLATE, call_count+1)
+    setattr(REQUEST, SUBTEMPLATE, call_count + 1)
     if call_count != 0:
         return False
 
-    if_modified_since = REQUEST.get_header('If-Modified-Since', None)
-    if_none_match = REQUEST.get_header('If-None-Match', None)
+    if_modified_since = REQUEST.getHeader('If-Modified-Since', None)
+    if_none_match = REQUEST.getHeader('If-None-Match', None)
 
     if if_modified_since is None and if_none_match is None:
         # not a conditional GET
         return False
 
-    manager = getToolByName(obj, 'caching_policy_manager', None)
+    manager = queryUtility(ICachingPolicyManager)
     if manager is None:
         return False
 
@@ -383,7 +421,7 @@ def _checkConditionalGET(obj, extra_context):
 
     (content_mod_time, content_etag, set_last_modified_header) = ret
     if content_mod_time:
-        mod_time_secs = long(content_mod_time.timeTime())
+        mod_time_secs = int(content_mod_time.timeTime())
     else:
         mod_time_secs = None
 
@@ -397,9 +435,9 @@ def _checkConditionalGET(obj, extra_context):
         # understand the screwy date string as a lucky side effect
         # of the way they parse it).
         try:
-            if_modified_since=long(DateTime(if_modified_since).timeTime())
-        except:
-            if_modified_since=None
+            if_modified_since = int(DateTime(if_modified_since).timeTime())
+        except Exception:
+            if_modified_since = None
 
     client_etags = None
     if if_none_match:
@@ -410,19 +448,19 @@ def _checkConditionalGET(obj, extra_context):
         return False
 
     if if_modified_since:
-        if ( not content_mod_time or 
-             mod_time_secs < 0 or 
-             mod_time_secs > if_modified_since ):
+        if not content_mod_time or \
+           mod_time_secs < 0 or \
+           mod_time_secs > if_modified_since:
             return False
 
     if client_etags:
-        if ( not content_etag or 
-             (content_etag not in client_etags and '*' not in client_etags) ):
+        if not content_etag or \
+           (content_etag not in client_etags and '*' not in client_etags):
             return False
     else:
-        # If we generate an ETag, don't validate the conditional GET unless 
+        # If we generate an ETag, don't validate the conditional GET unless
         # the client supplies an ETag
-        # This may be more conservative than the spec requires, but we are 
+        # This may be more conservative than the spec requires, but we are
         # already _way_ more conservative.
         if content_etag:
             return False
@@ -437,7 +475,8 @@ def _checkConditionalGET(obj, extra_context):
 
     return True
 
-security.declarePrivate('_setCacheHeaders')
+
+@security.private
 def _setCacheHeaders(obj, extra_context):
     """Set cache headers according to cache policy manager for the obj."""
     REQUEST = getattr(obj, 'REQUEST', None)
@@ -446,20 +485,19 @@ def _setCacheHeaders(obj, extra_context):
         call_count = getattr(REQUEST, SUBTEMPLATE, 1) - 1
         setattr(REQUEST, SUBTEMPLATE, call_count)
         if call_count != 0:
-           return
+            return
 
         # cleanup
         delattr(REQUEST, SUBTEMPLATE)
 
         content = aq_parent(obj)
-        manager = getToolByName(obj, 'caching_policy_manager', None)
+        manager = queryUtility(ICachingPolicyManager)
         if manager is None:
             return
 
         view_name = obj.getId()
         headers = manager.getHTTPCachingHeaders(
-                          content, view_name, extra_context
-                          )
+                          content, view_name, extra_context)
         RESPONSE = REQUEST['RESPONSE']
         for key, value in headers:
             if key == 'ETag':
@@ -471,6 +509,7 @@ def _setCacheHeaders(obj, extra_context):
                                'CachingPolicyManager: %s' %
                                '/'.join(manager.getPhysicalPath()))
 
+
 class _ViewEmulator(Implicit):
     """Auxiliary class used to adapt FSFile and FSImage
     for caching_policy_manager
@@ -498,30 +537,31 @@ class ImmutableId(Base):
                              % self.getId())
 
 
-class UniqueObject (ImmutableId):
+class UniqueObject(ImmutableId):
 
     """ Base class for objects which cannot be "overridden" / shadowed.
     """
+    zmi_icon = 'fas fa-wrench'
+
     def _getUNIQUE(self):
         return UNIQUE
 
-    __replaceable__ = property(_getUNIQUE,)
+    __replaceable__ = property(_getUNIQUE)
 
 
-class SimpleItemWithProperties (PropertyManager, SimpleItem):
+class SimpleItemWithProperties(PropertyManager, SimpleItem):
     """
     A common base class for objects with configurable
     properties in a fixed schema.
     """
     manage_options = (
-        PropertyManager.manage_options
-        + SimpleItem.manage_options)
-
+        PropertyManager.manage_options +
+        SimpleItem.manage_options)
 
     security = ClassSecurityInfo()
-    security.declarePrivate('manage_addProperty')
-    security.declarePrivate('manage_delProperties')
-    security.declarePrivate('manage_changePropertyTypes')
+    security.declarePrivate('manage_addProperty')  # NOQA: flake8: D001
+    security.declarePrivate('manage_delProperties')  # NOQA: flake8: D001
+    security.declarePrivate('manage_changePropertyTypes')  # NOQA: flake8: D001
 
     def manage_propertiesForm(self, REQUEST, *args, **kw):
         """ An override that makes the schema fixed.
@@ -531,7 +571,8 @@ class SimpleItemWithProperties (PropertyManager, SimpleItem):
         form = PropertyManager.manage_propertiesForm.__of__(self)
         return form(self, REQUEST, *args, **my_kw)
 
-InitializeClass( SimpleItemWithProperties )
+
+InitializeClass(SimpleItemWithProperties)
 
 
 #
@@ -550,7 +591,7 @@ class ToolInit:
         self.meta_type = meta_type
         self.tools = tools
         if product_name is not None:
-            warn("The product_name parameter of ToolInit is now ignored",
+            warn('The product_name parameter of ToolInit is now ignored',
                  DeprecationWarning, stacklevel=2)
         self.icon = icon
 
@@ -559,15 +600,12 @@ class ToolInit:
         productObject = context._ProductContext__prod
         self.product_name = productObject.id
         context.registerClass(
-            meta_type = self.meta_type,
+            meta_type=self.meta_type,
             # This is a little sneaky: we add self to the
             # FactoryDispatcher under the name "toolinit".
             # manage_addTool() can then grab it.
-            constructors = (manage_addToolForm,
-                            manage_addTool,
-                            self,),
-            icon = self.icon
-            )
+            constructors=(manage_addToolForm, manage_addTool, self),
+            icon=self.icon)
 
         if self.icon:
             icon = os_path.split(self.icon)[1]
@@ -577,10 +615,12 @@ class ToolInit:
             tool.__factory_meta_type__ = self.meta_type
             tool.icon = 'misc_/%s/%s' % (self.product_name, icon)
 
-InitializeClass( ToolInit )
+
+InitializeClass(ToolInit)
 
 addInstanceForm = HTMLFile('dtml/addInstance', globals())
 
+
 def manage_addToolForm(self, REQUEST):
 
     """ Show the add tool form.
@@ -598,6 +638,7 @@ def manage_addToolForm(self, REQUEST):
                            factory_types_list=tl,
                            factory_need_id=0)
 
+
 def manage_addTool(self, type, REQUEST=None):
 
     """ Add the tool specified by name.
@@ -628,14 +669,8 @@ class ContentInit:
     security = ClassSecurityInfo()
     security.declareObjectPrivate()
 
-    def __init__( self
-                , meta_type
-                , content_types
-                , permission=None
-                , extra_constructors=()
-                , fti=()
-                , visibility='Global'
-                ):
+    def __init__(self, meta_type, content_types, permission=None,
+                 extra_constructors=(), fti=(), visibility='Global'):
         # BBB: fti argument is ignored
         self.meta_type = meta_type
         self.content_types = content_types
@@ -646,24 +681,23 @@ class ContentInit:
     def initialize(self, context):
         # Add only one meta type to the folder add list.
         context.registerClass(
-            meta_type = self.meta_type
+            meta_type=self.meta_type,
             # This is a little sneaky: we add self to the
             # FactoryDispatcher under the name "contentinit".
             # manage_addContentType() can then grab it.
-            , constructors = ( manage_addContentForm
-                               , manage_addContent
-                               , self ) + self.extra_constructors
-            , permission = self.permission
-            , visibility = self.visibility
-            )
+            constructors=(manage_addContentForm, manage_addContent,
+                          self) + self.extra_constructors,
+            permission=self.permission,
+            visibility=self.visibility)
 
         for ct in self.content_types:
             ct.__factory_meta_type__ = self.meta_type
 
-InitializeClass( ContentInit )
+
+InitializeClass(ContentInit)
+
 
 def manage_addContentForm(self, REQUEST):
-
     """ Show the add content type form.
     """
     # self is a FactoryDispatcher.
@@ -678,8 +712,8 @@ def manage_addContentForm(self, REQUEST):
                            factory_types_list=tl,
                            factory_need_id=1)
 
-def manage_addContent( self, id, type, REQUEST=None ):
 
+def manage_addContent(self, id, type, REQUEST=None):
     """ Add the content type specified by name.
     """
     # self is a FactoryDispatcher.
@@ -687,52 +721,15 @@ def manage_addContent( self, id, type, REQUEST=None ):
     obj = None
     for content_type in contentinit.content_types:
         if content_type.meta_type == type:
-            obj = content_type( id )
+            obj = content_type(id)
             break
     if obj is None:
         raise NotFound(type)
-    self._setObject( id, obj )
+    self._setObject(id, obj)
     if REQUEST is not None:
         return self.manage_main(self, REQUEST)
 
 
-def initializeBasesPhase1(base_classes, module):
-    """ Execute the first part of initialization of ZClass base classes.
-
-    Stuffs a _ZClass_for_x class in the module for each base.
-    """
-    warn('initializeBasesPhase1() is deprecated and will be removed in CMF '
-         '2.3. There is no replacement because ZClasses are also deprecated.',
-         DeprecationWarning, stacklevel=2)
-
-    rval = []
-    for base_class in base_classes:
-        d={}
-        zclass_name = '_ZClass_for_%s' % base_class.__name__
-        exec 'class %s: pass' % zclass_name in d
-        Z = d[ zclass_name ]
-        Z.propertysheets = PropertySheets()
-        Z._zclass_ = base_class
-        Z.manage_options = ()
-        Z.__module__ = module.__name__
-        setattr( module, zclass_name, Z )
-        rval.append(Z)
-    return rval
-
-def initializeBasesPhase2(zclasses, context):
-    """ Finishes ZClass base initialization.
-
-    o 'zclasses' is the list returned by initializeBasesPhase1().
-
-    o 'context' is a ProductContext object.
-    """
-    warn('initializeBasesPhase2() is deprecated and will be removed in CMF '
-         '2.3. There is no replacement because ZClasses are also deprecated.',
-         DeprecationWarning, stacklevel=2)
-
-    for zclass in zclasses:
-        context.registerZClass(zclass)
-
 def registerIcon(klass, iconspec, _prefix=None):
 
     """ Make an icon available for a given class.
@@ -746,100 +743,56 @@ def registerIcon(klass, iconspec, _prefix=None):
     name = os_path.split(iconspec)[1]
     klass.icon = 'misc_/%s/%s' % (pid, name)
     icon = ImageFile(iconspec, _prefix)
-    icon.__roles__=None
+    icon.__roles__ = None
     if not hasattr(misc_images, pid):
         setattr(misc_images, pid, MiscImage(pid, {}))
-    getattr(misc_images, pid)[name]=icon
+    getattr(misc_images, pid)[name] = icon
+
 
 #
 #   Metadata Keyword splitter utilities
 #
 KEYSPLITRE = re.compile(r'[,;]')
 
-security.declarePublic('keywordsplitter')
-def keywordsplitter( headers
-                   , names=('Subject', 'Keywords',)
-                   , splitter=KEYSPLITRE.split
-                   ):
+
+@security.public
+def keywordsplitter(headers, names=('Subject', 'Keywords'),
+                    splitter=KEYSPLITRE.split):
     """ Split keywords out of headers, keyed on names.  Returns list.
     """
     out = []
     for head in names:
         keylist = splitter(headers.get(head, ''))
-        keylist = map(lambda x: x.strip(), keylist)
-        out.extend( [key for key in keylist if key] )
+        keylist = [x.strip() for x in keylist]
+        out.extend([key for key in keylist if key])
     return out
 
+
 #
 #   Metadata Contributors splitter utilities
 #
 CONTRIBSPLITRE = re.compile(r';')
 
-security.declarePublic('contributorsplitter')
-def contributorsplitter( headers
-                       , names=('Contributors',)
-                       , splitter=CONTRIBSPLITRE.split
-                       ):
+
+@security.public
+def contributorsplitter(headers, names=('Contributors',),
+                        splitter=CONTRIBSPLITRE.split):
     """ Split contributors out of headers, keyed on names.  Returns list.
     """
-    return keywordsplitter( headers, names, splitter )
+    return keywordsplitter(headers, names, splitter)
+
 
 #
 #   Directory-handling utilities
 #
-security.declarePublic('normalize')
+@security.public
 def normalize(p):
     # the first .replace is needed to help normpath when dealing with Windows
     # paths under *nix, the second to normalize to '/'
-    return os_path.normpath(p.replace('\\','/')).replace('\\','/')
+    return os_path.normpath(p.replace('\\', '/')).replace('\\', '/')
 
-import Products
-ProductsPath = [ abspath(ppath) for ppath in Products.__path__ ]
 
-security.declarePublic('expandpath')
-def expandpath(p):
-    """ Convert minimal filepath to (expanded) filepath.
-
-    The (expanded) filepath is the valid absolute path on the current platform
-    and setup.
-    """
-    warn('expandpath() is deprecated and will be removed in CMF 2.3.',
-         DeprecationWarning, stacklevel=2)
-
-    p = os_path.normpath(p)
-    if os_path.isabs(p):
-        return p
-
-    for ppath in ProductsPath:
-        abs = os_path.join(ppath, p)
-        if os_path.exists(abs):
-            return abs
-
-    # return the last one, errors will happen else where as as result
-    # and be caught
-    return abs
-
-security.declarePublic('minimalpath')
-def minimalpath(p):
-    """ Convert (expanded) filepath to minimal filepath.
-
-    The minimal filepath is the cross-platform / cross-setup path stored in
-    persistent objects and used as key in the directory registry.
-
-    Returns a slash-separated path relative to the Products path. If it can't
-    be found, a normalized path is returned.
-    """
-    warn('minimalpath() is deprecated and will be removed in CMF 2.3.',
-         DeprecationWarning, stacklevel=2)
-
-    p = abspath(p)
-    for ppath in ProductsPath:
-        if p.startswith(ppath):
-            p = p[len(ppath)+1:]
-            break
-    return p.replace('\\','/')
-
-security.declarePrivate('getContainingPackage')
+@security.private
 def getContainingPackage(module):
     parts = module.split('.')
     while parts:
@@ -851,7 +804,8 @@ def getContainingPackage(module):
 
     raise ValueError('Unable to find package for module %s' % module)
 
-security.declarePrivate('getPackageLocation')
+
+@security.private
 def getPackageLocation(module):
     """ Return the filesystem location of a module.
 
@@ -859,13 +813,15 @@ def getPackageLocation(module):
     tricks it into working with just a module name.
     """
     package = getContainingPackage(module)
-    return package_home({'__name__' : package})
+    return package_home({'__name__': package})
 
-security.declarePrivate('getPackageName')
+
+@security.private
 def getPackageName(globals_):
     module = globals_['__name__']
     return getContainingPackage(module)
 
+
 def _OldCacheHeaders(obj):
     # Old-style checking of modified headers
 
@@ -874,8 +830,8 @@ def _OldCacheHeaders(obj):
         return False
 
     RESPONSE = REQUEST.RESPONSE
-    header = REQUEST.get_header('If-Modified-Since', None)
-    last_mod = long(obj.modified().timeTime())
+    header = REQUEST.getHeader('If-Modified-Since', None)
+    last_mod = int(obj.modified().timeTime())
 
     if header is not None:
         header = header.split(';')[0]
@@ -886,20 +842,21 @@ def _OldCacheHeaders(obj):
         # understand the screwy date string as a lucky side effect
         # of the way they parse it).
         try:
-            mod_since=DateTime(header)
-            mod_since=long(mod_since.timeTime())
-        except TypeError:
-            mod_since=None
+            mod_since = DateTime(header)
+            mod_since = int(mod_since.timeTime())
+        except (TypeError, DateTimeError):
+            mod_since = None
 
         if mod_since is not None:
             if last_mod > 0 and last_mod <= mod_since:
                 RESPONSE.setStatus(304)
                 return True
 
-    #Last-Modified will get stomped on by a cache policy if there is
-    #one set....
+    # Last-Modified will get stomped on by a cache policy if there is
+    # one set....
     RESPONSE.setHeader('Last-Modified', rfc1123_date(last_mod))
 
+
 def _FSCacheHeaders(obj):
     # Old-style setting of modified headers for FS-based objects
 
@@ -908,8 +865,10 @@ def _FSCacheHeaders(obj):
         return False
 
     RESPONSE = REQUEST.RESPONSE
-    header = REQUEST.get_header('If-Modified-Since', None)
-    last_mod = obj._file_mod_time
+    header = REQUEST.getHeader('If-Modified-Since', None)
+    # Reduce resolution to one second, else if-modified-since would
+    # always be older if system resolution is higher
+    last_mod = int(obj._file_mod_time)
 
     if header is not None:
         header = header.split(';')[0]
@@ -920,18 +879,18 @@ def _FSCacheHeaders(obj):
         # understand the screwy date string as a lucky side effect
         # of the way they parse it).
         try:
-            mod_since=DateTime(header)
-            mod_since=long(mod_since.timeTime())
-        except TypeError:
-            mod_since=None
+            mod_since = DateTime(header)
+            mod_since = int(mod_since.timeTime())
+        except (TypeError, DateTimeError):
+            mod_since = None
 
         if mod_since is not None:
             if last_mod > 0 and last_mod <= mod_since:
                 RESPONSE.setStatus(304)
                 return True
 
-    #Last-Modified will get stomped on by a cache policy if there is
-    #one set....
+    # Last-Modified will get stomped on by a cache policy if there is
+    # one set....
     RESPONSE.setHeader('Last-Modified', rfc1123_date(last_mod))
 
 
@@ -942,5 +901,19 @@ class SimpleRecord:
         self.__dict__.update(kw)
 
 
-security.declarePublic('Message')
+def base64_encode(text):
+    # Helper method to avoid deprecation warning under Python 3
+    if six.PY2:
+        return base64.encodestring(text).rstrip()
+    return base64.encodebytes(text).rstrip()
+
+
+def base64_decode(text):
+    # Helper method to avoid deprecation warning under Python 3
+    if six.PY2:
+        return base64.decodestring(text)
+    return base64.decodebytes(text)
+
+
+security.declarePublic('Message')  # NOQA: flake8: D001
 Message = MessageFactory('cmf_default')
